@@ -1,6 +1,6 @@
 from xsdata.codegen.container import ClassContainer
+from xsdata.codegen.exceptions import CodegenError
 from xsdata.codegen.handlers import DesignateClassPackages
-from xsdata.exceptions import CodeGenerationError
 from xsdata.models.config import (
     GeneratorConfig,
     GeneratorSubstitution,
@@ -12,17 +12,18 @@ from xsdata.utils.testing import AttrFactory, ClassFactory, FactoryTestCase
 
 
 class DesignateClassPackagesTests(FactoryTestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         super().setUp()
         self.config = GeneratorConfig()
         self.container = ClassContainer(config=self.config)
         self.handler = DesignateClassPackages(container=self.container)
 
-    def test_group_by_filenames(self):
+    def test_group_by_filenames(self) -> None:
         voc = "file://HL7V3/NE2008/coreschemas/voc.xsd"
         prpa = "file://HL7V3/NE2008/multicacheschemas/PRPA_MT201307UV02.xsd"
         coct = "file://HL7V3/NE2008/multicacheschemas/COCT_MT080000UV.xsd"
         foo_bar = "http://xsdata/foo/bar/schema.xsd"
+        foo_wsdl = "http://xsdata/foo/bar/schema.wsdl"
         foo_common = "http://xsdata/foo/common.xsd"
         xsi = Namespace.XSI.location
         xlink = Namespace.XLINK.location
@@ -31,6 +32,7 @@ class DesignateClassPackagesTests(FactoryTestCase):
         multi_one = ClassFactory.list(2, location=prpa)
         multi_two = ClassFactory.list(1, location=coct)
         http_one = ClassFactory.list(1, location=foo_bar)
+        wsdl_one = ClassFactory.list(1, location=foo_wsdl)
         http_two = ClassFactory.list(1, location=foo_common)
         local_one = ClassFactory.list(1, location=xsi)
         local_two = ClassFactory.list(1, location=xlink)
@@ -39,25 +41,27 @@ class DesignateClassPackagesTests(FactoryTestCase):
         self.container.extend(multi_one)
         self.container.extend(multi_two)
         self.container.extend(http_one)
+        self.container.extend(wsdl_one)
         self.container.extend(http_two)
         self.container.extend(local_one)
         self.container.extend(local_two)
 
-        self.config.output.package = "foo.bar"
+        self.config.output.package = "foo"
 
         self.handler.run()
 
-        self.assertEqual("foo.bar.coreschemas", core[0].package)
-        self.assertEqual("foo.bar.coreschemas", core[0].inner[0].package)
-        self.assertEqual("foo.bar.multicacheschemas", multi_one[0].package)
-        self.assertEqual("foo.bar.multicacheschemas", multi_one[1].package)
-        self.assertEqual("foo.bar.multicacheschemas", multi_two[0].package)
-        self.assertEqual("foo.bar.bar", http_one[0].package)
-        self.assertEqual("foo.bar", http_two[0].package)
-        self.assertEqual("foo.bar", local_one[0].package)
-        self.assertEqual("foo.bar", local_two[0].package)
+        self.assertEqual("foo.coreschemas", core[0].package)
+        self.assertEqual("foo.coreschemas", core[0].inner[0].package)
+        self.assertEqual("foo.multicacheschemas", multi_one[0].package)
+        self.assertEqual("foo.multicacheschemas", multi_one[1].package)
+        self.assertEqual("foo.multicacheschemas", multi_two[0].package)
+        self.assertEqual("foo.bar", http_one[0].package)
+        self.assertEqual("foo", http_two[0].package)
+        self.assertEqual("foo.bar", wsdl_one[0].package)
+        self.assertEqual("foo", local_one[0].package)
+        self.assertEqual("foo", local_two[0].package)
 
-    def test_group_by_namespace(self):
+    def test_group_by_namespace(self) -> None:
         classes = [
             ClassFactory.create(qname="{myNS.tempuri.org}a", location="foo"),
             ClassFactory.create(qname="{myNS.tempuri.org}b", location="foo"),
@@ -77,7 +81,7 @@ class DesignateClassPackagesTests(FactoryTestCase):
         self.assertEqual("myNS", classes[1].module)
         self.assertEqual("bar", classes[2].module)
 
-    def test_group_all_together(self):
+    def test_group_all_together(self) -> None:
         classes = [
             ClassFactory.create(qname="{a}a", location="foo"),
             ClassFactory.create(qname="{a}b", location="foo"),
@@ -108,7 +112,7 @@ class DesignateClassPackagesTests(FactoryTestCase):
         self.assertEqual("foo", classes[1].module)
         self.assertEqual("foo", classes[2].module)
 
-    def test_group_by_strong_components(self):
+    def test_group_by_strong_components(self) -> None:
         classes = ClassFactory.list(4)
         classes[0].attrs.append(AttrFactory.reference(classes[1].qname))
         classes[1].attrs.append(AttrFactory.reference(classes[2].qname))
@@ -132,7 +136,7 @@ class DesignateClassPackagesTests(FactoryTestCase):
         self.assertEqual("class_E", classes[2].module)
         self.assertEqual("class_E", classes[3].module)
 
-    def test_group_by_namespace_clusters(self):
+    def test_group_by_namespace_clusters(self) -> None:
         classes = [
             ClassFactory.create("{urn:foo-bar:com}a"),
             ClassFactory.create("{urn:foo-bar:add}b"),
@@ -160,7 +164,7 @@ class DesignateClassPackagesTests(FactoryTestCase):
         self.assertEqual("models.bar.foo.add", classes[2].package)
         self.assertEqual("models.bar.foo.add", classes[3].package)
 
-    def test_group_by_namespace_clusters_raises_exception(self):
+    def test_group_by_namespace_clusters_raises_exception(self) -> None:
         classes = [
             ClassFactory.create("{urn:foo-bar:com}a"),
             ClassFactory.create("{urn:foo-bar:add}b"),
@@ -177,16 +181,10 @@ class DesignateClassPackagesTests(FactoryTestCase):
         self.config.output.package = "models"
         self.container.extend(classes)
 
-        with self.assertRaises(CodeGenerationError) as cm:
+        with self.assertRaises(CodegenError):
             self.handler.run()
 
-        self.assertEqual(
-            "Found strongly connected classes from different namespaces, "
-            "grouping them is impossible!",
-            str(cm.exception),
-        )
-
-    def test_combine_ns_package(self):
+    def test_combine_ns_package(self) -> None:
         namespace = "urn:foo-bar:add"
         result = self.handler.combine_ns_package(namespace)
         self.assertEqual(["generated", "bar", "foo", "add"], result)
