@@ -2,7 +2,7 @@ from unittest import mock
 
 from xsdata.codegen.container import ClassContainer
 from xsdata.codegen.handlers import ProcessAttributeTypes
-from xsdata.codegen.models import Class, Restrictions, Status
+from xsdata.codegen.models import Restrictions, Status
 from xsdata.codegen.utils import ClassUtils
 from xsdata.models.config import GeneratorConfig
 from xsdata.models.enums import DataType, Tag
@@ -15,7 +15,7 @@ from xsdata.utils.testing import (
 
 
 class ProcessAttributeTypesTests(FactoryTestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         super().setUp()
 
         container = ClassContainer(config=GeneratorConfig())
@@ -23,7 +23,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
 
     @mock.patch.object(ProcessAttributeTypes, "cascade_properties")
     @mock.patch.object(ProcessAttributeTypes, "process_types")
-    def test_process(self, mock_process_types, mock_cascade_properties):
+    def test_process(self, mock_process_types, mock_cascade_properties) -> None:
         target = ClassFactory.elements(2)
 
         self.processor.process(target)
@@ -34,7 +34,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.assertEqual(2, len(calls))
 
     @mock.patch.object(ProcessAttributeTypes, "process_type")
-    def test_process_types(self, mock_process_type):
+    def test_process_types(self, mock_process_type) -> None:
         target = ClassFactory.create()
         attr = AttrFactory.create()
         types = [
@@ -53,7 +53,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
 
         self.assertEqual(types[:-1], attr.types)
 
-    def test_process_types_with_ignore_patterns(self):
+    def test_process_types_with_ignore_patterns(self) -> None:
         target = ClassFactory.create()
         attr = AttrFactory.native(DataType.DECIMAL)
         attr.restrictions.pattern = r"\d{2}.\d{2}"
@@ -62,7 +62,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.processor.process_types(target, attr)
         self.assertEqual(DataType.DECIMAL, attr.types[0].datatype)
 
-    def test_cascade_properties(self):
+    def test_cascade_properties(self) -> None:
         target = ClassFactory.create(default="2", fixed=True, nillable=True)
         attr = AttrFactory.native(DataType.STRING, tag=Tag.EXTENSION)
         self.processor.cascade_properties(target, attr)
@@ -89,7 +89,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
     @mock.patch.object(ProcessAttributeTypes, "process_native_type")
     def test_process_type_with_native_type(
         self, mock_process_native_type, mock_process_dependency_type
-    ):
+    ) -> None:
         attr = AttrFactory.create()
         target = ClassFactory.create()
         xs_int = AttrTypeFactory.native(DataType.INT)
@@ -102,7 +102,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
     @mock.patch.object(ProcessAttributeTypes, "process_native_type")
     def test_process_type_with_dependency_type(
         self, mock_process_native_type, mock_process_dependency_type
-    ):
+    ) -> None:
         attr = AttrFactory.create()
         target = ClassFactory.create()
         attr_type = AttrTypeFactory.create()
@@ -112,7 +112,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         mock_process_dependency_type.assert_called_once_with(target, attr, attr_type)
 
     @mock.patch.object(ProcessAttributeTypes, "process_inner_type")
-    def test_process_type_with_forward_reference(self, mock_process_inner_type):
+    def test_process_type_with_forward_reference(self, mock_process_inner_type) -> None:
         attr = AttrFactory.create()
         target = ClassFactory.create()
         attr_type = AttrTypeFactory.create(forward=True)
@@ -120,7 +120,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.processor.process_type(target, attr, attr_type)
         mock_process_inner_type.assert_called_once_with(target, attr, attr_type)
 
-    def test_process_native_type(self):
+    def test_process_native_type(self) -> None:
         attr = AttrFactory.native(DataType.INT)
         nm_tokens_type = AttrTypeFactory.native(DataType.NMTOKENS)
 
@@ -138,20 +138,20 @@ class ProcessAttributeTypesTests(FactoryTestCase):
     @mock.patch.object(ProcessAttributeTypes, "find_dependency")
     def test_process_dependency_type_with_absent_type(
         self, mock_find_dependency, mock_reset_attribute_type
-    ):
+    ) -> None:
         mock_find_dependency.return_value = None
         target = ClassFactory.create()
         attr = AttrFactory.create()
         attr_type = attr.types[0]
 
         self.processor.process_dependency_type(target, attr, attr_type)
-        mock_reset_attribute_type.assert_called_once_with(attr_type, True)
+        mock_reset_attribute_type.assert_called_once_with(attr_type)
 
     @mock.patch.object(ProcessAttributeTypes, "copy_attribute_properties")
     @mock.patch.object(ProcessAttributeTypes, "find_dependency")
     def test_process_dependency_type_with_simple_type(
         self, mock_find_dependency, mock_copy_attribute_properties
-    ):
+    ) -> None:
         simple = ClassFactory.simple_type()
         target = ClassFactory.create()
         attr = AttrFactory.create()
@@ -164,7 +164,9 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         )
 
     @mock.patch.object(ProcessAttributeTypes, "find_dependency")
-    def test_process_dependency_type_with_enumeration_type(self, mock_find_dependency):
+    def test_process_dependency_type_with_enumeration_type(
+        self, mock_find_dependency
+    ) -> None:
         enumeration = ClassFactory.enumeration(2)
         enumeration.attrs[1].restrictions.format = "base16"
         mock_find_dependency.return_value = enumeration
@@ -180,11 +182,10 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.assertIsNone(attr.restrictions.min_length)
         self.assertIsNone(attr.restrictions.max_length)
 
-    @mock.patch.object(ProcessAttributeTypes, "set_circular_flag")
     @mock.patch.object(ProcessAttributeTypes, "find_dependency")
     def test_process_dependency_type_with_complex_type(
-        self, mock_find_dependency, mock_set_circular_flag
-    ):
+        self, mock_find_dependency
+    ) -> None:
         complex_type = ClassFactory.elements(1)
         mock_find_dependency.return_value = complex_type
 
@@ -193,18 +194,18 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         attr_type = attr.types[0]
 
         self.processor.process_dependency_type(target, attr, attr_type)
-        mock_set_circular_flag.assert_called_once_with(complex_type, target, attr_type)
 
         self.assertFalse(attr.restrictions.nillable)
 
         complex_type.nillable = True
         self.processor.process_dependency_type(target, attr, attr_type)
         self.assertTrue(attr.restrictions.nillable)
+        self.assertEqual(complex_type.ref, attr_type.reference)
 
     @mock.patch.object(ProcessAttributeTypes, "find_dependency")
     def test_process_dependency_type_with_abstract_type_type(
         self, mock_find_dependency
-    ):
+    ) -> None:
         complex_type = ClassFactory.create(tag=Tag.ELEMENT, abstract=True)
         mock_find_dependency.return_value = complex_type
 
@@ -221,7 +222,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
     @mock.patch.object(ProcessAttributeTypes, "copy_attribute_properties")
     def test_process_inner_type_with_simple_type(
         self, mock_copy_attribute_properties, mock_update_restrictions
-    ):
+    ) -> None:
         attr = AttrFactory.create(types=[AttrTypeFactory.create(qname="{bar}a")])
         inner = ClassFactory.simple_type(qname="{bar}a", status=Status.FLATTENED)
         target = ClassFactory.create(inner=[inner])
@@ -238,7 +239,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
     @mock.patch.object(ProcessAttributeTypes, "copy_attribute_properties")
     def test_process_inner_type_with_complex_type(
         self, mock_copy_attribute_properties, mock_update_restrictions
-    ):
+    ) -> None:
         target = ClassFactory.create()
         inner = ClassFactory.elements(2, qname="a", status=Status.FLATTENED)
         attr = AttrFactory.create(types=[AttrTypeFactory.create(qname="a")])
@@ -253,17 +254,19 @@ class ProcessAttributeTypesTests(FactoryTestCase):
     @mock.patch.object(ProcessAttributeTypes, "copy_attribute_properties")
     def test_process_inner_type_with_circular_reference(
         self, mock_copy_attribute_properties, mock_update_restrictions
-    ):
+    ) -> None:
         target = ClassFactory.create()
         attr = AttrFactory.create()
         attr_type = AttrTypeFactory.create(circular=True)
 
         self.processor.process_inner_type(target, attr, attr_type)
+
+        self.assertEqual(target.ref, attr_type.reference)
         self.assertEqual(0, mock_copy_attribute_properties.call_count)
         self.assertEqual(0, mock_update_restrictions.call_count)
 
     @mock.patch.object(ClassUtils, "copy_inner_class")
-    def test_copy_attribute_properties(self, mock_copy_inner_class):
+    def test_copy_attribute_properties(self, mock_copy_inner_class) -> None:
         source = ClassFactory.elements(1, qname="Foobar")
         source.attrs[0].restrictions.max_length = 100
         source.attrs[0].restrictions.min_length = 1
@@ -295,12 +298,24 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         )
         mock_copy_inner_class.assert_has_calls(
             [
-                mock.call(source, target, attr, source.attrs[0].types[0]),
-                mock.call(source, target, attr, source.attrs[0].types[1]),
+                mock.call(source, target, source.attrs[0].types[0]),
+                mock.call(source, target, source.attrs[0].types[1]),
             ]
         )
 
-    def test_copy_attribute_properties_from_nillable_source(self):
+    @mock.patch.object(ProcessAttributeTypes, "reset_attribute_type")
+    def test_copy_attribute_properties_from_empty_source(
+        self, mock_reset_attribute_type
+    ) -> None:
+        source = ClassFactory.create()
+        target = ClassFactory.elements(1)
+        attr = target.attrs[0]
+
+        self.processor.copy_attribute_properties(source, target, attr, attr.types[0])
+
+        mock_reset_attribute_type.assert_called_once_with(attr.types[0])
+
+    def test_copy_attribute_properties_from_nillable_source(self) -> None:
         source = ClassFactory.elements(1, nillable=True)
         target = ClassFactory.elements(1)
         attr = target.attrs[0]
@@ -308,7 +323,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.processor.copy_attribute_properties(source, target, attr, attr.types[0])
         self.assertTrue(attr.restrictions.nillable)
 
-    def test_copy_attribute_properties_set_default_value_if_none(self):
+    def test_copy_attribute_properties_set_default_value_if_none(self) -> None:
         target = ClassFactory.create(attrs=AttrFactory.list(1, tag=Tag.ATTRIBUTE))
         attr = target.attrs[0]
 
@@ -326,107 +341,45 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.assertEqual("foo", attr.default)
         self.assertTrue("foo", attr.fixed)
 
-    @mock.patch.object(ProcessAttributeTypes, "is_circular_dependency")
-    def test_set_circular_flag(self, mock_is_circular_dependency):
-        source = ClassFactory.create()
-        target = ClassFactory.create()
-        attr = AttrFactory.create()
-        attr_type = attr.types[0]
-
-        mock_is_circular_dependency.return_value = True
-
-        self.processor.set_circular_flag(source, target, attr_type)
-        self.assertTrue(attr_type.circular)
-        self.assertEqual(id(source), attr_type.reference)
-
-        mock_is_circular_dependency.assert_called_once_with(source, target, set())
-
-    @mock.patch.object(ClassContainer, "find")
-    @mock.patch.object(Class, "dependencies")
-    def test_is_circular_dependency(self, mock_dependencies, mock_container_find):
-        source = ClassFactory.create()
-        target = ClassFactory.create()
-        another = ClassFactory.create()
-        processing = ClassFactory.create(status=Status.FLATTENING)
-
-        find_classes = {"a": another, "b": target}
-
-        mock_container_find.side_effect = lambda x: find_classes.get(x)
-        mock_dependencies.side_effect = [
-            list("ccde"),
-            list("abc"),
-            list("xy"),
-        ]
-
-        self.assertTrue(
-            self.processor.is_circular_dependency(processing, target, set())
-        )
-
-        self.processor.dependencies.clear()
-        self.assertFalse(self.processor.is_circular_dependency(source, target, set()))
-
-        self.processor.dependencies.clear()
-        self.assertTrue(self.processor.is_circular_dependency(source, target, set()))
-
-        self.processor.dependencies.clear()
-        self.assertTrue(self.processor.is_circular_dependency(source, source, set()))
-
-        mock_container_find.assert_has_calls(
-            [
-                mock.call("c"),
-                mock.call("d"),
-                mock.call("e"),
-                mock.call("a"),
-                mock.call("x"),
-                mock.call("y"),
-                mock.call("b"),
-            ]
-        )
-
-    def test_find_dependency(self):
+    def test_find_dependency(self) -> None:
         attr_type = AttrTypeFactory.create(qname="a")
 
         element = ClassFactory.create(qname="a", tag=Tag.ELEMENT)
         complex_type = ClassFactory.create(qname="a", tag=Tag.COMPLEX_TYPE)
         simple_type = ClassFactory.create(qname="a", tag=Tag.SIMPLE_TYPE)
 
-        actual = self.processor.find_dependency(attr_type, Tag.ELEMENT)
+        actual = self.processor.find_dependency(element, attr_type, Tag.ELEMENT)
         self.assertIsNone(actual)
 
         self.processor.container.add(simple_type)
-        actual = self.processor.find_dependency(attr_type, Tag.ELEMENT)
+        actual = self.processor.find_dependency(element, attr_type, Tag.ELEMENT)
         self.assertEqual(simple_type, actual)
 
         self.processor.container.add(complex_type)
-        actual = self.processor.find_dependency(attr_type, Tag.ELEMENT)
+        actual = self.processor.find_dependency(element, attr_type, Tag.ELEMENT)
         self.assertEqual(complex_type, actual)
 
         self.processor.container.add(element)
-        actual = self.processor.find_dependency(attr_type, Tag.ELEMENT)
+        actual = self.processor.find_dependency(complex_type, attr_type, Tag.ELEMENT)
         self.assertEqual(element, actual)
 
-        actual = self.processor.find_dependency(attr_type, Tag.SIMPLE_TYPE)
+        actual = self.processor.find_dependency(element, attr_type, Tag.ELEMENT)
+        self.assertEqual(complex_type, actual)
+
+        actual = self.processor.find_dependency(element, attr_type, Tag.SIMPLE_TYPE)
         self.assertEqual(simple_type, actual)
 
-        actual = self.processor.find_dependency(attr_type, Tag.EXTENSION)
+        actual = self.processor.find_dependency(element, attr_type, Tag.EXTENSION)
         self.assertEqual(simple_type, actual)
 
-    @mock.patch.object(Class, "dependencies")
-    def test_cached_dependencies(self, mock_class_dependencies):
-        mock_class_dependencies.return_value = ["a", "b"]
+        referenced = ClassFactory.create()
+        self.processor.container.add(referenced)
+        attr_type.reference = referenced.ref
+        attr_type.qname = referenced.qname
+        actual = self.processor.find_dependency(element, attr_type, Tag.EXTENSION)
+        self.assertEqual(referenced, actual)
 
-        source = ClassFactory.create()
-        self.processor.dependencies[id(source)] = ("a",)
-
-        actual = self.processor.cached_dependencies(source)
-        self.assertEqual(("a",), actual)
-
-        self.processor.dependencies.clear()
-        actual = self.processor.cached_dependencies(source)
-        self.assertEqual(("a", "b"), actual)
-        mock_class_dependencies.assert_called_once_with()
-
-    def test_update_restrictions(self):
+    def test_update_restrictions(self) -> None:
         attr = AttrFactory.native(DataType.NMTOKENS)
         self.processor.update_restrictions(attr, attr.types[0].datatype)
         self.assertTrue(attr.restrictions.tokens)
@@ -443,7 +396,7 @@ class ProcessAttributeTypesTests(FactoryTestCase):
         self.processor.update_restrictions(attr, attr.types[0].datatype)
         self.assertEqual("base16", attr.restrictions.format)
 
-    def test_detect_lazy_namespace(self):
+    def test_detect_lazy_namespace(self) -> None:
         source = ClassFactory.create(namespace="foo", tag=Tag.ELEMENT)
         target = ClassFactory.create()
         attr = AttrFactory.create(namespace="##lazy")
