@@ -3,19 +3,22 @@ import tempfile
 from pathlib import Path
 from unittest import mock
 
-from xsdata.codegen.analyzer import ClassAnalyzer
+from toposort import CircularDependencyError
+
+from xsdata import __version__
 from xsdata.codegen.container import ClassContainer
-from xsdata.codegen.mappers.definitions import DefinitionsMapper
-from xsdata.codegen.mappers.dict import DictMapper
-from xsdata.codegen.mappers.dtd import DtdMapper
-from xsdata.codegen.mappers.element import ElementMapper
-from xsdata.codegen.mappers.schema import SchemaMapper
-from xsdata.codegen.parsers import DefinitionsParser
-from xsdata.codegen.parsers.dtd import DtdParser
-from xsdata.codegen.transformer import SchemaTransformer
+from xsdata.codegen.exceptions import CodegenError
+from xsdata.codegen.mappers import (
+    DefinitionsMapper,
+    DictMapper,
+    DtdMapper,
+    ElementMapper,
+    SchemaMapper,
+)
+from xsdata.codegen.parsers import DefinitionsParser, DtdParser
+from xsdata.codegen.transformer import ResourceTransformer
 from xsdata.codegen.utils import ClassUtils
 from xsdata.codegen.writer import CodeWriter
-from xsdata.exceptions import CodeGenerationError
 from xsdata.formats.dataclass.models.generics import AnyElement
 from xsdata.formats.dataclass.parsers import TreeParser
 from xsdata.models.config import GeneratorConfig
@@ -24,18 +27,18 @@ from xsdata.models.xsd import Import, Include, Override, Schema
 from xsdata.utils.testing import ClassFactory, DtdFactory, FactoryTestCase
 
 
-class SchemaTransformerTests(FactoryTestCase):
-    def setUp(self):
+class ResourceTransformerTests(FactoryTestCase):
+    def setUp(self) -> None:
         config = GeneratorConfig()
-        self.transformer = SchemaTransformer(print=True, config=config)
+        self.transformer = ResourceTransformer(config=config)
         super().setUp()
 
-    @mock.patch.object(SchemaTransformer, "process_classes")
-    @mock.patch.object(SchemaTransformer, "process_dtds")
-    @mock.patch.object(SchemaTransformer, "process_json_documents")
-    @mock.patch.object(SchemaTransformer, "process_xml_documents")
-    @mock.patch.object(SchemaTransformer, "process_schemas")
-    @mock.patch.object(SchemaTransformer, "process_definitions")
+    @mock.patch.object(ResourceTransformer, "process_classes")
+    @mock.patch.object(ResourceTransformer, "process_dtds")
+    @mock.patch.object(ResourceTransformer, "process_json_documents")
+    @mock.patch.object(ResourceTransformer, "process_xml_documents")
+    @mock.patch.object(ResourceTransformer, "process_schemas")
+    @mock.patch.object(ResourceTransformer, "process_definitions")
     def test_process(
         self,
         mock_process_definitions,
@@ -44,7 +47,7 @@ class SchemaTransformerTests(FactoryTestCase):
         mock_process_json_documents,
         mock_process_dtds,
         mock_process_classes,
-    ):
+    ) -> None:
         uris = [
             "a.wsdl",
             "b.wsdl",
@@ -65,12 +68,12 @@ class SchemaTransformerTests(FactoryTestCase):
         mock_process_dtds.assert_called_once_with(uris[8:])
         mock_process_classes.assert_called_once_with()
 
-    @mock.patch.object(SchemaTransformer, "process_classes")
-    @mock.patch.object(SchemaTransformer, "process_sources")
-    @mock.patch.object(SchemaTransformer, "get_cache_file")
+    @mock.patch.object(ResourceTransformer, "process_classes")
+    @mock.patch.object(ResourceTransformer, "process_sources")
+    @mock.patch.object(ResourceTransformer, "get_cache_file")
     def test_process_from_cache(
         self, mock_get_cache_file, mock_process_sources, mock_process_classes
-    ):
+    ) -> None:
         with tempfile.TemporaryDirectory() as tmpdir:
             cache = Path(tmpdir).joinpath("foo.cache")
             classes = ClassFactory.list(2)
@@ -85,12 +88,12 @@ class SchemaTransformerTests(FactoryTestCase):
             self.assertEqual(0, mock_process_sources.call_count)
             mock_process_classes.assert_called_once_with()
 
-    @mock.patch.object(SchemaTransformer, "process_classes")
-    @mock.patch.object(SchemaTransformer, "process_sources")
-    @mock.patch.object(SchemaTransformer, "get_cache_file")
+    @mock.patch.object(ResourceTransformer, "process_classes")
+    @mock.patch.object(ResourceTransformer, "process_sources")
+    @mock.patch.object(ResourceTransformer, "get_cache_file")
     def test_process_with_cache(
         self, mock_get_cache_file, mock_process_sources, mock_process_classes
-    ):
+    ) -> None:
         with tempfile.TemporaryDirectory() as tmpdir:
             cache = Path(tmpdir).joinpath("foo.cache")
             classes = ClassFactory.list(2)
@@ -104,15 +107,34 @@ class SchemaTransformerTests(FactoryTestCase):
             self.assertEqual(classes, pickle.loads(cache.read_bytes()))
             mock_process_classes.assert_called_once_with()
 
-    @mock.patch.object(SchemaTransformer, "convert_schema")
-    @mock.patch.object(SchemaTransformer, "convert_definitions")
-    @mock.patch.object(SchemaTransformer, "parse_definitions")
+    @mock.patch.object(ResourceTransformer, "process_classes")
+    def test_process_with_circular_dependencies_error(
+        self, mock_process_classes
+    ) -> None:
+        mock_process_classes.side_effect = CircularDependencyError({})
+        with self.assertRaises(CodegenError):
+            self.transformer.process([])
+
+    @mock.patch("xsdata.codegen.transformer.logger.warning")
+    @mock.patch.object(ResourceTransformer, "process_classes")
+    def test_process_with_module_not_found_error(
+        self, mock_process_classes, mock_warning
+    ) -> None:
+        mock_process_classes.side_effect = ModuleNotFoundError({})
+        self.transformer.process([])
+        mock_warning.assert_called_once_with(
+            "Module not found on imports validation, please report it."
+        )
+
+    @mock.patch.object(ResourceTransformer, "convert_schema")
+    @mock.patch.object(ResourceTransformer, "convert_definitions")
+    @mock.patch.object(ResourceTransformer, "parse_definitions")
     def test_process_definitions(
         self,
         mock_parse_definitions,
         mock_convert_definitions,
         mock_convert_schema,
-    ):
+    ) -> None:
         uris = [
             "http://xsdata/services.wsdl",
             "http://xsdata/abstractServices.wsdl",
@@ -129,8 +151,8 @@ class SchemaTransformerTests(FactoryTestCase):
         )
         mock_convert_definitions.assert_called_once_with(fist_def)
 
-    @mock.patch.object(SchemaTransformer, "process_schema")
-    def test_process_schemas(self, mock_process_schema):
+    @mock.patch.object(ResourceTransformer, "process_schema")
+    def test_process_schemas(self, mock_process_schema) -> None:
         uris = ["http://xsdata/foo.xsd", "http://xsdata/bar.xsd"]
 
         self.transformer.process_schemas(uris)
@@ -140,10 +162,10 @@ class SchemaTransformerTests(FactoryTestCase):
     @mock.patch.object(ClassUtils, "reduce_classes")
     @mock.patch.object(ElementMapper, "map")
     @mock.patch.object(TreeParser, "from_bytes")
-    @mock.patch.object(SchemaTransformer, "load_resource")
+    @mock.patch.object(ResourceTransformer, "load_resource")
     def test_process_xml_documents(
         self, mock_load_resource, mock_from_bytes, mock_map, mock_reduce_classes
-    ):
+    ) -> None:
         uris = ["foo/a.xml", "foo/b.xml", "foo/c.xml"]
         resources = [b"a", None, b"c"]
         elements = [AnyElement(), AnyElement()]
@@ -169,10 +191,10 @@ class SchemaTransformerTests(FactoryTestCase):
     @mock.patch("xsdata.codegen.transformer.logger.warning")
     @mock.patch.object(ClassUtils, "reduce_classes")
     @mock.patch.object(DictMapper, "map")
-    @mock.patch.object(SchemaTransformer, "load_resource")
+    @mock.patch.object(ResourceTransformer, "load_resource")
     def test_process_json_documents(
         self, mock_load_resource, mock_map, mock_reduce_classes, mock_warning
-    ):
+    ) -> None:
         uris = ["foo/a.json", "foo/b.json", "foo/c.json", "bar.json"]
         resources = [b'{"foo": 1}', None, b'[{"foo": true}]', b"notjson"]
 
@@ -201,8 +223,8 @@ class SchemaTransformerTests(FactoryTestCase):
 
     @mock.patch.object(DtdMapper, "map")
     @mock.patch.object(DtdParser, "parse")
-    @mock.patch.object(SchemaTransformer, "load_resource")
-    def test_process_dtds(self, mock_load_resource, mock_parse, mock_map):
+    @mock.patch.object(ResourceTransformer, "load_resource")
+    def test_process_dtds(self, mock_load_resource, mock_parse, mock_map) -> None:
         uris = ["foo/a.dtd", "foo/b.dtd", "foo/c.dtd"]
         resources = [b"a", None, b"c"]
         dtds = DtdFactory.list(2)
@@ -231,45 +253,19 @@ class SchemaTransformerTests(FactoryTestCase):
             ]
         )
 
-    @mock.patch("xsdata.codegen.transformer.logger.info")
-    @mock.patch.object(CodeWriter, "print")
-    @mock.patch.object(SchemaTransformer, "analyze_classes")
-    def test_process_classes_with_print_true(
-        self,
-        mock_analyze_classes,
-        mock_writer_print,
-        mock_logger_into,
-    ):
-        schema_classes = ClassFactory.list(3)
-        analyzer_classes = ClassFactory.list(2)
-        mock_analyze_classes.return_value = analyzer_classes
-
-        self.transformer.classes = schema_classes
-        self.transformer.process_classes()
-
-        mock_analyze_classes.assert_called_once_with(schema_classes)
-        mock_writer_print.assert_called_once_with(analyzer_classes)
-        mock_logger_into.assert_has_calls(
-            [
-                mock.call("Analyzer input: %d main and %d inner classes", 3, 0),
-                mock.call("Analyzer output: %d main and %d inner classes", 2, 0),
-            ]
-        )
-
     @mock.patch("xsdata.codegen.transformer.logger.info")
     @mock.patch.object(CodeWriter, "write")
-    @mock.patch.object(SchemaTransformer, "analyze_classes")
-    def test_process_classes_with_print_false(
+    @mock.patch.object(ResourceTransformer, "analyze_classes")
+    def test_process_classes(
         self,
         mock_analyze_classes,
         mock_writer_write,
         mock_logger_into,
-    ):
+    ) -> None:
         schema_classes = ClassFactory.list(3)
         analyzer_classes = ClassFactory.list(2)
         mock_analyze_classes.return_value = analyzer_classes
 
-        self.transformer.print = False
         self.transformer.classes = schema_classes
         self.transformer.process_classes()
 
@@ -282,19 +278,13 @@ class SchemaTransformerTests(FactoryTestCase):
             ]
         )
 
-    def test_process_classes_with_zero_classes_after_analyze(self):
-        with self.assertRaises(CodeGenerationError) as cm:
-            self.transformer.process_classes()
-
-        self.assertEqual("Nothing to generate.", str(cm.exception))
-
-    @mock.patch.object(SchemaTransformer, "convert_schema")
-    @mock.patch.object(SchemaTransformer, "parse_schema")
+    @mock.patch.object(ResourceTransformer, "convert_schema")
+    @mock.patch.object(ResourceTransformer, "parse_schema")
     def test_process_schema(
         self,
         mock_parse_schema,
         mock_convert_schema,
-    ):
+    ) -> None:
         schema = Schema()
         mock_parse_schema.return_value = schema
         uri = "http://xsdata/services.xsd"
@@ -304,13 +294,13 @@ class SchemaTransformerTests(FactoryTestCase):
 
         mock_convert_schema.assert_called_once_with(schema)
 
-    @mock.patch.object(SchemaTransformer, "convert_schema")
-    @mock.patch.object(SchemaTransformer, "parse_schema")
+    @mock.patch.object(ResourceTransformer, "convert_schema")
+    @mock.patch.object(ResourceTransformer, "parse_schema")
     def test_process_schema_ignores_empty_schema(
         self,
         mock_parse_schema,
         mock_convert_schema,
-    ):
+    ) -> None:
         mock_parse_schema.return_value = None
         uri = "http://xsdata/services.xsd"
         namespace = "fooNS"
@@ -318,9 +308,9 @@ class SchemaTransformerTests(FactoryTestCase):
         self.transformer.process_schema(uri, namespace)
         self.assertEqual(0, mock_convert_schema.call_count)
 
-    @mock.patch.object(SchemaTransformer, "generate_classes")
-    @mock.patch.object(SchemaTransformer, "process_schema")
-    def test_convert_schema(self, mock_process_schema, mock_generate_classes):
+    @mock.patch.object(ResourceTransformer, "generate_classes")
+    @mock.patch.object(ResourceTransformer, "process_schema")
+    def test_convert_schema(self, mock_process_schema, mock_generate_classes) -> None:
         schema = Schema(target_namespace="thug", location="main")
         schema.includes.append(Include(location="foo"))
         schema.overrides.append(Override())
@@ -341,7 +331,7 @@ class SchemaTransformerTests(FactoryTestCase):
         )
 
     @mock.patch.object(DefinitionsMapper, "map")
-    def test_convert_definitions(self, mock_definitions_map):
+    def test_convert_definitions(self, mock_definitions_map) -> None:
         classes = ClassFactory.list(2)
         mock_definitions_map.return_value = classes
         definitions = Definitions(location="foo")
@@ -350,11 +340,11 @@ class SchemaTransformerTests(FactoryTestCase):
         self.assertEqual(classes, self.transformer.classes)
 
     @mock.patch("xsdata.codegen.transformer.logger.info")
-    @mock.patch.object(SchemaTransformer, "count_classes")
+    @mock.patch.object(ResourceTransformer, "count_classes")
     @mock.patch.object(SchemaMapper, "map")
     def test_generate_classes(
         self, mock_mapper_map, mock_count_classes, mock_logger_info
-    ):
+    ) -> None:
         schema = Schema(location="edo.xsd")
         classes = ClassFactory.list(2)
 
@@ -370,24 +360,24 @@ class SchemaTransformerTests(FactoryTestCase):
             ]
         )
 
-    def test_parse_schema(self):
+    def test_parse_schema(self) -> None:
         uri = Path(__file__).parent.joinpath("../fixtures/books/schema.xsd").as_uri()
         schema = self.transformer.parse_schema(uri, "foo.bar")
         self.assertIsInstance(schema, Schema)
         self.assertEqual(2, len(schema.complex_types))
         self.assertIsNone(self.transformer.parse_schema(uri, None))  # Once
 
-    @mock.patch.object(SchemaTransformer, "process_schema")
+    @mock.patch.object(ResourceTransformer, "process_schema")
     @mock.patch.object(Definitions, "merge")
     @mock.patch.object(DefinitionsParser, "from_bytes")
-    @mock.patch.object(SchemaTransformer, "load_resource")
+    @mock.patch.object(ResourceTransformer, "load_resource")
     def test_parse_definitions(
         self,
         mock_load_resource,
         mock_definitions_parser,
         mock_definitions_merge,
         mock_process_schema,
-    ):
+    ) -> None:
         def_one = Definitions(
             imports=[
                 Import(),
@@ -407,7 +397,7 @@ class SchemaTransformerTests(FactoryTestCase):
         mock_process_schema.assert_called_once_with("file://types.xsd")
 
     @mock.patch("xsdata.codegen.transformer.logger.debug")
-    def test_load_resource(self, mock_debug):
+    def test_load_resource(self, mock_debug) -> None:
         path = Path(__file__).as_uri()
 
         result = self.transformer.load_resource(path)
@@ -419,7 +409,7 @@ class SchemaTransformerTests(FactoryTestCase):
         self.assertIsNone(result)
         mock_debug.assert_called_once_with("Skipping already processed: %s", path)
 
-    def test_classify_resource(self):
+    def test_classify_resource(self) -> None:
         self.assertEqual(0, self.transformer.classify_resource("file://notexists"))
         self.assertEqual(1, self.transformer.classify_resource("a.xsd"))
         self.assertEqual(2, self.transformer.classify_resource("a.wsdl"))
@@ -455,38 +445,34 @@ class SchemaTransformerTests(FactoryTestCase):
         file_path.unlink()
 
     @mock.patch("xsdata.codegen.transformer.logger.warning")
-    def test_load_resource_missing(self, mock_warning):
-        uri = "file://foo/bar.xsd"
-        result = self.transformer.load_resource(uri)
+    def test_load_resource_missing(self, mock_warning) -> None:
+        uri = Path.cwd().joinpath("foo/bar.xsd").as_uri()
+        result = self.transformer.process([uri])
         self.assertIsNone(result)
 
         mock_warning.assert_called_once_with("Resource not found %s", uri)
 
-    def test_count_classes(self):
+    def test_count_classes(self) -> None:
         classes = ClassFactory.list(
             2, inner=ClassFactory.list(2, inner=ClassFactory.list(3))
         )
 
         self.assertEqual((2, 16), self.transformer.count_classes(classes))
 
-    @mock.patch.object(ClassAnalyzer, "process")
-    def test_analyze_classes(self, mock_process):
+    @mock.patch.object(ClassContainer, "process")
+    def test_analyze_classes(self, mock_process) -> None:
         classes = ClassFactory.list(2)
-        mock_process.return_value = classes[1:]
 
         result = self.transformer.analyze_classes(classes)
-        self.assertEqual(1, len(result))
+        self.assertEqual(2, len(result))
+        mock_process.assert_called_once()
 
-        actual = mock_process.call_args[0][0]
-
-        self.assertIsInstance(actual, ClassContainer)
-        self.assertEqual(2, len(actual.data))
-        self.assertEqual(self.transformer.config, actual.config)
-
-    def test_get_cache_file(self):
+    def test_get_cache_file(self) -> None:
         uris = ["a.xml", "b.json"]
         actual = self.transformer.get_cache_file(uris)
         tempdir = Path(tempfile.gettempdir())
-        expected = tempdir.joinpath("ae1bed744d3d3611e698a2d2ef5335d2.cache")
+        expected = tempdir.joinpath(
+            f"xsdata.{__version__}.ae1bed744d3d3611e698a2d2ef5335d2.cache"
+        )
 
         self.assertEqual(expected, actual)
