@@ -1,10 +1,10 @@
 import sys
-from typing import Generator
+from collections.abc import Generator
 from unittest import mock
 
+from xsdata.codegen.exceptions import CodegenError
 from xsdata.codegen.models import Restrictions, Status
 from xsdata.codegen.utils import ClassUtils
-from xsdata.exceptions import CodeGenerationError
 from xsdata.models.enums import DataType, Tag
 from xsdata.utils.testing import (
     AttrFactory,
@@ -16,22 +16,20 @@ from xsdata.utils.testing import (
 
 
 class ClassUtilsTests(FactoryTestCase):
-    def test_find_value_attr(self):
+    def test_find_value_attr(self) -> None:
         target = ClassFactory.create()
-        with self.assertRaises(CodeGenerationError) as cm:
+        with self.assertRaises(CodegenError):
             ClassUtils.find_value_attr(target)
 
-        self.assertEqual("Class has no value attr {xsdata}class_B", str(cm.exception))
-
         target.attrs.append(AttrFactory.element())
-        with self.assertRaises(CodeGenerationError) as cm:
+        with self.assertRaises(CodegenError):
             ClassUtils.find_value_attr(target)
 
         target.attrs.append(AttrFactory.extension())
         actual = ClassUtils.find_value_attr(target)
         self.assertEqual(target.attrs[1], actual)
 
-    def test_remove_attribute(self):
+    def test_remove_attribute(self) -> None:
         target = ClassFactory.elements(1)
         attr = target.attrs[0]
 
@@ -39,7 +37,7 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertEqual(0, len(target.attrs))
 
     @mock.patch.object(ClassUtils, "is_orphan_inner")
-    def test_clean_inner_classes(self, mock_is_orphan_inner):
+    def test_clean_inner_classes(self, mock_is_orphan_inner) -> None:
         mock_is_orphan_inner.side_effect = [True, False, True]
 
         target = ClassFactory.create()
@@ -51,7 +49,7 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertEqual(1, len(target.inner))
         self.assertEqual(survivor, target.inner[0])
 
-    def test_is_orphan_inner(self):
+    def test_is_orphan_inner(self) -> None:
         inner = ClassFactory.create(qname="thug")
         target = ClassFactory.create(
             attrs=[
@@ -72,7 +70,9 @@ class ClassUtilsTests(FactoryTestCase):
 
     @mock.patch.object(ClassUtils, "copy_inner_classes")
     @mock.patch.object(ClassUtils, "clone_attribute")
-    def test_copy_attributes(self, mock_clone_attribute, mock_copy_inner_classes):
+    def test_copy_attributes(
+        self, mock_clone_attribute, mock_copy_inner_classes
+    ) -> None:
         mock_clone_attribute.side_effect = lambda x, y: x.clone()
         target = ClassFactory.create(
             attrs=[AttrFactory.create(name="a"), AttrFactory.create(name="b")]
@@ -107,12 +107,14 @@ class ClassUtilsTests(FactoryTestCase):
 
     @mock.patch.object(ClassUtils, "copy_inner_classes")
     @mock.patch.object(ClassUtils, "clone_attribute")
-    def test_copy_group_attributes(self, mock_clone_attribute, mock_copy_inner_classes):
+    def test_copy_group_attributes(
+        self, mock_clone_attribute, mock_copy_inner_classes
+    ) -> None:
         mock_clone_attribute.side_effect = lambda x, y: x.clone()
         source = ClassFactory.elements(2)
         source.inner.append(ClassFactory.create())
         target = ClassFactory.elements(3)
-        attrs = list(target.attrs)
+        attrs = target.attrs.copy()
         attrs[1].name = "bar"
         attr = target.attrs[1]
 
@@ -135,7 +137,7 @@ class ClassUtilsTests(FactoryTestCase):
             ]
         )
 
-    def test_copy_extensions(self):
+    def test_copy_extensions(self) -> None:
         target = ClassFactory.create(extensions=ExtensionFactory.list(1))
         source = ClassFactory.create(extensions=ExtensionFactory.list(2))
         link_extension = ExtensionFactory.create()
@@ -147,7 +149,7 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertEqual(2, target.extensions[1].restrictions.max_occurs)
         self.assertEqual(2, target.extensions[2].restrictions.max_occurs)
 
-    def test_clone_attribute(self):
+    def test_clone_attribute(self) -> None:
         attr = AttrFactory.create(
             restrictions=Restrictions(length=1),
             types=[
@@ -164,7 +166,7 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertIsNot(attr, clone)
 
     @mock.patch.object(ClassUtils, "copy_inner_class")
-    def test_copy_inner_classes(self, mock_copy_inner_class):
+    def test_copy_inner_classes(self, mock_copy_inner_class) -> None:
         source = ClassFactory.create()
         target = ClassFactory.create()
         attr = AttrFactory.create(types=AttrTypeFactory.list(3))
@@ -173,23 +175,22 @@ class ClassUtilsTests(FactoryTestCase):
 
         mock_copy_inner_class.assert_has_calls(
             [
-                mock.call(source, target, attr, attr.types[0]),
-                mock.call(source, target, attr, attr.types[1]),
-                mock.call(source, target, attr, attr.types[2]),
+                mock.call(source, target, attr.types[0]),
+                mock.call(source, target, attr.types[1]),
+                mock.call(source, target, attr.types[2]),
             ]
         )
 
-    def test_copy_inner_class(self):
+    def test_copy_inner_class(self) -> None:
         source = ClassFactory.create()
         inner = ClassFactory.create(
             qname="a", module="b", package="c", status=Status.FLATTENED
         )
         target = ClassFactory.create()
-        attr = AttrFactory.create()
         attr_type = AttrTypeFactory.create(forward=True, qname=inner.qname)
 
         source.inner.append(inner)
-        ClassUtils.copy_inner_class(source, target, attr, attr_type)
+        ClassUtils.copy_inner_class(source, target, attr_type)
 
         self.assertEqual(1, len(target.inner))
         self.assertIsNot(inner, target.inner[0])
@@ -199,42 +200,25 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertIs(Status.RAW, target.inner[0].status)
         self.assertIs(Status.FLATTENED, inner.status)
 
-    def test_copy_inner_class_check_circular_reference(self):
+    def test_copy_inner_class_check_circular_reference(self) -> None:
         source = ClassFactory.create()
         target = ClassFactory.create()
-        attr = AttrFactory.create()
         attr_type = AttrTypeFactory.create(forward=True, qname=target.qname)
         source.inner.append(target)
 
-        ClassUtils.copy_inner_class(source, target, attr, attr_type)
+        ClassUtils.copy_inner_class(source, target, attr_type)
         self.assertTrue(attr_type.circular)
         self.assertEqual(0, len(target.inner))
 
-    def test_copy_inner_class_with_missing_inner(self):
+    def test_copy_inner_class_with_missing_inner(self) -> None:
         source = ClassFactory.create()
         target = ClassFactory.create()
-        attr = AttrFactory.create()
         attr_type = AttrTypeFactory.create(forward=True, qname=target.qname)
 
-        with self.assertRaises(CodeGenerationError):
-            ClassUtils.copy_inner_class(source, target, attr, attr_type)
+        with self.assertRaises(CodegenError):
+            ClassUtils.copy_inner_class(source, target, attr_type)
 
-    def test_find_inner(self):
-        obj = ClassFactory.create(qname="{a}parent")
-        first = ClassFactory.create(qname="{a}a")
-        second = ClassFactory.create(qname="{c}c")
-        third = ClassFactory.enumeration(2, qname="{d}d")
-        obj.inner.extend((first, second, third))
-
-        with self.assertRaises(CodeGenerationError) as cm:
-            self.assertIsNone(ClassUtils.find_inner(obj, "nope"))
-
-        self.assertEqual("Missing inner class {a}parent.nope", str(cm.exception))
-        self.assertEqual(first, ClassUtils.find_inner(obj, "{a}a"))
-        self.assertEqual(second, ClassUtils.find_inner(obj, "{c}c"))
-        self.assertEqual(third, ClassUtils.find_inner(obj, "{d}d"))
-
-    def test_flatten(self):
+    def test_flatten(self) -> None:
         target = ClassFactory.create(
             qname="{xsdata}root", attrs=AttrFactory.list(3), inner=ClassFactory.list(2)
         )
@@ -257,7 +241,7 @@ class ClassUtilsTests(FactoryTestCase):
             self.assertEqual(1, len(attr.types))
             self.assertFalse(attr.types[0].forward)
 
-    def test_reduce_classes(self):
+    def test_reduce_classes(self) -> None:
         class_a = ClassFactory.elements(3)
         class_a_clone = class_a.clone()
         class_a_clone.mixed = True
@@ -274,7 +258,7 @@ class ClassUtilsTests(FactoryTestCase):
         )
         self.assertEqual(["attr_E", "attr_F"], [x.name for x in result[1].attrs])
 
-    def test_reduce_attributes(self):
+    def test_reduce_attributes(self) -> None:
         restrictions = Restrictions(min_occurs=1, max_occurs=1)
         attr_a = AttrFactory.create(name="a", restrictions=restrictions.clone())
         attr_b = AttrFactory.create(name="b", restrictions=restrictions.clone())
@@ -293,7 +277,7 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertEqual(0, result[2].restrictions.min_occurs)
         self.assertEqual(0, result[3].restrictions.min_occurs)
 
-    def test_merge_attributes(self):
+    def test_merge_attributes(self) -> None:
         a = AttrFactory.native(DataType.INT, name="a")
         c = AttrFactory.native(DataType.FLOAT, name="c")
 
@@ -313,7 +297,47 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertEqual(4, c.restrictions.max_occurs)
         self.assertEqual(1, c.restrictions.sequence)
 
-    def test_rename_attribute_by_preference(self):
+    def test_rename_duplicate_attributes(self) -> None:
+        attrs = [
+            AttrFactory.create(name="a", tag=Tag.ELEMENT),
+            AttrFactory.create(name="a", tag=Tag.ATTRIBUTE),
+            AttrFactory.create(name="b", tag=Tag.ATTRIBUTE),
+            AttrFactory.create(name="c", tag=Tag.ATTRIBUTE),
+            AttrFactory.create(name="c", tag=Tag.ELEMENT),
+            AttrFactory.create(name="d", tag=Tag.ELEMENT),
+            AttrFactory.create(name="d", tag=Tag.ELEMENT),
+            AttrFactory.create(name="e", tag=Tag.ELEMENT, namespace="b"),
+            AttrFactory.create(name="e", tag=Tag.ELEMENT),
+            AttrFactory.create(name="f", tag=Tag.ELEMENT),
+            AttrFactory.create(name="f", tag=Tag.ELEMENT, namespace="a"),
+            AttrFactory.create(name="gA", tag=Tag.ENUMERATION),
+            AttrFactory.create(name="g[A]", tag=Tag.ENUMERATION),
+            AttrFactory.create(name="g_a", tag=Tag.ENUMERATION),
+            AttrFactory.create(name="g_a_1", tag=Tag.ENUMERATION),
+        ]
+        target = ClassFactory.create(attrs=attrs)
+
+        ClassUtils.rename_duplicate_attributes(target)
+        expected = [
+            "a",
+            "a_Attribute",
+            "b",
+            "c_Attribute",
+            "c",
+            "d_Element",
+            "d",
+            "b_e",
+            "e",
+            "f",
+            "a_f",
+            "gA",
+            "g[A]_2",
+            "g_a_3",
+            "g_a_1",
+        ]
+        self.assertEqual(expected, [x.name for x in attrs])
+
+    def test_rename_attribute_by_preference(self) -> None:
         one = AttrFactory.create(name="a", tag=Tag.ELEMENT)
         two = AttrFactory.create(name="a", tag=Tag.ATTRIBUTE)
 
@@ -339,7 +363,7 @@ class ClassUtilsTests(FactoryTestCase):
         self.assertEqual("a_Element", one.name)
         self.assertEqual("a", two.name)
 
-    def test_filter_types(self):
+    def test_filter_types(self) -> None:
         xs_string = AttrTypeFactory.native(DataType.STRING)
         xs_error = AttrTypeFactory.native(DataType.ERROR)
         xs_any = AttrTypeFactory.native(DataType.ANY_TYPE)
@@ -366,3 +390,28 @@ class ClassUtilsTests(FactoryTestCase):
         types = [xs_any]
         actual = ClassUtils.filter_types(types)
         self.assertEqual(1, len(actual))
+
+    def test_find_nested(self) -> None:
+        a = ClassFactory.create(qname="a")
+        b = ClassFactory.create(qname="b")
+        c = ClassFactory.create(qname="c")
+
+        a.inner.append(b)
+        b.inner.append(c)
+        c.parent = b
+        b.parent = a
+
+        self.assertEqual(a, ClassUtils.find_nested(a, "a"))
+        self.assertEqual(b, ClassUtils.find_nested(a, "b"))
+        self.assertEqual(b, ClassUtils.find_nested(c, "b"))
+        self.assertEqual(a, ClassUtils.find_nested(c, "a"))
+
+        a2 = ClassFactory.create(qname="a")
+        c.inner.append(a2)
+        a2.parent = c
+
+        # Breadth-first search
+        self.assertEqual(a2, ClassUtils.find_nested(c, "a"))
+
+        with self.assertRaises(CodegenError):
+            ClassUtils.find_nested(a, "nope")
