@@ -1,20 +1,16 @@
 from __future__ import annotations
+
 from dataclasses import dataclass, field
-from typing import Optional
+
 from tests.fixtures.annotations.units import unit
 
 __NAMESPACE__ = "http://domain.org/schema/model"
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Measurement:
-    value: Optional[float] = field(
-        default=None,
-        metadata={
-            "required": True,
-        },
-    )
-    unit: Optional[unit] = field(
+    value: float = field()
+    unit: None | unit = field(
         default=None,
         metadata={
             "type": "Attribute",
@@ -22,7 +18,7 @@ class Measurement:
     )
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Weight(Measurement):
     class Meta:
         namespace = "http://domain.org/schema/model"
