@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 from enum import Enum
 
 __NAMESPACE__ = "http://domain.org/schema/model/units"
@@ -7,5 +8,5 @@ __NAMESPACE__ = "http://domain.org/schema/model/units"
 class unit(Enum):
     M = "m"
     KG = "kg"
-    VALUE = "%"
+    PERCENT_SIGN = "%"
     NA = "NA"
