@@ -1,11 +1,13 @@
+from __future__ import annotations
+
 from dataclasses import dataclass, field
-from typing import List, Optional
+
 from xsdata.models.datatype import XmlDate
 
 __NAMESPACE__ = "urn:books"
 
 
-@dataclass
+@dataclass(kw_only=True)
 class BookForm:
     """
     Book Definition.
@@ -21,55 +23,43 @@ class BookForm:
         lang: Language ISO Code
     """
 
-    author: Optional[str] = field(
-        default=None,
+    author: str = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    title: Optional[str] = field(
-        default=None,
+    title: str = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    genre: Optional[str] = field(
-        default=None,
+    genre: str = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    price: Optional[float] = field(
-        default=None,
+    price: float = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    pub_date: Optional[XmlDate] = field(
-        default=None,
+    pub_date: XmlDate = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    review: Optional[str] = field(
-        default=None,
+    review: str = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    id: Optional[str] = field(
+    id: None | str = field(
         default=None,
         metadata={
             "type": "Attribute",
@@ -84,9 +74,9 @@ class BookForm:
     )
 
 
-@dataclass
+@dataclass(kw_only=True)
 class BooksForm:
-    book: List[BookForm] = field(
+    book: list[BookForm] = field(
         default_factory=list,
         metadata={
             "type": "Element",
@@ -95,7 +85,7 @@ class BooksForm:
     )
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Books(BooksForm):
     """
     Το βιβλίο.
