@@ -1,8 +1,9 @@
+from __future__ import annotations
+
 from dataclasses import dataclass, field
-from typing import List, Union
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Alpha:
     class Meta:
         name = "alpha"
@@ -16,7 +17,7 @@ class Alpha:
     )
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Bravo:
     class Meta:
         name = "bravo"
@@ -30,12 +31,12 @@ class Bravo:
     )
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Root:
     class Meta:
         name = "root"
 
-    alpha_or_bravo: List[Union[Alpha, Bravo]] = field(
+    alpha_or_bravo_or_charlie: list[Alpha | Bravo | list[str]] = field(
         default_factory=list,
         metadata={
             "type": "Elements",
@@ -48,6 +49,13 @@ class Root:
                     "name": "bravo",
                     "type": Bravo,
                 },
+                {
+                    "name": "charlie",
+                    "type": list[str],
+                    "namespace": "",
+                    "default_factory": list,
+                    "tokens": True,
+                },
             ),
         },
     )
