@@ -1,17 +1,18 @@
+from __future__ import annotations
+
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import Optional
 
 __NAMESPACE__ = "urn:docs"
 
 
-@dataclass
+@dataclass(kw_only=True)
 class DoubleQuotesDescription:
     class Meta:
         namespace = "urn:docs"
 
 
-@dataclass
+@dataclass(kw_only=True)
 class DoubleQuotesSummary:
     class Meta:
         namespace = "urn:docs"
@@ -32,51 +33,41 @@ class RootD(Enum):
     FALSE = "false"
 
 
-@dataclass
+@dataclass(kw_only=True)
 class Root:
     class Meta:
         namespace = "urn:docs"
 
-    a: Optional["Root.A"] = field(
-        default=None,
+    a: Root.A = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    b: Optional[RootB] = field(
-        default=None,
+    b: RootB = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    c: Optional[RootEnum] = field(
-        default=None,
+    c: RootEnum = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
-    d: Optional[RootD] = field(
-        default=None,
+    d: RootD = field(
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
-        },
+        }
     )
 
-    @dataclass
+    @dataclass(kw_only=True)
     class A:
-        sub_a: Optional[str] = field(
-            default=None,
+        sub_a: str = field(
             metadata={
                 "type": "Element",
                 "namespace": "",
-                "required": True,
-            },
+            }
         )
