@@ -14,19 +14,19 @@ class LxmlEventHandlerTests(TestCase):
     def setUp(self) -> None:
         self.parser = RecordParser(handler=LxmlEventHandler)
 
-    def test_parse(self):
+    def test_parse(self) -> None:
         path = fixtures_dir.joinpath("books/books.xml")
         self.assertEqual(books, self.parser.from_path(path, Books))
         self.assertEqual({"brk": "urn:books"}, self.parser.ns_map)
         self.assertEqual(events, self.parser.events)
 
-    def test_parse_with_default_ns(self):
+    def test_parse_with_default_ns(self) -> None:
         path = fixtures_dir.joinpath("books/books_default_ns.xml")
         self.assertEqual(books, self.parser.from_path(path, Books))
         self.assertEqual({None: "urn:books"}, self.parser.ns_map)
         self.assertEqual(events_default_ns, self.parser.events)
 
-    def test_parse_with_element_or_tree(self):
+    def test_parse_with_element_or_tree(self) -> None:
         path = fixtures_dir.joinpath("books/books.xml")
         tree = etree.parse(str(path))
 
@@ -37,7 +37,7 @@ class LxmlEventHandlerTests(TestCase):
         result = self.parser.parse(tree.find(".//book"), BookForm)
         self.assertEqual(books.book[0], result)
 
-    def test_parse_with_xinclude(self):
+    def test_parse_with_xinclude(self) -> None:
         path = fixtures_dir.joinpath("books/books-xinclude.xml")
         ns_map = {"brk": "urn:books", "xi": "http://www.w3.org/2001/XInclude"}
 
@@ -45,7 +45,7 @@ class LxmlEventHandlerTests(TestCase):
         self.assertEqual(books, self.parser.from_path(path, Books))
         self.assertEqual(ns_map, self.parser.ns_map)
 
-    def test_parse_with_xinclude_from_memory(self):
+    def test_parse_with_xinclude_from_memory(self) -> None:
         path = fixtures_dir.joinpath("books/books-xinclude.xml")
         ns_map = {"brk": "urn:books", "xi": "http://www.w3.org/2001/XInclude"}
 
@@ -54,14 +54,14 @@ class LxmlEventHandlerTests(TestCase):
         self.assertEqual(books, self.parser.from_bytes(path.read_bytes(), Books))
         self.assertEqual(ns_map, self.parser.ns_map)
 
-    def test_parse_context_with_unhandled_event(self):
+    def test_parse_context_with_unhandled_event(self) -> None:
         handler = LxmlEventHandler(clazz=Books, parser=self.parser)
 
         with self.assertRaises(XmlHandlerError) as cm:
-            handler.process_context([("reverse", "")])
+            handler.process_context([("reverse", "")], {})
 
         self.assertEqual("Unhandled event: `reverse`.", str(cm.exception))
 
-    def test_parse_with_xml_syntax_error(self):
+    def test_parse_with_xml_syntax_error(self) -> None:
         with self.assertRaises(ParserError):
             self.parser.from_string("<", Books)
