@@ -11,6 +11,7 @@ from tests.fixtures.models import (
     NillableType,
     Paragraph,
     SequentialType,
+    Span,
     TypeA,
     TypeB,
     TypeC,
@@ -47,7 +48,7 @@ class ElementNodeTests(FactoryTestCase):
             ns_map={},
         )
 
-    def test_bind(self):
+    def test_bind(self) -> None:
         node = ElementNode(
             position=0,
             meta=self.context.build(SequentialType),
@@ -61,17 +62,16 @@ class ElementNodeTests(FactoryTestCase):
         expected = SequentialType(a0="0", a1={"a": "b"}, x0=1, x1=[1], x2=[2, 3])
 
         self.assertTrue(node.bind("foo", "1", "tail", objects))
-        self.assertEqual("foo", objects[-1][0])
-        self.assertEqual(expected, objects[-1][1])
+        self.assertListEqual(objects, [("foo", expected), (None, "tail")])
 
-    def test_bind_nil_value(self):
+    def test_bind_nil_value(self) -> None:
         self.node.xsi_nil = True
         objects = []
 
         self.assertTrue(self.node.bind("foo", None, None, objects))
         self.assertEqual(("foo", None), objects[-1])
 
-    def test_bind_nillable_type(self):
+    def test_bind_nillable_type(self) -> None:
         self.node.meta = self.context.build(NillableType)
         self.node.xsi_nil = True
 
@@ -79,14 +79,14 @@ class ElementNodeTests(FactoryTestCase):
         self.assertTrue(self.node.bind("foo", None, None, objects))
         self.assertEqual(("foo", NillableType(None)), objects[-1])
 
-    def test_bind_fixed_value(self):
+    def test_bind_fixed_value(self) -> None:
         self.node.meta = self.context.build(FixedType)
 
         objects = []
-        self.assertTrue(self.node.bind("foo", "not the fixed value", None, objects))
+        self.assertTrue(self.node.bind("foo", "abc", None, objects))
         self.assertEqual(("foo", FixedType()), objects[-1])
 
-    def test_bind_with_derived_element(self):
+    def test_bind_with_derived_element(self) -> None:
         self.node.meta = self.context.build(TypeA)
         self.node.derived_factory = DerivedElement
 
@@ -95,7 +95,7 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual("foo", objects[-1][0])
         self.assertEqual(DerivedElement("foo", TypeA(2)), objects[-1][1])
 
-    def test_bind_with_wildcard_var(self):
+    def test_bind_with_wildcard_var(self) -> None:
         self.node.meta = self.context.build(ExtendedType)
         self.node.attrs = {"a": "b"}
         self.node.ns_map = {"ns0": "xsdata"}
@@ -115,7 +115,7 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual("foo", objects[-1][0])
         self.assertEqual(expected, objects[-1][1])
 
-    def test_bind_with_mixed_flag_true(self):
+    def test_bind_with_mixed_flag_true(self) -> None:
         self.node.meta = self.context.build(TypeB)
         self.node.attrs = {"a": "b"}
         self.node.ns_map = {"ns0": "xsdata"}
@@ -132,19 +132,18 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(None, objects[-1][0])
         self.assertEqual(" tail ", objects[-1][1])
 
-    def test_bind_with_mixed_content_var(self):
+    def test_bind_with_mixed_content_var(self) -> None:
         self.node.meta = self.context.build(Paragraph)
         self.node.attrs = {"a": "b"}
         self.node.ns_map = {"ns0": "xsdata"}
 
         objects = [("a", 1)]
-        expected = Paragraph(content=["text", AnyElement(qname="a", text="1"), "tail"])
+        expected = Paragraph(content=["text", AnyElement(qname="a", text="1")])
 
         self.assertTrue(self.node.bind("foo", "text", "tail", objects))
-        self.assertEqual("foo", objects[-1][0])
-        self.assertEqual(expected, objects[-1][1])
+        self.assertListEqual([("foo", expected), (None, "tail")], objects)
 
-    def test_bind_wild_text(self):
+    def test_bind_wild_text(self) -> None:
         self.node.meta = self.context.build(ExtendedType)
         var = self.node.meta.wildcards[0]
 
@@ -170,19 +169,19 @@ class ElementNodeTests(FactoryTestCase):
 
         params = {}
         self.node.bind_wild_text(params, var, "txt", "tail")
-        self.assertEqual({"wildcard": ["txt", "tail"]}, params)
+        self.assertEqual({"wildcard": ["txt"]}, params)
 
         self.node.bind_wild_text(params, var, None, "tail")
-        self.assertEqual({"wildcard": [None, "txt", "tail", "tail"]}, params)
+        self.assertEqual({"wildcard": [None, "txt"]}, params)
 
         self.node.bind_wild_text(params, var, "first", None)
-        self.assertEqual({"wildcard": ["first", None, "txt", "tail", "tail"]}, params)
+        self.assertEqual({"wildcard": ["first", None, "txt"]}, params)
 
-    def test_bind_attrs(self):
+    def test_bind_attrs(self) -> None:
         self.node.meta = self.context.build(AttrsType)
         self.node.attrs = {
             "index": "0",
-            "fixed": "will be ignored",
+            "fixed": "ignored",
             "{what}ever": "qname",
             "extended": "attr",
         }
@@ -193,12 +192,12 @@ class ElementNodeTests(FactoryTestCase):
         expected = {"attrs": {"extended": "attr", "{what}ever": "qname"}, "index": 0}
         self.assertEqual(expected, params)
 
-    def test_bind_attrs_with_fail_on_unknown_attributes(self):
+    def test_bind_attrs_with_fail_on_unknown_attributes(self) -> None:
         self.node.meta = self.context.build(AttrsType)
         self.node.config.fail_on_unknown_attributes = True
         self.node.attrs = {
             "index": "0",
-            "fixed": "will be ignored",
+            "fixed": "ignored",
             "{what}ever": "qname",
             "extended": "attr",
         }
@@ -209,7 +208,7 @@ class ElementNodeTests(FactoryTestCase):
         expected = {"attrs": {"extended": "attr", "{what}ever": "qname"}, "index": 0}
         self.assertEqual(expected, params)
 
-    def test_bind_with_fail_on_unknown_attributes(self):
+    def test_bind_with_fail_on_unknown_attributes(self) -> None:
         self.node.meta = self.context.build(ExtendedType)
         self.node.config.fail_on_unknown_attributes = True
         self.node.attrs = {"a": "b"}
@@ -220,7 +219,7 @@ class ElementNodeTests(FactoryTestCase):
 
         self.assertEqual("Unknown attribute ExtendedType:a", str(cm.exception))
 
-    def test_bind_with_fail_on_unknown_attributes_ignores_xsi_attributes(self):
+    def test_bind_with_fail_on_unknown_attributes_ignores_xsi_attributes(self) -> None:
         self.node.meta = self.context.build(ExtendedType)
         self.node.config.fail_on_unknown_attributes = True
         self.node.attrs = {QNames.XSI_TYPE: "b"}
@@ -230,7 +229,7 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(1, len(objects))
 
     @mock.patch("xsdata.formats.dataclass.parsers.nodes.element.logger.warning")
-    def test_bind_objects(self, mock_warning):
+    def test_bind_objects(self, mock_warning) -> None:
         self.node.meta = self.context.build(TypeC)
 
         objects = [("x", 1), ("x", 2), ("z", 3.0), ("fixed", "bar")]
@@ -241,7 +240,7 @@ class ElementNodeTests(FactoryTestCase):
 
         mock_warning.assert_called_once_with("Unassigned parsed object %s", "x")
 
-    def test_bind_wild_var(self):
+    def test_bind_wild_var(self) -> None:
         self.node.meta = self.context.build(ExtendedType)
         x = make_dataclass("x", [("value", int)])
 
@@ -259,7 +258,7 @@ class ElementNodeTests(FactoryTestCase):
         }
         self.assertEqual(expected, params)
 
-    def test_bind_wild_list_var(self):
+    def test_bind_wild_list_var(self) -> None:
         self.node.meta = self.context.build(ExtendedListType)
 
         params = {}
@@ -274,32 +273,96 @@ class ElementNodeTests(FactoryTestCase):
         }
         self.assertEqual(expected, params)
 
-    def test_prepare_generic_value(self):
-        var = XmlVarFactory.create(
-            index=2,
-            xml_type=XmlType.WILDCARD,
-            qname="a",
-            types=(object,),
-            elements={"known": XmlVarFactory.create()},
-        )
-
-        actual = self.node.prepare_generic_value(None, 1, var)
+    def test_prepare_generic_value(self) -> None:
+        actual = self.node.prepare_generic_value(None, 1)
         self.assertEqual(1, actual)
 
-        actual = self.node.prepare_generic_value("a", 1, var)
+        actual = self.node.prepare_generic_value("a", 1)
         expected = AnyElement(qname="a", text="1")
         self.assertEqual(expected, actual)
 
-        actual = self.node.prepare_generic_value("a", "foo", var)
+        actual = self.node.prepare_generic_value("a", "foo")
         expected = AnyElement(qname="a", text="foo")
         self.assertEqual(expected, actual)
 
         fixture = make_dataclass("Fixture", [("content", str)])
-        actual = self.node.prepare_generic_value("a", fixture("foo"), var)
+        actual = self.node.prepare_generic_value("a", fixture("foo"))
         self.assertEqual(fixture("foo"), actual)
 
-    def test_child(self):
-        var = XmlVarFactory.create(xml_type=XmlType.ELEMENT, qname="a", types=(TypeC,))
+    def test_bind_tail_of_non_wildcard_attaches_to_wildcard_parent(self) -> None:
+        self.node.meta = self.context.build(Paragraph)
+        expected_inner_node = Span(content="This is a note inside the paragraph.")
+        expected_first_text = "This is before the note."
+        expected_tail = "This is after the note."
+        expected_outer_node = Paragraph(
+            content=[expected_first_text, expected_inner_node, expected_tail]
+        )
+        objects = []
+
+        inner_node = ElementNode(
+            position=0,
+            meta=self.context.build(Span),
+            context=self.context,
+            config=ParserConfig(),
+            attrs={},
+            ns_map={},
+        )
+
+        self.assertTrue(
+            inner_node.bind(
+                qname="span",
+                text=expected_inner_node.content,
+                tail=expected_tail,
+                objects=objects,
+            )
+        )
+
+        self.assertListEqual(
+            objects, [("span", expected_inner_node), (None, expected_tail)]
+        )
+
+        outer_node = ElementNode(
+            position=0,
+            meta=self.context.build(Paragraph),
+            context=self.context,
+            config=ParserConfig(),
+            attrs={},
+            ns_map={},
+        )
+        self.assertTrue(
+            outer_node.bind(
+                qname="p",
+                text=expected_first_text,
+                tail=None,
+                objects=objects,
+            )
+        )
+
+        self.assertListEqual(objects, [("p", expected_outer_node)])
+
+    def test_bind_tail_of_wildcard_attaches_to_wildcard_parent(self) -> None:
+        self.node.meta = self.context.build(Paragraph)
+        subparagraph = Paragraph(
+            content=["This is a subparagraph inside the paragraph."],
+        )
+        objects = [
+            (None, "This is before the subparagraph."),
+            ("p", subparagraph),
+            (None, "This is after the subparagraph."),
+        ]
+        self.assertTrue(self.node.bind("foo", None, None, objects))
+        result = objects[-1][1]
+        expected = Paragraph(
+            content=[
+                "This is before the subparagraph.",
+                subparagraph,
+                "This is after the subparagraph.",
+            ]
+        )
+        self.assertEqual(result, expected)
+
+    def test_child(self) -> None:
+        var = XmlVarFactory.create(xml_type=XmlType.ELEMENT, name="a", types=(TypeC,))
         attrs = {"a": "b"}
         ns_map = {"ns0": "xsdata"}
         position = 1
@@ -311,12 +374,12 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(ns_map, actual.ns_map)
         self.assertEqual(position, actual.position)
 
-    def test_child_with_unique_element(self):
+    def test_child_with_unique_element(self) -> None:
         single = XmlVarFactory.create(
-            index=1, xml_type=XmlType.ELEMENT, qname="cc", types=(TypeC,)
+            index=1, xml_type=XmlType.ELEMENT, name="cc", types=(TypeC,)
         )
         wildcard = XmlVarFactory.create(
-            index=2, xml_type=XmlType.WILDCARD, qname="cc", types=(object,)
+            index=2, xml_type=XmlType.WILDCARD, name="cc", types=(object,)
         )
         self.meta.elements[single.qname] = [single]
         self.meta.wildcards.append(wildcard)
@@ -334,10 +397,10 @@ class ElementNodeTests(FactoryTestCase):
         self.assertNotIn(wildcard.index, self.node.assigned)
 
     @mock.patch.object(ElementNode, "build_node")
-    def test_child_when_failed_to_build_next_node(self, mock_build_node):
+    def test_child_when_failed_to_build_next_node(self, mock_build_node) -> None:
         mock_build_node.return_value = None
-        element = XmlVarFactory.create(xml_type=XmlType.ELEMENT, qname="a")
-        wildcard = XmlVarFactory.create(xml_type=XmlType.WILDCARD, qname="a")
+        element = XmlVarFactory.create(xml_type=XmlType.ELEMENT, name="a")
+        wildcard = XmlVarFactory.create(xml_type=XmlType.WILDCARD, name="a")
 
         self.meta.elements[element.qname] = [element]
         self.meta.wildcards.append(wildcard)
@@ -352,11 +415,10 @@ class ElementNodeTests(FactoryTestCase):
         actual = self.node.child("foobar", {}, {}, 0)
         self.assertIsInstance(actual, SkipNode)
 
-    def test_build_node_with_dataclass_union_var(self):
+    def test_build_node_with_dataclass_union_var(self) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
             types=(TypeC, TypeB),
         )
         attrs = {"a": "b"}
@@ -373,13 +435,11 @@ class ElementNodeTests(FactoryTestCase):
 
     @mock.patch.object(ParserUtils, "xsi_type", return_value="foo")
     @mock.patch.object(XmlContext, "fetch")
-    def test_build_node_with_dataclass_var(self, mock_ctx_fetch, mock_xsi_type):
+    def test_build_node_with_dataclass_var(self, mock_ctx_fetch, mock_xsi_type) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
             types=(TypeC,),
-            derived=True,
         )
         xsi_type = "foo"
         namespace = self.meta.namespace
@@ -392,7 +452,6 @@ class ElementNodeTests(FactoryTestCase):
 
         self.assertIsInstance(actual, ElementNode)
         self.assertEqual(10, actual.position)
-        self.assertEqual(DerivedElement, actual.derived_factory)
         self.assertIs(mock_ctx_fetch.return_value, actual.meta)
 
         mock_xsi_type.assert_called_once_with(attrs, ns_map)
@@ -402,11 +461,10 @@ class ElementNodeTests(FactoryTestCase):
     @mock.patch.object(XmlContext, "fetch")
     def test_build_node_with_dataclass_var_and_mismatch_xsi_type(
         self, mock_ctx_fetch, mock_xsi_type
-    ):
+    ) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
             types=(TypeB,),
             derived=False,
         )
@@ -428,8 +486,10 @@ class ElementNodeTests(FactoryTestCase):
         mock_ctx_fetch.assert_called_once_with(var.clazz, namespace, xsi_type)
 
     @mock.patch.object(XmlContext, "fetch")
-    def test_build_node_with_dataclass_var_validates_nillable(self, mock_ctx_fetch):
-        var = XmlVarFactory.create(xml_type=XmlType.ELEMENT, qname="a", types=(TypeC,))
+    def test_build_node_with_dataclass_var_validates_nillable(
+        self, mock_ctx_fetch
+    ) -> None:
+        var = XmlVarFactory.create(xml_type=XmlType.ELEMENT, name="a", types=(TypeC,))
         ns_map = {}
         nillable_meta = copy.deepcopy(self.meta)
         nillable_meta.nillable = True
@@ -444,11 +504,10 @@ class ElementNodeTests(FactoryTestCase):
         attrs = {QNames.XSI_NIL: "false"}
         self.assertIsNone(self.node.build_node(var.qname, var, attrs, ns_map, 10))
 
-    def test_build_node_with_any_type_var_with_matching_xsi_type(self):
+    def test_build_node_with_any_type_var_with_matching_xsi_type(self) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
             types=(object,),
             any_type=True,
         )
@@ -463,11 +522,10 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(ns_map, actual.ns_map)
         self.assertFalse(actual.mixed)
 
-    def test_build_node_with_any_type_var_with_datatype(self):
+    def test_build_node_with_any_type_var_with_datatype(self) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
             types=(object,),
             any_type=True,
         )
@@ -480,11 +538,11 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(DataType.HEX_BINARY, actual.datatype)
         self.assertIsNone(actual.derived_factory)
 
-    def test_build_node_with_any_type_var_with_no_matching_xsi_type(self):
+    def test_build_node_with_any_type_var_with_no_matching_xsi_type(self) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="aaa",
+            local_name="aaa",
             types=(object,),
             any_type=True,
         )
@@ -497,11 +555,11 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(attrs, actual.attrs)
         self.assertEqual({}, actual.ns_map)
 
-    def test_build_node_with_any_type_var_with_no_xsi_type(self):
+    def test_build_node_with_any_type_var_with_no_xsi_type(self) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="aaaa",
+            local_name="aaaa",
             types=(object,),
             any_type=True,
         )
@@ -514,11 +572,13 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(attrs, actual.attrs)
         self.assertEqual({}, actual.ns_map)
 
-    def test_build_node_with_any_type_var_with_no_xsi_type_and_type_exists(self):
+    def test_build_node_with_any_type_var_with_no_xsi_type_and_type_exists(
+        self,
+    ) -> None:
         var = XmlVarFactory.create(
             xml_type=XmlType.ELEMENT,
             name="a",
-            qname="a",
+            local_name="a",
             types=(object,),
             any_type=True,
         )
@@ -533,8 +593,8 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual({}, actual.ns_map)
         self.assertFalse(actual.mixed)
 
-    def test_build_node_with_wildcard_var(self):
-        var = XmlVarFactory.create(xml_type=XmlType.WILDCARD, qname="aaaaa")
+    def test_build_node_with_wildcard_var(self) -> None:
+        var = XmlVarFactory.create(xml_type=XmlType.WILDCARD, local_name="aaaaa")
         var.process_contents = "skip"
 
         actual = self.node.build_node(var.qname, var, {}, {}, 10)
@@ -543,9 +603,9 @@ class ElementNodeTests(FactoryTestCase):
         self.assertEqual(10, actual.position)
         self.assertEqual(var, actual.var)
 
-    def test_build_node_with_primitive_var(self):
+    def test_build_node_with_primitive_var(self) -> None:
         var = XmlVarFactory.create(
-            xml_type=XmlType.TEXT, qname="a", types=(int,), default=100
+            xml_type=XmlType.TEXT, name="a", types=(int,), default=100
         )
         attrs = {"a": "b"}
         ns_map = {"ns0": "xsdata"}
@@ -553,5 +613,5 @@ class ElementNodeTests(FactoryTestCase):
 
         self.assertIsInstance(actual, PrimitiveNode)
         self.assertEqual(ns_map, actual.ns_map)
+        self.assertEqual(self.meta, actual.meta)
         self.assertEqual(var, actual.var)
-        self.assertEqual(self.node.meta.mixed_content, actual.mixed)
