@@ -1,5 +1,4 @@
 from dataclasses import dataclass, field
-from typing import List
 from unittest import TestCase
 
 from xsdata.formats.dataclass.parsers import XmlParser
@@ -9,10 +8,10 @@ class WrapperTests(TestCase):
     def setUp(self) -> None:
         self.parser = XmlParser()
 
-    def test_namespace(self):
+    def test_namespace(self) -> None:
         @dataclass
         class NamespaceWrapper:
-            items: List[str] = field(
+            items: list[str] = field(
                 metadata={
                     "wrapper": "Items",
                     "type": "Element",
@@ -29,10 +28,10 @@ class WrapperTests(TestCase):
         self.assertEqual(obj.items[0], "a")
         self.assertEqual(obj.items[1], "b")
 
-    def test_primitive(self):
+    def test_primitive(self) -> None:
         @dataclass
         class PrimitiveWrapper:
-            primitive_list: List[str] = field(
+            primitive_list: list[str] = field(
                 metadata={
                     "wrapper": "PrimitiveList",
                     "type": "Element",
@@ -48,14 +47,14 @@ class WrapperTests(TestCase):
         self.assertEqual(obj.primitive_list[0], "Value 1")
         self.assertEqual(obj.primitive_list[1], "Value 2")
 
-    def test_element(self):
+    def test_element(self) -> None:
         @dataclass
         class ElementObject:
             content: str = field(metadata={"type": "Element"})
 
         @dataclass
         class ElementWrapper:
-            elements: List[ElementObject] = field(
+            elements: list[ElementObject] = field(
                 metadata={"wrapper": "Elements", "type": "Element", "name": "Object"}
             )
 
