@@ -1,10 +1,9 @@
 import sys
-import warnings
+import unittest
 from datetime import date, datetime, time
 from decimal import Decimal
 from enum import Enum
 from typing import Any
-from unittest import TestCase
 from xml.etree.ElementTree import QName
 
 import pytest
@@ -16,19 +15,17 @@ from xsdata.models.datatype import XmlDuration, XmlPeriod
 from xsdata.models.enums import UseType
 
 
-class ConverterFactoryTests(TestCase):
-    def test_deserialize(self):
-        with warnings.catch_warnings(record=True) as w:
-            self.assertEqual("a", converter.deserialize("a", [int]))
+class ConverterFactoryTests(unittest.TestCase):
+    def test_deserialize(self) -> None:
+        with self.assertRaises(ConverterError) as cm:
+            converter.deserialize("a", [int])
 
-        self.assertEqual(
-            "Failed to convert value `a` to one of [<class 'int'>]", str(w[-1].message)
-        )
+        self.assertEqual("`a` is not a valid `int`", str(cm.exception))
 
         self.assertFalse(converter.deserialize("false", [int, bool]))
         self.assertEqual(1, converter.deserialize("1", [int, bool]))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual(None, converter.serialize(None))
         self.assertEqual("1", converter.serialize(1))
         self.assertEqual("1 2 3", converter.serialize([1, "2", 3]))
@@ -40,7 +37,7 @@ class ConverterFactoryTests(TestCase):
         self.assertEqual("0.0000000877683", converter.serialize(Decimal("8.77683E-8")))
         self.assertEqual("8.77683E-08", converter.serialize(float("8.77683E-8")))
 
-    def test_test(self):
+    def test_test(self) -> None:
         self.assertTrue(converter.test("1", [int]))
         self.assertTrue(converter.test("1", [float]))
         self.assertFalse(converter.test("1", [float], strict=True))
@@ -53,23 +50,34 @@ class ConverterFactoryTests(TestCase):
 
         self.assertTrue(converter.test("0", [float]))
         self.assertFalse(converter.test("0", [float], strict=True))
+
+        self.assertTrue(converter.test("INF", [float], strict=True))
+        self.assertTrue(converter.test("inf", [float], strict=True))
+        self.assertTrue(converter.test("+INF", [float], strict=True))
+        self.assertTrue(converter.test("+inf", [float], strict=True))
+        self.assertTrue(converter.test("-INF", [float], strict=True))
+        self.assertTrue(converter.test("-inf", [float], strict=True))
+        self.assertTrue(converter.test("NAN", [float], strict=True))
+        self.assertTrue(converter.test("NaN", [float], strict=True))
+        self.assertTrue(converter.test("nan", [float], strict=True))
+        self.assertTrue(converter.test("-NAN", [float], strict=True))
+
         self.assertTrue(converter.test(".0", [float]))
         self.assertFalse(converter.test(".0", [float], strict=True))
         self.assertTrue(converter.test("1.0", [float]))
 
-    def test_unknown_converter(self):
+    def test_unknown_converter(self) -> None:
         class A:
             pass
 
-        class B(A):
-            pass
+        with self.assertRaises(ConverterError) as cm:
+            converter.serialize(A())
 
-        with warnings.catch_warnings(record=True) as w:
-            converter.serialize(B())
+        self.assertEqual(
+            f"No converter registered for `{A.__qualname__}`", str(cm.exception)
+        )
 
-        self.assertEqual(f"No converter registered for `{B}`", str(w[-1].message))
-
-    def test_register_converter(self):
+    def test_register_converter(self) -> None:
         class MinusOneInt(int):
             pass
 
@@ -88,7 +96,7 @@ class ConverterFactoryTests(TestCase):
         self.assertEqual("3", converter.serialize(MinusOneInt("3")))
         converter.unregister_converter(MinusOneInt)
 
-    def test_register_converter_with_lambda(self):
+    def test_register_converter_with_lambda(self) -> None:
         class MinusOneInt(int):
             pass
 
@@ -98,39 +106,39 @@ class ConverterFactoryTests(TestCase):
         converter.unregister_converter(MinusOneInt)
 
 
-class StrConverterTests(TestCase):
-    def setUp(self):
+class StrConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(str)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         self.assertEqual("a", self.converter.deserialize("a"))
         self.assertEqual("1", self.converter.deserialize(1))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual("a", self.converter.serialize("a"))
         self.assertEqual("1", self.converter.serialize(1))
 
 
-class StringConverterTests(TestCase):
-    def setUp(self):
+class StringConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(str)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         string = "foo"
         self.assertIs(string, self.converter.deserialize(string))
         self.assertEqual("1", self.converter.deserialize(1))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         string = "foo"
         self.assertIs(string, self.converter.serialize(string))
         self.assertEqual("1", self.converter.serialize(1))
 
 
-class BoolConverterTests(TestCase):
-    def setUp(self):
+class BoolConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(bool)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         for invalid in ("True", "False", 1, 0):
             with self.assertRaises(ConverterError):
                 self.converter.deserialize(invalid)
@@ -142,16 +150,16 @@ class BoolConverterTests(TestCase):
         self.assertTrue(self.converter.deserialize(True))
         self.assertFalse(self.converter.deserialize(False))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual("true", self.converter.serialize(True))
         self.assertEqual("false", self.converter.serialize(False))
 
 
-class IntConverterTests(TestCase):
-    def setUp(self):
+class IntConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(int)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.deserialize("a")
 
@@ -159,22 +167,22 @@ class IntConverterTests(TestCase):
         self.assertEqual(2, self.converter.deserialize("+2"))
         self.assertEqual(-2, self.converter.deserialize("-2"))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual("2", self.converter.serialize(2))
 
 
-class FloatConverterTests(TestCase):
-    def setUp(self):
+class FloatConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(float)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.deserialize("a")
 
         self.assertEqual(2.0, self.converter.deserialize("2"))
         self.assertEqual(2.1, self.converter.deserialize("2.1"))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual("2.1", self.converter.serialize(2.1))
         self.assertEqual("INF", self.converter.serialize(float("inf")))
         self.assertEqual("INF", self.converter.serialize(float("+inf")))
@@ -183,14 +191,14 @@ class FloatConverterTests(TestCase):
         self.assertEqual("8.77683E-08", self.converter.serialize(float("8.77683E-8")))
 
 
-class BytesConverterTests(TestCase):
-    def setUp(self):
+class BytesConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(bytes)
 
-    def test_serialize_with_base16_format(self):
+    def test_serialize_with_base16_format(self) -> None:
         inputs = [
-            ("312d322d33", "312D322D33"),
-            ("312D322D33", "312D322D33"),
+            ("312d\n322d33", "312D322D33"),
+            ("312D \t322D33", "312D322D33"),
         ]
 
         for actual, expected in inputs:
@@ -201,7 +209,7 @@ class BytesConverterTests(TestCase):
             self.assertEqual(b"1-2-3", obj)
             self.assertEqual(expected, output)
 
-    def test_serialize_with_base64_format(self):
+    def test_serialize_with_base64_format(self) -> None:
         obj = self.converter.deserialize("MS0yLTM=", format="base64")
         output = self.converter.serialize(obj, format="base64")
 
@@ -209,7 +217,7 @@ class BytesConverterTests(TestCase):
         self.assertEqual(b"1-2-3", obj)
         self.assertEqual("MS0yLTM=", output)
 
-    def test_serialize_raises_exception(self):
+    def test_serialize_raises_exception(self) -> None:
         with self.assertRaises(ConverterError) as cm:
             self.converter.deserialize(1, format="foo")
 
@@ -221,7 +229,7 @@ class BytesConverterTests(TestCase):
         with self.assertRaises(ConverterError):
             self.converter.deserialize("AA~AA", format="base64")
 
-    def test_unknown_formats(self):
+    def test_unknown_formats(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.serialize("foo")
 
@@ -237,17 +245,17 @@ class BytesConverterTests(TestCase):
             self.converter.deserialize("foo", format="foo")
 
 
-class DecimalConverterTests(TestCase):
-    def setUp(self):
+class DecimalConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(Decimal)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.deserialize("a")
 
         self.assertEqual(Decimal(1), self.converter.deserialize("1"))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual("2.1", self.converter.serialize(Decimal("2.1")))
         self.assertEqual("INF", self.converter.serialize(Decimal("inf")))
         self.assertEqual("INF", self.converter.serialize(Decimal("+inf")))
@@ -257,11 +265,11 @@ class DecimalConverterTests(TestCase):
         )
 
 
-class DateTimeConverterTests(TestCase):
-    def setUp(self):
+class DateTimeConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(datetime)
 
-    def test_converter(self):
+    def test_converter(self) -> None:
         original = "21 June 2018 15:40"
         fmt = "%d %B %Y %H:%M"
         obj = self.converter.deserialize(original, format=fmt)
@@ -269,14 +277,14 @@ class DateTimeConverterTests(TestCase):
         self.assertEqual(datetime(2018, 6, 21, 15, 40), obj)
         self.assertEqual(original, self.converter.serialize(obj, format=fmt))
 
-    def test_serialize_raises_exception(self):
+    def test_serialize_raises_exception(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.serialize(datetime(2018, 6, 21, 15, 40))
 
         with self.assertRaises(ConverterError):
             self.converter.serialize(1, format="")
 
-    def test_deserialize_raises_exception(self):
+    def test_deserialize_raises_exception(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.deserialize("21 June 2018 15:40", format="%Y")
 
@@ -290,11 +298,11 @@ class DateTimeConverterTests(TestCase):
             self.converter.deserialize("21 June 2018 15:40", format="")
 
 
-class DateConverterTests(TestCase):
-    def setUp(self):
+class DateConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(date)
 
-    def test_converter(self):
+    def test_converter(self) -> None:
         original = "21 June 2018"
         fmt = "%d %B %Y"
         obj = self.converter.deserialize(original, format=fmt)
@@ -303,11 +311,11 @@ class DateConverterTests(TestCase):
         self.assertEqual(original, self.converter.serialize(obj, format=fmt))
 
 
-class TimeConverterTests(TestCase):
-    def setUp(self):
+class TimeConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(time)
 
-    def test_converter(self):
+    def test_converter(self) -> None:
         original = "1255"
         fmt = "%H%M"
         obj = self.converter.deserialize(original, format=fmt)
@@ -316,11 +324,11 @@ class TimeConverterTests(TestCase):
         self.assertEqual(original, self.converter.serialize(obj, format=fmt))
 
 
-class QNameConverterTests(TestCase):
-    def setUp(self):
+class QNameConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(QName)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         convert = self.converter.deserialize
 
         invalid = ["a:b", "", " ", "{a}1b", "{a} b", "{|}b", "a a"]
@@ -333,7 +341,7 @@ class QNameConverterTests(TestCase):
         self.assertEqual(QName("a"), convert("a", ns_map={}))
         self.assertEqual(QName("aa", "b"), convert("a:b", ns_map={"a": "aa"}))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         ns_map = {"c_prefix": "c"}
         convert = self.converter.serialize
 
@@ -357,15 +365,15 @@ class EnumA(Enum):
     J = (Telephone(1, 2, 3), Telephone(4, 5, 6))
 
 
-class EnumConverterTests(TestCase):
-    def setUp(self):
+class EnumConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(Enum)
 
     @pytest.mark.skipif(
         sys.version_info == (3, 11, 1, "final", 0),
         reason="https://github.com/python/cpython/issues/100098",
     )
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         convert = self.converter.deserialize
         self.assertEqual(EnumA.C, convert("2.1", data_type=EnumA))
         self.assertEqual(EnumA.C, convert(2.1, data_type=EnumA))
@@ -384,54 +392,54 @@ class EnumConverterTests(TestCase):
         with self.assertRaises(ConverterError):
             convert("nope", data_type=EnumA)
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         ns_map = {}
         self.assertEqual("ns0:b", self.converter.serialize(EnumA.A, ns_map=ns_map))
         self.assertEqual("INF", self.converter.serialize(EnumA.B))
         self.assertEqual("2.1", self.converter.serialize(EnumA.C))
 
 
-class ProxyConverterTests(TestCase):
-    def setUp(self):
+class ProxyConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = ProxyConverter(lambda x: int(x))
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         with self.assertRaises(ConverterError):
             self.converter.deserialize("a")
 
         self.assertEqual(1, self.converter.deserialize("1"))
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         self.assertEqual("1", self.converter.serialize(1))
 
 
-class XmlDurationConverterTests(TestCase):
-    def setUp(self):
+class XmlDurationConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(XmlDuration)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         self.assertIsInstance(self.converter.deserialize("P20M"), XmlDuration)
 
         with self.assertRaises(ConverterError):
             self.converter.deserialize("P-20M")
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         actual = self.converter.serialize(XmlDuration("PT3S"))
         self.assertEqual("PT3S", actual)
         self.assertNotIsInstance(actual, XmlDuration)
 
 
-class XmlPeriodConverterTests(TestCase):
-    def setUp(self):
+class XmlPeriodConverterTests(unittest.TestCase):
+    def setUp(self) -> None:
         self.converter = converter.type_converter(XmlPeriod)
 
-    def test_deserialize(self):
+    def test_deserialize(self) -> None:
         self.assertIsInstance(self.converter.deserialize("---15Z"), XmlPeriod)
 
         with self.assertRaises(ConverterError):
             self.converter.deserialize("---1Z")
 
-    def test_serialize(self):
+    def test_serialize(self) -> None:
         actual = self.converter.serialize(XmlPeriod("---15Z"))
         self.assertEqual("---15Z", actual)
         self.assertNotIsInstance(actual, XmlPeriod)
