@@ -12,12 +12,12 @@ from xsdata.utils.testing import load_class
 os.chdir(root)
 
 
-def test_annotations():
+def test_annotations() -> None:
     filepath = fixtures_dir.joinpath("annotations")
     schema = filepath.joinpath("model.xsd")
     runner = CliRunner()
     result = runner.invoke(
-        cli, [str(schema), f"--config={str(filepath.joinpath('xsdata.xml'))}"]
+        cli, ["generate", str(schema), f"--config={filepath.joinpath('xsdata.xml')!s}"]
     )
 
     if result.exception:
