@@ -12,11 +12,11 @@ from xsdata.utils.testing import load_class
 os.chdir(root)
 
 
-def test_xml_documents():
+def test_xml_documents() -> None:
     filepath = fixtures_dir.joinpath("artists")
     package = "tests.fixtures.artists"
     runner = CliRunner()
-    result = runner.invoke(cli, [str(filepath), "--package", package])
+    result = runner.invoke(cli, ["generate", str(filepath), "--package", package])
 
     if result.exception:
         raise result.exception
@@ -25,7 +25,7 @@ def test_xml_documents():
 
     parser = XmlParser()
     serializer = XmlSerializer(writer=XmlEventWriter)
-    serializer.config.pretty_print = True
+    serializer.config.indent = "  "
     serializer.config.xml_declaration = False
     ns_map = {None: "http://musicbrainz.org/ns/mmd-2.0#"}
 
