@@ -16,11 +16,11 @@ os.chdir(root)
 
 
 class CalculatorServiceTests(TestCase):
-    def test_wsdl_codegen(self):
+    def test_wsdl_codegen(self) -> None:
         schema = fixtures_dir.joinpath("calculator/services.wsdl")
         package = "tests.fixtures.calculator"
         runner = CliRunner()
-        result = runner.invoke(cli, [str(schema), "--package", package])
+        result = runner.invoke(cli, ["generate", str(schema), "--package", package])
 
         if result.exception:
             raise result.exception
@@ -29,7 +29,7 @@ class CalculatorServiceTests(TestCase):
         self.assertEqual("Envelope", clazz.Meta.name)
 
     @mock.patch.object(DefaultTransport, "post")
-    def test_client(self, mock_most):
+    def test_client(self, mock_most) -> None:
         url = "http://www.dneonline.com/calculator.asmx"
         request = fixtures_dir.joinpath("calculator/AddRQ.xml").read_text()
         response = fixtures_dir.joinpath("calculator/AddRS.xml").read_bytes()
@@ -37,7 +37,7 @@ class CalculatorServiceTests(TestCase):
         mock_most.return_value = response
 
         config = Config.from_service(CalculatorSoapAdd)
-        serializer = XmlSerializer(config=SerializerConfig(pretty_print=True))
+        serializer = XmlSerializer(config=SerializerConfig(indent="  "))
         client = Client(config=config, serializer=serializer)
         result = client.send({"Body": {"Add": {"intA": 1, "intB": 3}}})
 
