@@ -10,12 +10,21 @@ from xsdata.utils.testing import load_class
 os.chdir(root)
 
 
-def test_xml_documents():
+def test_xml_documents() -> None:
     schema = fixtures_dir.joinpath("compound/schema.xsd")
     package = "tests.fixtures.compound.models"
     runner = CliRunner()
     result = runner.invoke(
-        cli, [str(schema), "-p", package, "-ss", "single-package", "--compound-fields"]
+        cli,
+        [
+            "generate",
+            str(schema),
+            "-p",
+            package,
+            "-ss",
+            "single-package",
+            "--compound-fields",
+        ],
     )
 
     if result.exception:
