@@ -9,11 +9,12 @@ from xsdata.utils.testing import load_class
 os.chdir(root)
 
 
-def test_dtd_documents():
+def test_dtd_documents() -> None:
     runner = CliRunner()
     result = runner.invoke(
         cli,
         [
+            "generate",
             str(fixtures_dir.joinpath("dtd/complete_example.dtd")),
             "--package",
             "tests.fixtures.dtd.models",
