@@ -10,12 +10,13 @@ from xsdata.utils.testing import load_class
 os.chdir(root)
 
 
-def test_primer_schema():
+def test_primer_schema() -> None:
     schema = fixtures_dir.joinpath("primer/order.xsd")
     package = "tests.fixtures.primer"
     runner = CliRunner()
     result = runner.invoke(
-        cli, [str(schema), "--package", package, "--docstring-style", "NumPy"]
+        cli,
+        ["generate", str(schema), "--package", package, "--docstring-style", "NumPy"],
     )
 
     if result.exception:
