@@ -8,17 +8,17 @@ from xsdata.cli import cli
 from xsdata.formats.dataclass.parsers import JsonParser
 from xsdata.formats.dataclass.serializers import JsonSerializer
 from xsdata.formats.dataclass.serializers.config import SerializerConfig
-from xsdata.utils.testing import load_class
+from xsdata.utils.testing import filter_none, load_class
 
 os.chdir(root)
 
 
-def test_json_documents():
+def test_json_documents() -> None:
     filepath = fixtures_dir.joinpath("series")
     package = "tests.fixtures.series"
     runner = CliRunner()
     result = runner.invoke(
-        cli, [str(filepath.joinpath("samples")), "--package", package]
+        cli, ["generate", str(filepath.joinpath("samples")), "--package", package]
     )
 
     if result.exception:
@@ -27,7 +27,7 @@ def test_json_documents():
     clazz = load_class(result.output, "Series")
 
     parser = JsonParser()
-    config = SerializerConfig(pretty_print=True)
+    config = SerializerConfig(indent="  ")
     serializer = JsonSerializer(config=config)
 
     for i in range(1, 3):
@@ -36,10 +36,3 @@ def test_json_documents():
         actual = serializer.render(obj)
 
         assert filter_none(json.loads(ori)) == filter_none(json.loads(actual))
-
-
-def filter_none(d):
-    if isinstance(d, dict):
-        return {k: filter_none(v) for k, v in d.items() if v is not None}
-    else:
-        return d
