@@ -8,19 +8,20 @@ from xsdata.cli import cli
 from xsdata.formats.dataclass.parsers import JsonParser
 from xsdata.formats.dataclass.serializers import JsonSerializer
 from xsdata.formats.dataclass.serializers.config import SerializerConfig
-from xsdata.utils.testing import load_class
+from xsdata.utils.testing import filter_none, load_class
 
 os.chdir(root)
 
 
-def test_json_documents():
+def test_json_documents() -> None:
     filepath = fixtures_dir.joinpath("stripe")
     runner = CliRunner()
     result = runner.invoke(
         cli,
         [
+            "generate",
             str(filepath.joinpath("samples")),
-            f"--config={str(filepath.joinpath('.xsdata.xml'))}",
+            f"--config={filepath.joinpath('.xsdata.xml')!s}",
         ],
     )
 
@@ -30,7 +31,7 @@ def test_json_documents():
     clazz = load_class(result.output, "Balance")
 
     parser = JsonParser()
-    config = SerializerConfig(pretty_print=True)
+    config = SerializerConfig(indent="  ")
     serializer = JsonSerializer(config=config)
 
     for sample in filepath.joinpath("samples").glob("*.json"):
@@ -39,10 +40,3 @@ def test_json_documents():
         actual = serializer.render(obj)
 
         assert filter_none(json.loads(ori)) == filter_none(json.loads(actual))
-
-
-def filter_none(d):
-    if isinstance(d, dict):
-        return {k: filter_none(v) for k, v in d.items() if v is not None}
-    else:
-        return d
