@@ -1,19 +1,16 @@
-import sys
 import tempfile
 import warnings
 from pathlib import Path
 from unittest import TestCase
 
 from xsdata import __version__
-from xsdata.exceptions import GeneratorConfigError, ParserError
+from xsdata.codegen.exceptions import CodegenError
+from xsdata.exceptions import ParserError
 from xsdata.models.config import (
     ExtensionType,
-    GeneratorAlias,
-    GeneratorAliases,
     GeneratorConfig,
     GeneratorExtension,
     GeneratorOutput,
-    ObjectType,
     OutputFormat,
 )
 
@@ -22,7 +19,7 @@ class GeneratorConfigTests(TestCase):
     def setUp(self) -> None:
         self.maxDiff = None
 
-    def test_create(self):
+    def test_create(self) -> None:
         file_path = Path(tempfile.mktemp())
         obj = GeneratorConfig.create()
         with file_path.open("w") as fp:
@@ -31,15 +28,14 @@ class GeneratorConfigTests(TestCase):
         expected = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             f'<Config xmlns="http://pypi.org/project/xsdata" version="{__version__}">\n'
-            '  <Output maxLineLength="79" subscriptableTypes="false" unionType="false">\n'
+            '  <Output maxLineLength="79" genericCollections="false">\n'
             "    <Package>generated</Package>\n"
-            '    <Format repr="true" eq="true" order="false" unsafeHash="false" frozen="false" slots="false" kwOnly="false">dataclasses</Format>\n'
+            '    <Format repr="true" eq="true" order="false" unsafeHash="false" frozen="false" slots="false">dataclasses</Format>\n'
             "    <Structure>filenames</Structure>\n"
             "    <DocstringStyle>reStructuredText</DocstringStyle>\n"
-            "    <FilterStrategy>allGlobals</FilterStrategy>\n"
             "    <RelativeImports>false</RelativeImports>\n"
             '    <CompoundFields defaultName="choice" useSubstitutionGroups="false" forceDefaultName="false" maxNameParts="3">false</CompoundFields>\n'
-            "    <PostponedAnnotations>false</PostponedAnnotations>\n"
+            "    <WrapperFields>false</WrapperFields>\n"
             "    <UnnestClasses>false</UnnestClasses>\n"
             "    <IgnorePatterns>false</IgnorePatterns>\n"
             "    <IncludeHeader>false</IncludeHeader>\n"
@@ -61,6 +57,7 @@ class GeneratorConfigTests(TestCase):
             '    <Substitution type="package" search="http://schemas.xmlsoap.org/wsdl/soap/" replace="soap"/>\n'
             '    <Substitution type="package" search="http://schemas.xmlsoap.org/wsdl/soap12/" replace="soap12"/>\n'
             '    <Substitution type="package" search="http://schemas.xmlsoap.org/soap/envelope/" replace="soapenv"/>\n'
+            '    <Substitution type="package" search="http://schemas.xmlsoap.org/soap/encoding/" replace="soapenc"/>\n'
             '    <Substitution type="class" search="(.*)Class$" replace="\\1Type"/>\n'
             "  </Substitutions>\n"
             "  <Extensions/>\n"
@@ -69,17 +66,16 @@ class GeneratorConfigTests(TestCase):
         self.assertEqual(expected, file_path.read_text())
         file_path.unlink()
 
-    def test_read(self):
+    def test_read(self) -> None:
         existing = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<Config xmlns="http://pypi.org/project/xsdata" version="20.8">\n'
-            '  <Output maxLineLength="79" subscriptableTypes="false" unionType="false">\n'
+            '  <Output maxLineLength="79">\n'
             "    <Package>foo.bar</Package>\n"
             "  </Output>\n"
             "  <Conventions>\n"
             '    <ClassName case="pascalCase" safePrefix="type"/>\n'
             "  </Conventions>\n"
-            "  <Aliases/>\n"
             "  <Substitutions/>\n"
             "</Config>\n"
         )
@@ -92,16 +88,15 @@ class GeneratorConfigTests(TestCase):
         expected = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             f'<Config xmlns="http://pypi.org/project/xsdata" version="{__version__}">\n'
-            '  <Output maxLineLength="79" subscriptableTypes="false" unionType="false">\n'
+            '  <Output maxLineLength="79" genericCollections="false">\n'
             "    <Package>foo.bar</Package>\n"
             '    <Format repr="true" eq="true" order="false" unsafeHash="false"'
-            ' frozen="false" slots="false" kwOnly="false">dataclasses</Format>\n'
+            ' frozen="false" slots="false">dataclasses</Format>\n'
             "    <Structure>filenames</Structure>\n"
             "    <DocstringStyle>reStructuredText</DocstringStyle>\n"
-            "    <FilterStrategy>allGlobals</FilterStrategy>\n"
             "    <RelativeImports>false</RelativeImports>\n"
             '    <CompoundFields defaultName="choice" useSubstitutionGroups="false" forceDefaultName="false" maxNameParts="3">false</CompoundFields>\n'
-            "    <PostponedAnnotations>false</PostponedAnnotations>\n"
+            "    <WrapperFields>false</WrapperFields>\n"
             "    <UnnestClasses>false</UnnestClasses>\n"
             "    <IgnorePatterns>false</IgnorePatterns>\n"
             "    <IncludeHeader>false</IncludeHeader>\n"
@@ -113,14 +108,13 @@ class GeneratorConfigTests(TestCase):
             '    <ModuleName case="snakeCase" safePrefix="mod"/>\n'
             '    <PackageName case="snakeCase" safePrefix="pkg"/>\n'
             "  </Conventions>\n"
-            "  <Aliases/>\n"
             "  <Substitutions/>\n"
             "  <Extensions/>\n"
             "</Config>\n"
         )
         self.assertEqual(expected, file_path.read_text())
 
-    def test_read_with_wrong_value(self):
+    def test_read_with_wrong_value(self) -> None:
         existing = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<Config xmlns="http://pypi.org/project/xsdata" version="21.7">\n'
@@ -134,114 +128,51 @@ class GeneratorConfigTests(TestCase):
         with self.assertRaises(ParserError):
             GeneratorConfig.read(file_path)
 
-    def test_format_with_invalid_state(self):
-        with self.assertRaises(GeneratorConfigError) as cm:
+    def test_format_with_invalid_eq_config(self) -> None:
+        with warnings.catch_warnings(record=True) as w:
             OutputFormat(eq=False, order=True)
 
-        self.assertEqual("eq must be true if order is true", str(cm.exception))
+        self.assertEqual("Enabling eq because order is true", str(w[-1].message))
 
-    def test_subscriptable_types_requires_390(self):
-        if sys.version_info < (3, 9):
-            with warnings.catch_warnings(record=True) as w:
-                self.assertFalse(
-                    GeneratorOutput(subscriptable_types=True).subscriptable_types
-                )
+    def test_generic_collections_requires_frozen_false(self) -> None:
+        with warnings.catch_warnings(record=True) as w:
+            output = GeneratorOutput(
+                generic_collections=True, format=OutputFormat(frozen=True)
+            )
+            self.assertFalse(output.generic_collections)
 
             self.assertEqual(
-                "Generics PEP 585 requires python >= 3.9, reverting...",
+                "Generic Collections, requires frozen=False, reverting...",
                 str(w[-1].message),
             )
 
-        else:
-            self.assertTrue(
-                GeneratorOutput(subscriptable_types=True).subscriptable_types
-            )
-
-    def test_use_union_type_requires_310_and_postponed_annotations(self):
-        if sys.version_info < (3, 10):
-            with warnings.catch_warnings(record=True) as w:
-                self.assertFalse(GeneratorOutput(union_type=True).union_type)
-
-            self.assertEqual(
-                "UnionType PEP 604 requires python >= 3.10, reverting...",
-                str(w[-1].message),
-            )
-        else:
-            with warnings.catch_warnings(record=True) as w:
-                output = GeneratorOutput(union_type=True)
-                self.assertTrue(output.postponed_annotations)
-
-                self.assertEqual(
-                    "Enabling postponed annotations, because `union_type==True`",
-                    str(w[-1].message),
-                )
-
-    def test_format_slots_requires_310(self):
-        if sys.version_info < (3, 10):
-            self.assertTrue(OutputFormat(slots=True, value="attrs").slots)
-
-            with warnings.catch_warnings(record=True) as w:
-                self.assertFalse(OutputFormat(slots=True).slots)
-
-            self.assertEqual(
-                "slots requires python >= 3.10, reverting...", str(w[-1].message)
-            )
-
-        else:
-            self.assertIsNotNone(OutputFormat(slots=True))
-
-    def test_format_kw_only_requires_310(self):
-        if sys.version_info < (3, 10):
-            self.assertTrue(OutputFormat(kw_only=True, value="attrs").kw_only)
-
-            with warnings.catch_warnings(record=True) as w:
-                self.assertFalse(OutputFormat(kw_only=True).kw_only)
-
-            self.assertEqual(
-                "kw_only requires python >= 3.10, reverting...", str(w[-1].message)
-            )
-
-        else:
-            self.assertIsNotNone(OutputFormat(kw_only=True))
-
-    def test_init_config_with_aliases(self):
-        config = GeneratorConfig(
-            aliases=GeneratorAliases(
-                class_name=[GeneratorAlias(source="a", target="b")],
-                field_name=[GeneratorAlias(source="c", target="d")],
-                package_name=[GeneratorAlias(source="e", target="f")],
-                module_name=[GeneratorAlias(source="g", target="h")],
-            )
-        )
-
-        self.assertEqual(4, len(config.substitutions.substitution))
-        self.assertEqual(ObjectType.CLASS, config.substitutions.substitution[0].type)
-        self.assertEqual(ObjectType.FIELD, config.substitutions.substitution[1].type)
-        self.assertEqual(ObjectType.PACKAGE, config.substitutions.substitution[2].type)
-        self.assertEqual(ObjectType.MODULE, config.substitutions.substitution[3].type)
-
-        output = tempfile.mktemp()
-        output_path = Path(output)
-        config.substitutions = None
-        with output_path.open("w") as fp:
-            config.write(fp, config)
-
-        config = GeneratorConfig.read(output_path)
-        self.assertIsNone(config.aliases)
-        self.assertEqual(4, len(config.substitutions.substitution))
-
-    def test_extension_with_invalid_import_string(self):
+    def test_extension_with_invalid_import_string(self) -> None:
         cases = [None, "", "bar"]
         for case in cases:
-            with self.assertRaises(GeneratorConfigError) as cm:
-                GeneratorExtension(type=ExtensionType.DECORATOR, import_string=case)
+            with self.assertRaises(CodegenError):
+                GeneratorExtension(
+                    type=ExtensionType.DECORATOR, import_string=case, class_name="Test"
+                )
 
-            self.assertEqual(f"Invalid extension import '{case}'", str(cm.exception))
-
-    def test_extension_with_invalid_class_name_pattern(self):
-        with self.assertRaises(GeneratorConfigError) as cm:
+    def test_extension_with_invalid_class_name_pattern(self) -> None:
+        with self.assertRaises(CodegenError):
             GeneratorExtension(
                 type=ExtensionType.DECORATOR, import_string="a.b", class_name="*Foo"
             )
 
-        self.assertEqual("Failed to compile pattern '*Foo'", str(cm.exception))
+    def test_extension_with_parent_path(self) -> None:
+        GeneratorExtension(
+            type=ExtensionType.DECORATOR,
+            import_string="a.b",
+            class_name="Foo",
+            parent_path=r"Grandpa\.Papa$",
+        )
+
+    def test_extension_with_invalid_parent_path(self) -> None:
+        with self.assertRaises(CodegenError):
+            GeneratorExtension(
+                type=ExtensionType.DECORATOR,
+                import_string="a.b",
+                class_name="Foo",
+                parent_path=r"*Grandpa\.Papa$",
+            )
