@@ -1,15 +1,15 @@
 import copy
-from typing import Generator
+from collections.abc import Generator
 from unittest import TestCase
 
-from xsdata.exceptions import DefinitionsValueError
+from xsdata.codegen.exceptions import CodegenError
 from xsdata.formats.dataclass.models.generics import AnyElement
 from xsdata.models.wsdl import Binding, Definitions, Message, PortType, Service, Types
 from xsdata.models.xsd import Schema
 
 
 class DefinitionsTests(TestCase):
-    def test_property_schemas(self):
+    def test_property_schemas(self) -> None:
         obj = Definitions()
 
         self.assertIsInstance(obj.schemas, Generator)
@@ -23,40 +23,34 @@ class DefinitionsTests(TestCase):
 
         self.assertEqual(schemas, list(obj.schemas))
 
-    def test_find_binding(self):
+    def test_find_binding(self) -> None:
         res = Binding(name="foo")
         obj = Definitions(bindings=[res])
 
         self.assertEqual(res, obj.find_binding("foo"))
 
-        with self.assertRaises(DefinitionsValueError) as cm:
+        with self.assertRaises(CodegenError):
             obj.find_binding("nope")
 
-        self.assertEqual("Unknown Binding name: nope", str(cm.exception))
-
-    def test_find_message(self):
+    def test_find_message(self) -> None:
         res = Message(name="foo")
         obj = Definitions(messages=[res])
 
         self.assertEqual(res, obj.find_message("foo"))
 
-        with self.assertRaises(DefinitionsValueError) as cm:
+        with self.assertRaises(CodegenError):
             obj.find_message("nope")
 
-        self.assertEqual("Unknown Message name: nope", str(cm.exception))
-
-    def test_find_port_type(self):
+    def test_find_port_type(self) -> None:
         res = PortType(name="foo")
         obj = Definitions(port_types=[res])
 
         self.assertEqual(res, obj.find_port_type("foo"))
 
-        with self.assertRaises(DefinitionsValueError) as cm:
+        with self.assertRaises(CodegenError):
             obj.find_port_type("nope")
 
-        self.assertEqual("Unknown PortType name: nope", str(cm.exception))
-
-    def test_merge(self):
+    def test_merge(self) -> None:
         target = Definitions()
         source = Definitions()
         source.types = Types()
