@@ -5,7 +5,7 @@ from xsdata.models.xsd import Annotation, AnnotationBase, Documentation
 
 
 class AnnotationBaseTest(TestCase):
-    def test_property_dispaly_help(self):
+    def test_property_display_help(self) -> None:
         base = AnnotationBase()
         self.assertIsNone(base.display_help)
 
@@ -16,7 +16,7 @@ class AnnotationBaseTest(TestCase):
             Annotation(
                 documentations=[
                     Documentation(
-                        elements=[
+                        content=[
                             "    I am a ",
                             AnyElement(
                                 qname="{http://www.w3.org/1999/xhtml}p",
@@ -34,4 +34,4 @@ class AnnotationBaseTest(TestCase):
                 ]
             )
         )
-        self.assertEqual("I am a <p>test<span>!</span></p>", base.display_help)
+        self.assertEqual("I am a <p>test<span>!</span>\n</p>", base.display_help)
