@@ -5,11 +5,11 @@ from xsdata.models.xsd import AnyAttribute
 
 
 class AnyAttributeTests(TestCase):
-    def test_is_attribute(self):
+    def test_is_attribute(self) -> None:
         obj = AnyAttribute()
         self.assertTrue(obj.is_property)
 
-    def test_property_raw_namespace(self):
+    def test_property_raw_namespace(self) -> None:
         obj = AnyAttribute()
         self.assertEqual(NamespaceType.ANY_NS, obj.raw_namespace)
 
@@ -19,7 +19,7 @@ class AnyAttributeTests(TestCase):
         obj = AnyAttribute(namespace="    foo  \n    \t  \r  bar foo ")
         self.assertEqual("foo bar", obj.raw_namespace)
 
-    def test_property_real_name(self):
+    def test_property_real_name(self) -> None:
         obj = AnyAttribute()
         self.assertEqual("@any_attributes", obj.real_name)
 
@@ -32,11 +32,11 @@ class AnyAttributeTests(TestCase):
         obj.namespace = "http://foo http://bar"
         self.assertEqual("@foo_bar_attributes", obj.real_name)
 
-    def test_property_real_type(self):
+    def test_property_real_type(self) -> None:
         obj = AnyAttribute()
         obj.ns_map["xs"] = Namespace.XS.uri
         self.assertEqual(["xs:anyType"], list(obj.attr_types))
 
-    def get_restrictions(self):
+    def get_restrictions(self) -> None:
         obj = AnyAttribute()
         self.assertEqual({}, obj.get_restrictions())
