@@ -4,11 +4,11 @@ from xsdata.models.xsd import AttributeGroup
 
 
 class AttributeGroupTests(TestCase):
-    def test_property_is_property(self):
+    def test_property_is_property(self) -> None:
         obj = AttributeGroup()
         self.assertTrue(obj.is_property)
 
-    def test_property_attr_types(self):
+    def test_property_attr_types(self) -> None:
         obj = AttributeGroup()
         self.assertEqual([], list(obj.attr_types))
 
