@@ -4,7 +4,7 @@ from xsdata.models.xsd import ComplexContent, SimpleContent
 
 
 class ComplexContentTests(TestCase):
-    def test_class(self):
+    def test_class(self) -> None:
         obj = ComplexContent()
         self.assertIsInstance(obj, SimpleContent)
 
