@@ -1,6 +1,7 @@
+import sys
 from unittest import TestCase
 
-from xsdata.exceptions import SchemaValueError
+from xsdata.codegen.exceptions import CodegenError
 from xsdata.models.enums import Namespace
 from xsdata.models.xsd import (
     Alternative,
@@ -13,11 +14,20 @@ from xsdata.models.xsd import (
 
 
 class ElementTests(TestCase):
-    def test_property_is_property(self):
+    def test_normalize_max_occurs(self) -> None:
+        obj = Element(min_occurs=3, max_occurs=2)
+        self.assertEqual(3, obj.max_occurs)
+        self.assertEqual(3, obj.min_occurs)
+
+        obj = Element(min_occurs=3, max_occurs="unbounded")
+        self.assertEqual(sys.maxsize, obj.max_occurs)
+        self.assertEqual(3, obj.min_occurs)
+
+    def test_property_is_property(self) -> None:
         obj = Element()
         self.assertTrue(obj)
 
-    def test_property_default_type(self):
+    def test_property_default_type(self) -> None:
         obj = Element()
         self.assertEqual("anyType", obj.default_type)
 
@@ -28,7 +38,7 @@ class ElementTests(TestCase):
         obj.fixed = "aa"
         self.assertEqual("foo:string", obj.default_type)
 
-    def test_property_bases(self):
+    def test_property_bases(self) -> None:
         obj = Element()
         obj.ns_map["xs"] = Namespace.XS.uri
         self.assertEqual(["xs:anyType"], list(obj.bases))
@@ -40,18 +50,18 @@ class ElementTests(TestCase):
         obj.complex_type = ComplexType()
         self.assertEqual([], list(obj.bases))
 
-    def test_property_real_name(self):
+    def test_property_real_name(self) -> None:
         obj = Element(ref="bar")
         self.assertEqual("bar", obj.real_name)
 
         obj.name = "foo"
         self.assertEqual("foo", obj.real_name)
 
-        with self.assertRaises(SchemaValueError):
+        with self.assertRaises(CodegenError):
             obj = Element()
             obj.real_name
 
-    def test_property_attr_types(self):
+    def test_property_attr_types(self) -> None:
         obj = Element()
         self.assertEqual([], list(obj.attr_types))
 
@@ -74,7 +84,7 @@ class ElementTests(TestCase):
         obj.alternatives.append(Alternative(type="thug"))
         self.assertEqual(["bar", "foo", "bar", "thug"], list(obj.attr_types))
 
-    def test_property_is_mixed(self):
+    def test_property_is_mixed(self) -> None:
         obj = Element()
         self.assertFalse(obj.is_mixed)
 
@@ -84,14 +94,14 @@ class ElementTests(TestCase):
         obj.complex_type.mixed = True
         self.assertTrue(obj.is_mixed)
 
-    def test_property_substitutions(self):
+    def test_property_substitutions(self) -> None:
         obj = Element()
         self.assertEqual([], obj.substitutions)
 
         obj.substitution_group = "foo   bar xs:any"
         self.assertEqual(["foo", "bar", "xs:any"], obj.substitutions)
 
-    def test_get_restrictions(self):
+    def test_get_restrictions(self) -> None:
         obj = Element(min_occurs=1, max_occurs=1)
         expected = {"min_occurs": 1, "max_occurs": 1}
         self.assertEqual(expected, obj.get_restrictions())
