@@ -4,7 +4,7 @@ from xsdata.models.xsd import Extension
 
 
 class ExtensionTests(TestCase):
-    def test_property_bases(self):
+    def test_property_bases(self) -> None:
         obj = Extension()
         self.assertEqual([], list(obj.bases))
         obj.base = "a b c"
