@@ -2,7 +2,7 @@ import string
 from unittest import TestCase
 
 from xsdata.utils.text import (
-    StringType,
+    CharType,
     alnum,
     camel_case,
     capitalize,
@@ -16,23 +16,24 @@ from xsdata.utils.text import (
     screaming_snake_case,
     snake_case,
     split_words,
-    variable,
 )
 
 
 class TextTests(TestCase):
-    def test_original_case(self):
+    def test_original_case(self) -> None:
         self.assertEqual("p00p", original_case("p00p", foobar=True))
         self.assertEqual("p00p", original_case("p00p"))
         self.assertEqual("USERName", original_case("USERName"))
+        self.assertEqual("_USERName", original_case("_USERName"))
         self.assertEqual("UserNAME", original_case("UserNAME"))
         self.assertEqual("USER_name", original_case("USER_name"))
-        self.assertEqual("USER-NAME", original_case("USER-NAME"))
+        self.assertEqual("USER_name", original_case("3USER_name"))
+        self.assertEqual("USERNAME", original_case("USER-NAME"))
         self.assertEqual("User_Name", original_case("User_Name"))
         self.assertEqual("user_name", original_case("user_name"))
         self.assertEqual("SUserNAME", original_case("SUserNAME"))
 
-    def test_snake_case(self):
+    def test_snake_case(self) -> None:
         self.assertEqual("p00p", snake_case("p00p", foobar=True))
         self.assertEqual("p00p", snake_case("p00p"))
         self.assertEqual("username", snake_case("USERName"))
@@ -43,7 +44,7 @@ class TextTests(TestCase):
         self.assertEqual("user_name", snake_case("user_name"))
         self.assertEqual("suser_name", snake_case("SUserNAME"))
 
-    def test_screaming_snake_case(self):
+    def test_screaming_snake_case(self) -> None:
         self.assertEqual("P00P", screaming_snake_case("p00p", foobar=True))
         self.assertEqual("P00P", screaming_snake_case("p00p"))
         self.assertEqual("USERNAME", screaming_snake_case("USERName"))
@@ -54,7 +55,7 @@ class TextTests(TestCase):
         self.assertEqual("USER_NAME", screaming_snake_case("user_name"))
         self.assertEqual("SUSER_NAME", screaming_snake_case("SUserNAME"))
 
-    def test_pascal_case(self):
+    def test_pascal_case(self) -> None:
         self.assertEqual("P00P", pascal_case("p00p", foobar=True))
         self.assertEqual("P00P", pascal_case("p00p"))
         self.assertEqual("Username", pascal_case("USERName"))
@@ -65,7 +66,7 @@ class TextTests(TestCase):
         self.assertEqual("UserName", pascal_case("user_name"))
         self.assertEqual("SuserName", pascal_case("SUserNAME"))
 
-    def test_camel_case(self):
+    def test_camel_case(self) -> None:
         self.assertEqual("p00P", camel_case("p00p", foobar=True))
         self.assertEqual("p00P", camel_case("p00p"))
         self.assertEqual("username", camel_case("USERName"))
@@ -76,7 +77,7 @@ class TextTests(TestCase):
         self.assertEqual("userName", camel_case("user_name"))
         self.assertEqual("suserName", camel_case("SUserNAME"))
 
-    def test_mixed_case(self):
+    def test_mixed_case(self) -> None:
         self.assertEqual("p00p", mixed_case("p00p", foobar=True))
         self.assertEqual("p00p", mixed_case("p00p"))
         self.assertEqual("USERName", mixed_case("USERName"))
@@ -87,7 +88,7 @@ class TextTests(TestCase):
         self.assertEqual("username", mixed_case("user_name"))
         self.assertEqual("SUserNAME", mixed_case("SUserNAME"))
 
-    def test_mixed_pascal_case(self):
+    def test_mixed_pascal_case(self) -> None:
         self.assertEqual("P00p", mixed_pascal_case("p00p", foobar=True))
         self.assertEqual("P00p", mixed_pascal_case("p00p"))
         self.assertEqual("USERName", mixed_pascal_case("USERName"))
@@ -98,7 +99,7 @@ class TextTests(TestCase):
         self.assertEqual("Username", mixed_pascal_case("user_name"))
         self.assertEqual("SUserNAME", mixed_pascal_case("SUserNAME"))
 
-    def test_mixed_snake_case(self):
+    def test_mixed_snake_case(self) -> None:
         self.assertEqual("p00p", mixed_snake_case("p00p", foobar=True))
         self.assertEqual("p00p", mixed_snake_case("p00p"))
         self.assertEqual("USERName", mixed_snake_case("USERName"))
@@ -109,7 +110,7 @@ class TextTests(TestCase):
         self.assertEqual("user_name", mixed_snake_case("user_name"))
         self.assertEqual("SUser_NAME", mixed_snake_case("SUserNAME"))
 
-    def test_kebab_case(self):
+    def test_kebab_case(self) -> None:
         self.assertEqual("p00p", kebab_case("p00p", foobar=True))
         self.assertEqual("p00p", kebab_case("p00p"))
         self.assertEqual("USERName", kebab_case("USERName"))
@@ -120,11 +121,11 @@ class TextTests(TestCase):
         self.assertEqual("user-name", kebab_case("user_name"))
         self.assertEqual("SUser-NAME", kebab_case("SUserNAME"))
 
-    def test_capitalize(self):
+    def test_capitalize(self) -> None:
         self.assertEqual("UserName", capitalize("userName"))
         self.assertEqual(".userName", capitalize(".userName"))
 
-    def test_split_words(self):
+    def test_split_words(self) -> None:
         self.assertEqual(["user", "Name"], split_words("userName"))
         self.assertEqual(["User", "Name"], split_words("User.Name"))
         self.assertEqual(["User", "Name"], split_words("UserName"))
@@ -139,29 +140,22 @@ class TextTests(TestCase):
         self.assertEqual(["GLOBAL", "REF"], split_words("GLOBAL-REF"))
         self.assertEqual(["book"], split_words("βιβλιο-book"))
 
-    def test_alnum(self):
+    def test_alnum(self) -> None:
         self.assertEqual("foo1", alnum("foo 1"))
         self.assertEqual("foo1", alnum(" foo_1 "))
         self.assertEqual("foo1", alnum("\tfoo*1"))
         self.assertEqual("foo1", alnum(" foo*1"))
         self.assertEqual("1", alnum(" βιβλίο*1"))
 
-    def test_variable(self):
-        self.assertEqual("foO1", variable("foO1"))
-        self.assertEqual("foo_1", variable("foo_1"))
-        self.assertEqual("foo1", variable("foo-1"))
-        self.assertEqual("foo1", variable("@foo1"))
-        self.assertEqual("foo1", variable("1foo1"))
-
-    def test_classify(self):
+    def test_classify(self) -> None:
         for ltr in string.ascii_uppercase:
-            self.assertEqual(StringType.UPPER, classify(ltr))
+            self.assertEqual(CharType.UPPER, classify(ltr))
 
         for ltr in string.ascii_lowercase:
-            self.assertEqual(StringType.LOWER, classify(ltr))
+            self.assertEqual(CharType.LOWER, classify(ltr))
 
         for ltr in string.digits:
-            self.assertEqual(StringType.NUMERIC, classify(ltr))
+            self.assertEqual(CharType.NUMERIC, classify(ltr))
 
         for ltr in "~!@#$%^&*()_+β":
-            self.assertEqual(StringType.OTHER, classify(ltr))
+            self.assertEqual(CharType.OTHER, classify(ltr))
