@@ -6,24 +6,24 @@ from xsdata.models.enums import DataType, NamespaceType, Tag
 
 
 class ProcessMixedContentClass(HandlerInterface):
-    """
-    Mixed content handler.
-
-    If the target class supports mixed content, a new wildcard attr will
-    replace the originals except any attributes. All the previous attrs
-    derived from  xs:element will be moved as choices for the new
-    content attr.
-    """
+    """Mixed content handler."""
 
     __slots__ = ()
 
-    def process(self, target: Class):
+    def process(self, target: Class) -> None:
+        """Add a wildcard attr if the class supports mixed content.
+
+        All other elements will be moved as the wildcard attr choices.
+
+        Args:
+            target: The target class instance
+        """
         if not target.is_mixed:
             return
 
         attrs = []
         choices = []
-        for attr in list(target.attrs):
+        for attr in target.attrs.copy():
             if attr.is_attribute:
                 attrs.append(attr)
             elif not attr.is_any_type:
