@@ -1,5 +1,5 @@
 import itertools
-from typing import Dict, Iterator, List, Optional, Tuple
+from collections.abc import Iterator
 
 from xsdata.codegen.models import Attr, AttrType, Class, Restrictions, Status
 from xsdata.formats.dataclass.models.generics import AnyElement
@@ -20,16 +20,25 @@ from xsdata.utils import collections, namespaces, text
 
 
 class DefinitionsMapper:
-    """
-    Map a definitions instance to message and service classes.
+    """Map a definitions instance to message and service classes.
 
     Currently, only SOAP 1.1 bindings with rpc/document style is
     supported.
     """
 
     @classmethod
-    def map(cls, definitions: Definitions) -> List[Class]:
-        """Step 1: Main mapper entry point."""
+    def map(cls, definitions: Definitions) -> list[Class]:
+        """Main entrypoint for this mapper.
+
+        Iterates over their services and their ports and build
+        the binding and service classes.
+
+        Args:
+            definitions: The definitions instance to map.
+
+        Returns:
+            The generated class instances
+        """
         return [
             obj
             for service in definitions.services
@@ -39,9 +48,18 @@ class DefinitionsMapper:
 
     @classmethod
     def map_port(cls, definitions: Definitions, port: ServicePort) -> Iterator[Class]:
-        """Step 2: Match a ServicePort to a Binding and PortType object and
-        delegate the process to the next entry point."""
+        """Map a service port into binding and service classes.
 
+        Match a ServicePort to a Binding and PortType object and
+        delegate the process to the next entry point.
+
+        Args:
+            definitions: The definitions instance
+            port: The service port instance
+
+        Yields:
+            An iterator of class instances.
+        """
         binding = definitions.find_binding(text.suffix(port.binding))
         port_type = definitions.find_port_type(text.suffix(binding.type))
 
@@ -56,10 +74,22 @@ class DefinitionsMapper:
         definitions: Definitions,
         binding: Binding,
         port_type: PortType,
-        config: Dict,
+        config: dict,
     ) -> Iterator[Class]:
-        """Step 3: Match every BindingOperation to a PortTypeOperation and
-        delegate the process for each operation to the next entry point."""
+        """Map binding operations into binding and service classes.
+
+        Match every BindingOperation to a PortTypeOperation and
+        delegate the process for each operation to the next entry point.
+
+        Args:
+            definitions: The definitions instance
+            binding: The binding instance
+            port_type: The port type instance
+            config: Configuration dictionary
+
+        Yields:
+            An iterator of class instances.
+        """
         for operation in binding.unique_operations():
             cfg = config.copy()
             cfg.update(cls.attributes(operation.extended_elements))
@@ -75,12 +105,24 @@ class DefinitionsMapper:
         definitions: Definitions,
         binding_operation: BindingOperation,
         port_type_operation: PortTypeOperation,
-        config: Dict,
+        config: dict,
         name: str,
     ) -> Iterator[Class]:
-        """Step 4: Convert a BindingOperation to a service class and delegate
-        the process of all the message classes to the next entry point."""
+        """Map a binding operation to a service and binding classes.
 
+        Convert a BindingOperation to a service class and delegate
+        the process of all the message classes to the next entry point.
+
+        Args:
+            definitions: The definitions instance
+            binding_operation: The binding operation instance
+            port_type_operation: The port type operation instance
+            config: Configuration dictionary
+            name: The operation name
+
+        Yields:
+            An iterator of class instances.
+        """
         attrs = [
             cls.build_attr(key, str(DataType.STRING), native=True, default=config[key])
             for key in sorted(config.keys(), key=len)
@@ -91,14 +133,23 @@ class DefinitionsMapper:
         name = f"{name}_{binding_operation.name}"
         namespace = cls.operation_namespace(config)
         operation_messages = cls.map_binding_operation_messages(
-            definitions, binding_operation, port_type_operation, name, style, namespace
+            definitions,
+            binding_operation,
+            port_type_operation,
+            name,
+            style,
+            namespace,
         )
         for message_class in operation_messages:
             yield message_class
             # Only Envelope classes need to be added in service input/output
             if message_class.meta_name:
                 message_type = message_class.name.split("_")[-1]
-                attrs.append(cls.build_attr(message_type, message_class.qname))
+                attrs.append(
+                    cls.build_attr(
+                        message_type, message_class.qname, reference=id(message_class)
+                    )
+                )
 
         assert binding_operation.location is not None
 
@@ -115,24 +166,40 @@ class DefinitionsMapper:
     def map_binding_operation_messages(
         cls,
         definitions: Definitions,
-        operation: BindingOperation,
+        binding_operation: BindingOperation,
         port_type_operation: PortTypeOperation,
         name: str,
         style: str,
-        namespace: Optional[str],
+        namespace: str | None,
     ) -> Iterator[Class]:
-        """Step 5: Map the BindingOperation messages to classes."""
+        """Map the binding operation messages to binding classes.
 
-        messages: List[Tuple[str, BindingMessage, PortTypeMessage, Optional[str]]] = []
+        Args:
+            definitions: The definitions instance
+            binding_operation: The binding operation instance
+            port_type_operation: The port type operation instance
+            name: The operation name
+            style: The operation style
+            namespace: The operation namespace
 
-        if operation.input:
+        Yields:
+            An iterator of class instances.
+        """
+        messages: list[tuple[str, BindingMessage, PortTypeMessage, str | None]] = []
+
+        if binding_operation.input:
             messages.append(
-                ("input", operation.input, port_type_operation.input, operation.name)
+                (
+                    "input",
+                    binding_operation.input,
+                    port_type_operation.input,
+                    binding_operation.name,
+                )
             )
 
-        if operation.output:
+        if binding_operation.output:
             messages.append(
-                ("output", operation.output, port_type_operation.output, None)
+                ("output", binding_operation.output, port_type_operation.output, None)
             )
 
         for suffix, binding_message, port_type_message, operation_name in messages:
@@ -161,31 +228,58 @@ class DefinitionsMapper:
         port_type_operation: PortTypeOperation,
         target: Class,
     ):
-        """Build inner fault class with default fields."""
-        ns_map: Dict = {}
+        """Add an inner message fault class with default fields.
+
+        Args:
+            definitions: The definitions instance
+            port_type_operation: The port type operation instance
+            target: The target class instance
+        """
+        ns_map: dict = {}
         body = next(inner for inner in target.inner if inner.name == "Body")
         fault_class = cls.build_inner_class(body, "Fault", target.namespace)
 
-        detail_attrs: List[Attr] = []
+        detail_attrs: list[Attr] = []
         for fault in port_type_operation.faults:
             message = definitions.find_message(text.suffix(fault.message))
             detail_attrs.extend(cls.build_parts_attributes(message.parts, ns_map))
 
-        default_fields = ["faultcode", "faultstring", "faultactor"]
+        # faultcode and faultstring are required, faultactor and detail are optional
+        required_fields = ["faultcode", "faultstring"]
+        optional_fields = ["faultactor"]
         if detail_attrs:
             detail = cls.build_inner_class(fault_class, "detail", namespace="")
             detail.attrs.extend(detail_attrs)
+            # Make detail attr optional
+            detail_attr = fault_class.attrs[
+                -1
+            ]  # Last added attr is the detail forward ref
+            detail_attr.restrictions.min_occurs = 0
+            # Make detail attributes optional since SOAP faults contain one fault type
+            for attr in detail_attrs:
+                attr.restrictions.min_occurs = 0
         else:
-            default_fields.append("detail")
+            optional_fields.append("detail")
 
+        optional_attrs = [
+            cls.build_attr(f, str(DataType.STRING), native=True, namespace="")
+            for f in optional_fields
+        ]
+        for attr in optional_attrs:
+            attr.restrictions.min_occurs = 0
+
+        collections.prepend(fault_class.attrs, *optional_attrs)
         collections.prepend(
             fault_class.attrs,
             *(
                 cls.build_attr(f, str(DataType.STRING), native=True, namespace="")
-                for f in default_fields
+                for f in required_fields
             ),
         )
 
+        for attr in body.attrs:
+            attr.restrictions.min_occurs = 0
+
     @classmethod
     def build_envelope_class(
         cls,
@@ -194,12 +288,24 @@ class DefinitionsMapper:
         port_type_message: PortTypeMessage,
         name: str,
         style: str,
-        namespace: Optional[str],
-        operation: Optional[str],
+        namespace: str | None,
+        operation: str | None,
     ) -> Class:
-        """Step 6.1: Build Envelope class for the given binding message with
-        attributes from the port type message."""
+        """Map the binding message to an envelope class.
 
+        Args:
+            definitions: The definitions instance
+            binding_message: The port type message instance
+            port_type_message: The port type message instance
+            name: The class name
+            style: The operation style e.g. rpc
+            namespace: The operation namespace
+            operation: The custom operation name, if it's empty
+                the message name will be used instead
+
+        Returns:
+            The class instance.
+        """
         assert binding_message.location is not None
 
         target = Class(
@@ -233,10 +339,19 @@ class DefinitionsMapper:
 
     @classmethod
     def build_message_class(
-        cls, definitions: Definitions, port_type_message: PortTypeMessage
+        cls,
+        definitions: Definitions,
+        port_type_message: PortTypeMessage,
     ) -> Class:
-        """Step 6.2: Build the input/output message class of an rpc style
-        operation."""
+        """Map the input/output message of a rpc style operation.
+
+        Args:
+            definitions: The definitions instance
+            port_type_message: The port type message instance
+
+        Returns:
+            The class instance.
+        """
         prefix, name = text.split(port_type_message.message)
 
         definition_message = definitions.find_message(name)
@@ -257,14 +372,20 @@ class DefinitionsMapper:
 
     @classmethod
     def build_inner_class(
-        cls, target: Class, name: str, namespace: Optional[str] = None
+        cls, target: Class, name: str, namespace: str | None = None
     ) -> Class:
-        """
-        Build or retrieve an inner class for the given target class by the
-        given name.
+        """Build or retrieve an inner class.
 
         This helper will also create a forward reference attribute for
         the parent class.
+
+        Args:
+            target: The parent class instance
+            name: The inner class name
+            namespace: The inner class namespace
+
+        Returns:
+            The inner class instance.
         """
         inner = collections.first(inner for inner in target.inner if inner.name == name)
         if not inner:
@@ -276,6 +397,7 @@ class DefinitionsMapper:
             )
             attr = cls.build_attr(name, inner.qname, forward=True, namespace=namespace)
 
+            inner.parent = target
             target.inner.append(inner)
             target.attrs.append(attr)
 
@@ -284,11 +406,21 @@ class DefinitionsMapper:
     @classmethod
     def map_port_type_message(
         cls,
-        operation: Optional[str],
+        operation: str | None,
         message: PortTypeMessage,
-        namespace: Optional[str],
+        namespace: str | None,
     ) -> Iterator[Attr]:
-        """Build an attribute for the given port type message."""
+        """Build an attribute for the given port type message.
+
+        Args:
+            operation: The operation name, use the message name
+                if it's empty
+            message: The port type message instance
+            namespace: The operation namespace
+
+        Yields:
+            An iterator of class attrs.
+        """
         prefix, name = text.split(message.message)
         source_namespace = message.ns_map.get(prefix)
 
@@ -303,10 +435,19 @@ class DefinitionsMapper:
 
     @classmethod
     def map_binding_message_parts(
-        cls, definitions: Definitions, message: str, extended: AnyElement, ns_map: Dict
+        cls, definitions: Definitions, message: str, extended: AnyElement, ns_map: dict
     ) -> Iterator[Attr]:
-        """Find a Message instance and map its parts to attributes according to
-        the extensible element.."""
+        """Find a Message instance and map its parts to attrs.
+
+        Args:
+            definitions: The definitions instance
+            message: The message qualified name
+            extended: The related extended element
+            ns_map: The namespace prefix-URI map
+
+        Yields:
+            An iterator of class attrs.
+        """
         parts = []
         if "part" in extended.attributes:
             parts.append(extended.attributes["part"])
@@ -327,12 +468,15 @@ class DefinitionsMapper:
         yield from cls.build_parts_attributes(message_parts, ns_map)
 
     @classmethod
-    def build_parts_attributes(cls, parts: List[Part], ns_map: Dict) -> Iterator[Attr]:
-        """
-        Build attributes for the given list of parts.
+    def build_parts_attributes(cls, parts: list[Part], ns_map: dict) -> Iterator[Attr]:
+        """Build attributes for the given list of parts.
 
-        :param parts: List of parts
-        :param ns_map: Namespace prefix-URI map
+        Args:
+            parts: A list of part instances
+            ns_map: The namespace prefix-URI map
+
+        Yields:
+            An iterator of class attrs.
         """
         for part in parts:
             if part.element:
@@ -356,7 +500,15 @@ class DefinitionsMapper:
             yield cls.build_attr(name, type_qname, namespace=namespace, native=native)
 
     @classmethod
-    def operation_namespace(cls, config: Dict) -> Optional[str]:
+    def operation_namespace(cls, config: dict) -> str | None:
+        """Return the operation namespace by the operation transport.
+
+        Args:
+            config: The operation configuration
+
+        Returns:
+            The operation namespace string or None if transport is not soap.
+        """
         transport = config.get("transport")
         namespace = None
         if transport == "http://schemas.xmlsoap.org/soap/http":
@@ -365,8 +517,15 @@ class DefinitionsMapper:
         return namespace
 
     @classmethod
-    def attributes(cls, elements: Iterator[AnyElement]) -> Dict:
-        """Return all attributes from all extended elements as a dictionary."""
+    def attributes(cls, elements: Iterator[AnyElement]) -> dict:
+        """Return all attributes from all extended elements as a dictionary.
+
+        Args:
+            elements: An iterator of generic elements
+
+        Returns:
+            A key-value mapping of the xml attributes.
+        """
         return {
             namespaces.local_name(qname): value
             for element in elements
@@ -381,10 +540,24 @@ class DefinitionsMapper:
         qname: str,
         native: bool = False,
         forward: bool = False,
-        namespace: Optional[str] = None,
-        default: Optional[str] = None,
+        namespace: str | None = None,
+        default: str | None = None,
+        reference: int = 0,
     ) -> Attr:
-        """Builder method for attributes."""
+        """Helper method to build an attr instance.
+
+        Args:
+            name: The attr name
+            qname: The attr qualified name
+            native: Whether the type is native
+            forward: Whether the type is a forward reference
+            namespace: The attr namespace
+            default: The attr default value
+            reference: The class id reference, if any
+
+        Returns:
+            The new attr instance.
+        """
         occurs = 1 if default is not None else None
         if native:
             namespace = ""
@@ -394,6 +567,10 @@ class DefinitionsMapper:
             name=name,
             namespace=namespace,
             default=default,
-            types=[AttrType(qname=qname, forward=forward, native=native)],
+            types=[
+                AttrType(
+                    qname=qname, forward=forward, native=native, reference=reference
+                )
+            ],
             restrictions=Restrictions(min_occurs=occurs, max_occurs=occurs),
         )
