@@ -1,13 +1,13 @@
 import re
-import sys
 import textwrap
 from collections import defaultdict
-from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Tuple, Type
+from collections.abc import Callable, Iterable, Iterator
+from typing import Any
 
-from docformatter import configuration, format
 from jinja2 import Environment
 
 from xsdata.codegen.models import Attr, AttrType, Class
+from xsdata.codegen.utils import ClassUtils
 from xsdata.formats.converter import converter
 from xsdata.formats.dataclass.models.elements import XmlType
 from xsdata.models.config import (
@@ -18,48 +18,49 @@ from xsdata.models.config import (
     ObjectType,
     OutputFormat,
 )
+from xsdata.models.enums import Tag
 from xsdata.utils import collections, namespaces, text
 from xsdata.utils.objects import literal_value
 
 
 class Filters:
+    """Jinja filters for code generation."""
+
     DEFAULT_KEY = "default"
     FACTORY_KEY = "default_factory"
-    UNESCAPED_DBL_QUOTE_REGEX = re.compile(r"([^\\])\"")
 
     __slots__ = (
-        "substitutions",
-        "extensions",
         "class_case",
-        "field_case",
-        "constant_case",
-        "package_case",
-        "module_case",
         "class_safe_prefix",
-        "field_safe_prefix",
+        "constant_case",
         "constant_safe_prefix",
-        "package_safe_prefix",
-        "module_safe_prefix",
-        "docstring_style",
-        "max_line_length",
-        "union_type",
-        "subscriptable_types",
-        "relative_imports",
-        "postponed_annotations",
-        "format",
-        "import_patterns",
         "default_class_annotation",
+        "docstring_style",
+        "extensions",
+        "field_case",
+        "field_safe_prefix",
+        "format",
+        "generic_collections",
+        "import_patterns",
+        "max_line_length",
+        "module_case",
+        "module_safe_prefix",
+        "package_case",
+        "package_safe_prefix",
+        "relative_imports",
+        "substitutions",
     )
 
     def __init__(self, config: GeneratorConfig):
-        self.substitutions: Dict[ObjectType, Dict[str, str]] = defaultdict(dict)
+        """Initialize the filters."""
+        self.substitutions: dict[ObjectType, dict[str, str]] = defaultdict(dict)
         for sub in config.substitutions.substitution:
             self.substitutions[sub.type][sub.search] = sub.replace
 
-        self.import_patterns: Dict[str, Dict[str, Set[str]]] = defaultdict(
+        self.import_patterns: dict[str, dict[str, set[str]]] = defaultdict(
             lambda: defaultdict(set)
         )
-        self.extensions: Dict[ExtensionType, List[GeneratorExtension]] = defaultdict(
+        self.extensions: dict[ExtensionType, list[GeneratorExtension]] = defaultdict(
             list
         )
         for ext in config.extensions.extension:
@@ -74,6 +75,7 @@ class Filters:
                 patterns.update(
                     [
                         f"({ext.func_name}",
+                        f", {ext.func_name}",
                         f" {ext.func_name})",
                     ]
                 )
@@ -90,10 +92,8 @@ class Filters:
         self.module_safe_prefix: str = config.conventions.module_name.safe_prefix
         self.docstring_style: DocstringStyle = config.output.docstring_style
         self.max_line_length: int = config.output.max_line_length
-        self.union_type: bool = config.output.union_type
-        self.subscriptable_types: bool = config.output.subscriptable_types
+        self.generic_collections: bool = config.output.generic_collections
         self.relative_imports: bool = config.output.relative_imports
-        self.postponed_annotations: bool = config.output.postponed_annotations
         self.format = config.output.format
 
         # Build things
@@ -103,7 +103,8 @@ class Filters:
 
         self.default_class_annotation = self.build_class_annotation(self.format)
 
-    def register(self, env: Environment):
+    def register(self, env: Environment) -> None:
+        """Register the template filters to the jinja environment."""
         env.globals.update(
             {
                 "docstring_name": self.docstring_style.name.lower(),
@@ -137,6 +138,7 @@ class Filters:
 
     @classmethod
     def build_class_annotation(cls, fmt: OutputFormat) -> str:
+        """Build the class annotations."""
         args = []
         if not fmt.repr:
             args.append("repr=False")
@@ -150,12 +152,13 @@ class Filters:
             args.append("frozen=True")
         if fmt.slots:
             args.append("slots=True")
-        if fmt.kw_only:
-            args.append("kw_only=True")
+
+        args.append("kw_only=True")
 
         return f"@dataclass({', '.join(args)})" if args else "@dataclass"
 
-    def class_params(self, obj: Class):
+    def class_params(self, obj: Class) -> Iterator[tuple[str, str]]:
+        """Yield the class variables with their docstring text."""
         is_enum = obj.is_enumeration
         for attr in obj.attrs:
             name = attr.name
@@ -166,17 +169,26 @@ class Filters:
                 yield self.field_name(name, obj.name), docstring
 
     def class_name(self, name: str) -> str:
-        """Convert the given string to a class name according to the selected
-        conventions or use an existing alias."""
+        """Class name filter.
+
+        Steps:
+            - Apply substitutions before naming conventions
+            - Apply naming convention
+            - Apply substitutions after naming conventions
+
+        Args:
+            name: The original class name
+
+        Returns:
+            The final class name
+        """
         name = self.apply_substitutions(name, ObjectType.CLASS)
         name = self.safe_name(name, self.class_safe_prefix, self.class_case)
         return self.apply_substitutions(name, ObjectType.CLASS)
 
-    def class_bases(self, obj: Class, class_name: str) -> List[str]:
+    def class_bases(self, obj: Class, class_name: str) -> list[str]:
         """Return a list of base class names."""
-        bases = []
-        for obj_ext in obj.extensions:
-            bases.append(self.type_name(obj_ext.type))
+        bases = [self.type_name(x.type) for x in obj.extensions]
 
         derived = len(obj.extensions) > 0
         for ext in self.extensions[ExtensionType.CLASS]:
@@ -189,7 +201,14 @@ class Filters:
 
         return collections.unique_sequence(bases)
 
-    def class_annotations(self, obj: Class, class_name: str) -> List[str]:
+    @classmethod
+    def _parent_match(clazz, ext: GeneratorExtension, obj: Class) -> bool:
+        if not ext.parent_pattern:
+            return True
+        parent_path = ".".join(obj.parent_names())
+        return bool(ext.parent_pattern.match(parent_path))
+
+    def class_annotations(self, obj: Class, class_name: str) -> list[str]:
         """Return a list of decorator names."""
         annotations = []
         if self.default_class_annotation:
@@ -198,7 +217,11 @@ class Filters:
         derived = len(obj.extensions) > 0
         for ext in self.extensions[ExtensionType.DECORATOR]:
             is_valid = not derived or ext.apply_if_derived
-            if is_valid and ext.pattern.match(class_name):
+            if (
+                is_valid
+                and ext.pattern.match(class_name)
+                and self._parent_match(ext, obj)
+            ):
                 if ext.prepend:
                     annotations.insert(0, f"@{ext.func_name}")
                 else:
@@ -207,26 +230,30 @@ class Filters:
         return collections.unique_sequence(annotations)
 
     def apply_substitutions(self, name: str, obj_type: ObjectType) -> str:
+        """Apply name substitutions by obj type."""
         for search, replace in self.substitutions[obj_type].items():
-            name = re.sub(rf"{search}", rf"{replace}", name)
+            name = re.sub(search, replace, name)
 
         return name
 
     def field_definition(
         self,
+        obj: Class,
         attr: Attr,
-        ns_map: Dict,
-        parent_namespace: Optional[str],
-        parents: List[str],
+        parent_namespace: str | None,
     ) -> str:
         """Return the field definition with any extra metadata."""
+        ns_map = obj.ns_map
         default_value = self.field_default_value(attr, ns_map)
-        metadata = self.field_metadata(attr, parent_namespace, parents)
+        metadata = self.field_metadata(obj, attr, parent_namespace)
 
-        kwargs: Dict[str, Any] = {}
+        kwargs: dict[str, Any] = {}
         if attr.fixed or attr.is_prohibited:
             kwargs["init"] = False
 
+            if attr.is_prohibited:
+                kwargs[self.DEFAULT_KEY] = None
+
         if default_value is not False and not attr.is_prohibited:
             key = self.FACTORY_KEY if attr.is_factory else self.DEFAULT_KEY
             kwargs[key] = default_value
@@ -237,11 +264,19 @@ class Filters:
         return f"field({self.format_arguments(kwargs, 4)})"
 
     def field_name(self, name: str, class_name: str) -> str:
-        """
-        Convert the given name to a field name according to the selected
-        conventions or use an existing alias.
+        """Field name filter.
 
-        Provide the class name as context for the naming schemes.
+        Steps:
+            - Apply substitutions before naming conventions
+            - Apply naming convention
+            - Apply substitutions after naming conventions
+
+        Args:
+            name: The original field name
+            class_name: The class name, some naming conventions require it
+
+        Returns:
+            The final field name
         """
         prefix = self.field_safe_prefix
         name = self.apply_substitutions(name, ObjectType.FIELD)
@@ -249,11 +284,19 @@ class Filters:
         return self.apply_substitutions(name, ObjectType.FIELD)
 
     def constant_name(self, name: str, class_name: str) -> str:
-        """
-        Convert the given name to a constant name according to the selected
-        conventions or use an existing alias.
+        """Constant name filter.
 
-        Provide the class name as context for the naming schemes.
+        Steps:
+            - Apply substitutions before naming conventions
+            - Apply naming convention
+            - Apply substitutions after naming conventions
+
+        Args:
+            name: The original constant name
+            class_name: The class name, some naming conventions require it
+
+        Returns:
+            The final constant name
         """
         prefix = self.field_safe_prefix
         name = self.apply_substitutions(name, ObjectType.FIELD)
@@ -261,17 +304,38 @@ class Filters:
         return self.apply_substitutions(name, ObjectType.FIELD)
 
     def module_name(self, name: str) -> str:
-        """Convert the given string to a module name according to the selected
-        conventions or use an existing alias."""
+        """Module name filter.
+
+        Steps:
+            - Apply substitutions before naming conventions
+            - Apply naming convention
+            - Apply substitutions after naming conventions
+
+        Args:
+            name: The original module name
+
+        Returns:
+            The final module name
+        """
         prefix = self.module_safe_prefix
         name = self.apply_substitutions(name, ObjectType.MODULE)
         name = self.safe_name(namespaces.clean_uri(name), prefix, self.module_case)
         return self.apply_substitutions(name, ObjectType.MODULE)
 
     def package_name(self, name: str) -> str:
-        """Convert the given string to a package name according to the selected
-        conventions or use an existing alias."""
+        """Package name filter.
 
+        Steps:
+            - Apply substitutions before naming conventions
+            - Apply naming convention
+            - Apply substitutions after naming conventions
+
+        Args:
+            name: The original package name
+
+        Returns:
+            The final package name
+        """
         name = self.apply_substitutions(name, ObjectType.PACKAGE)
 
         if not name:
@@ -287,7 +351,14 @@ class Filters:
         return self.apply_substitutions(name, ObjectType.PACKAGE)
 
     def type_name(self, attr_type: AttrType) -> str:
-        """Return native python type name or apply class name conventions."""
+        """Field type filter.
+
+        Args:
+            attr_type: The attr type instance.
+
+        Returns:
+            The python type name or the user type final name
+        """
         datatype = attr_type.datatype
         if datatype:
             return datatype.type.__name__
@@ -295,7 +366,11 @@ class Filters:
         return self.class_name(attr_type.alias or attr_type.name)
 
     def safe_name(
-        self, name: str, prefix: str, name_case: Callable, **kwargs: Any
+        self,
+        name: str,
+        prefix: str,
+        name_case: Callable,
+        **kwargs: Any,
     ) -> str:
         """Sanitize names for safe generation."""
         if not name:
@@ -308,7 +383,7 @@ class Filters:
         if not slug or not slug[0].isalpha():
             return self.safe_name(f"{prefix}_{name}", prefix, name_case, **kwargs)
 
-        result = text.variable(name_case(name, **kwargs))
+        result = name_case(name, **kwargs)
         if text.is_reserved(result):
             return self.safe_name(f"{name}_{prefix}", prefix, name_case, **kwargs)
 
@@ -331,30 +406,31 @@ class Filters:
 
         return module
 
-    def import_class(self, name: str, alias: Optional[str]) -> str:
+    def import_class(self, name: str, alias: str | None) -> str:
         """Convert import class name with alias support."""
         if alias:
             return f"{self.class_name(name)} as {self.class_name(alias)}"
 
         return self.class_name(name)
 
-    def post_meta_hook(self, obj: Class) -> Optional[str]:
-        """Plugin hook to render additional information after the xsdata meta
-        class."""
+    def post_meta_hook(self, obj: Class) -> str | None:
+        """Plugin hook to render additional information after the xsdata meta class."""
         return None
 
     def field_metadata(
-        self, attr: Attr, parent_namespace: Optional[str], parents: List[str]
-    ) -> Dict:
+        self,
+        obj: Class,
+        attr: Attr,
+        parent_namespace: str | None,
+    ) -> dict:
         """Return a metadata dictionary for the given attribute."""
-
         if attr.is_prohibited:
             return {"type": XmlType.IGNORE}
 
         name = namespace = None
 
         if not attr.is_nameless and attr.local_name != self.field_name(
-            attr.name, parents[-1]
+            attr.name, obj.name
         ):
             name = attr.local_name
 
@@ -364,29 +440,30 @@ class Filters:
         restrictions = attr.restrictions.asdict(attr.native_types)
 
         metadata = {
+            "wrapper": attr.wrapper,
             "name": name,
             "type": attr.xml_type,
             "namespace": namespace,
             "mixed": attr.mixed,
-            "choices": self.field_choices(attr, parent_namespace, parents),
+            "choices": self.field_choices(obj, attr, parent_namespace),
             **restrictions,
         }
 
+        if not attr.is_attribute or attr.default is None:
+            metadata.pop("required", None)
+
         if self.docstring_style == DocstringStyle.ACCESSIBLE and attr.help:
             metadata["doc"] = self.clean_docstring(attr.help, False)
 
         return self.filter_metadata(metadata)
 
     def field_choices(
-        self, attr: Attr, parent_namespace: Optional[str], parents: List[str]
-    ) -> Optional[Tuple]:
-        """
-        Return a list of metadata dictionaries for the choices of the given
-        attribute.
-
-        Return None if attribute has no choices.
-        """
-
+        self,
+        obj: Class,
+        attr: Attr,
+        parent_namespace: str | None,
+    ) -> tuple | None:
+        """Return a tuple of field metadata if the attr has choices."""
         if not attr.choices:
             return None
 
@@ -399,17 +476,18 @@ class Filters:
             )
 
             metadata = {
-                "name": choice.name,
+                "name": choice.local_name,
                 "wildcard": choice.is_wildcard,
-                "type": self.choice_type(choice, parents),
+                "type": self.choice_type(obj, choice),
                 "namespace": namespace,
             }
 
             if choice.is_nameless:
                 del metadata["name"]
 
-            default_key = self.FACTORY_KEY if choice.is_factory else self.DEFAULT_KEY
-            metadata[default_key] = self.field_default_value(choice)
+            if choice.is_tokens:
+                metadata[self.FACTORY_KEY] = self.field_default_value(choice)
+
             metadata.update(restrictions)
 
             if self.docstring_style == DocstringStyle.ACCESSIBLE and choice.help:
@@ -420,14 +498,15 @@ class Filters:
         return tuple(result)
 
     @classmethod
-    def filter_metadata(cls, data: Dict) -> Dict:
+    def filter_metadata(cls, data: dict) -> dict:
+        """Filter out false,none keys from the given dict."""
         return {
             key: value
             for key, value in data.items()
             if value is not None and value is not False
         }
 
-    def format_arguments(self, data: Dict, indent: int = 0) -> str:
+    def format_arguments(self, data: dict, indent: int = 0) -> str:
         """Return a pretty keyword arguments representation."""
         ind = " " * indent
         fmt = "    {}{}={}"
@@ -451,7 +530,7 @@ class Filters:
 
         return literal_value(data)
 
-    def format_dict(self, data: Dict, indent: int) -> str:
+    def format_dict(self, data: dict, indent: int) -> str:
         """Return a pretty string representation of a dict."""
         ind = " " * indent
         fmt = '    {}"{}": {},'
@@ -473,17 +552,17 @@ class Filters:
         return wrap.format("\n".join(lines), ind)
 
     def format_string(self, data: str, indent: int, key: str = "", pad: int = 0) -> str:
-        """
-        Return a pretty string representation of a string.
+        """Return a pretty string representation of a string.
 
         If the total length of the input string plus indent plus the key
         length and the additional pad is more than the max line length,
         wrap the text into multiple lines, avoiding breaking long words
         """
-        if (data.startswith("Type[") or data.startswith("type[")) and data.endswith(
-            "]"
-        ):
-            return data if data[5] == '"' else data[5:-1]
+        if data.startswith("ForwardRef("):
+            return data
+
+        if data.startswith("Type["):
+            return data[5:-1]
 
         if data.startswith("Literal[") and data.endswith("]"):
             return data[8:-1]
@@ -492,10 +571,7 @@ class Filters:
             return data
 
         if key == "pattern":
-            # escape double quotes because double quotes surround the regex string
-            # in the rendered output
-            value = re.sub(self.UNESCAPED_DBL_QUOTE_REGEX, r'\1\\"', data)
-            return f'r"{value}"'
+            return f"r{data!r}".replace("\\\\", "\\")
 
         if data == "":
             return '""'
@@ -537,17 +613,20 @@ class Filters:
         )
 
     @classmethod
-    def clean_docstring(cls, string: Optional[str], escape: bool = True) -> str:
-        """
-        Prepare string for docstring generation.
+    def clean_docstring(cls, string: str | None, escape: bool = True) -> str:
+        """Prepare string for docstring generation.
 
         - Strip whitespace from each line
         - Replace triple double quotes with single quotes
         - Escape backslashes
 
-        :param string: input value
-        :param escape: skip backslashes escape, if string is going to
-            pass through formatting.
+        Args:
+            string: input value
+            escape: skip backslashes escape, if string is going to
+                pass through formatting.
+
+        Returns:
+            The cleaned docstring text.
         """
         if not string:
             return ""
@@ -561,7 +640,18 @@ class Filters:
         return "\n".join(_clean(line) for line in string.splitlines() if line.strip())
 
     def format_docstring(self, doc_string: str, level: int) -> str:
-        """Format doc strings."""
+        """Format docstrings with proper wrapping.
+
+        Splits text into summary (first sentence) and description (rest),
+        then wraps each appropriately.
+
+        Args:
+            doc_string: The raw docstring from the template
+            level: The indentation level (1 for top-level class, 2+ for nested)
+
+        Returns:
+            The formatted docstring with proper line wrapping.
+        """
         sep_pos = doc_string.rfind('"""')
         if sep_pos == -1:
             return ""
@@ -569,46 +659,90 @@ class Filters:
         content = doc_string[:sep_pos]
         params = doc_string[sep_pos + 3 :].strip()
 
-        if content.strip() == '"""' and not params:
+        # Extract the text (between opening """ and closing """)
+        text = content[3:].strip() if content.startswith('"""') else content.strip()
+
+        # Empty docstring with no params
+        if not text and not params:
             return ""
 
-        content += ' """' if content.endswith('"') else '"""'
+        # Calculate available width for text (accounting for indentation and quotes)
+        indent_width = level * 4
+        wrap_width = self.max_line_length - indent_width - 4
 
-        max_length = self.max_line_length - level * 4
-        configurator = configuration.Configurater(
-            [
-                "--wrap-summaries",
-                str(max_length - 3),
-                "--wrap-descriptions",
-                str(max_length - 7),
-                "--make-summary-multi-line",
-            ]
-        )
-        configurator.do_parse_arguments()
-        formatter = format.Formatter(
-            configurator.args,
-            sys.stderr,
-            sys.stdin,
-            sys.stdout,
-        )
-        content = formatter._do_format_code(content)
+        # Process the text: split into summary and description
+        if text:
+            # Normalize whitespace
+            text = " ".join(text.split())
 
+            # Add period if text doesn't end with punctuation
+            if text and text[-1] not in ".!?:":
+                text += "."
+
+            # Split into summary (first sentence) and description (rest)
+            summary, description = self._split_docstring(text)
+
+            # Wrap summary and description separately
+            wrapped_summary = "\n".join(
+                textwrap.wrap(
+                    summary,
+                    width=wrap_width,
+                    break_long_words=False,
+                    break_on_hyphens=False,
+                )
+            )
+
+            if description:
+                wrapped_description = "\n".join(
+                    textwrap.wrap(
+                        description,
+                        width=wrap_width,
+                        break_long_words=False,
+                        break_on_hyphens=False,
+                    )
+                )
+                wrapped_text = f"{wrapped_summary}\n\n{wrapped_description}"
+            else:
+                wrapped_text = wrapped_summary
+        else:
+            wrapped_text = ""
+
+        # Build the final docstring
         if params:
-            # Remove trailing triple quotes
-            content = content[:-3].strip()
-            new_lines = "\n" if content.endswith('"""') else "\n\n"
-            content += f'{new_lines}{params}\n"""'
+            if wrapped_text:
+                return f'"""\n{wrapped_text}\n\n{params}\n"""'
+            return f'"""\n{params}\n"""'
+        return f'"""\n{wrapped_text}\n"""'
 
-        return content
+    @staticmethod
+    def _split_docstring(text: str) -> tuple[str, str]:
+        """Split docstring text into summary and description.
 
-    def field_default_value(self, attr: Attr, ns_map: Optional[Dict] = None) -> Any:
+        The summary is the first sentence (ending with '. ' followed by
+        a capital letter). The description is everything after.
+
+        Args:
+            text: The normalized docstring text
+
+        Returns:
+            A tuple of (summary, description)
+        """
+        # Look for sentence end: period/exclamation/question followed by
+        # space and a capital letter (start of new sentence)
+        match = re.search(r"[.!?] (?=[A-Z])", text)
+        if match:
+            split_pos = match.start() + 1  # Include the punctuation
+            return text[:split_pos], text[split_pos:].strip()
+        return text, ""
+
+    def field_default_value(self, attr: Attr, ns_map: dict | None = None) -> Any:
         """Generate the field default value/factory for the given attribute."""
         if attr.is_list or (attr.is_tokens and not attr.default):
             return "tuple" if self.format.frozen else "list"
         if attr.is_dict:
             return "dict"
         if attr.default is None:
-            return False if self.format.kw_only and not attr.is_optional else None
+            return None if attr.is_optional else False
         if not isinstance(attr.default, str):
             return literal_value(attr.default)
         if attr.default.startswith("@enum@"):
@@ -626,6 +760,7 @@ class Filters:
         )
 
     def field_default_enum(self, attr: Attr) -> str:
+        """Generate the default value for enum fields."""
         assert attr.default is not None
 
         qname, reference = attr.default[6:].split("::", 1)
@@ -643,8 +778,9 @@ class Filters:
         return f"{class_name}.{self.constant_name(reference, name)}"
 
     def field_default_tokens(
-        self, attr: Attr, types: List[Type], ns_map: Optional[Dict]
+        self, attr: Attr, types: list[type], ns_map: dict | None
     ) -> str:
+        """Generate the default value for tokens fields."""
         assert isinstance(attr.default, str)
 
         fmt = attr.restrictions.format
@@ -659,15 +795,17 @@ class Filters:
 
         return f"lambda: {self.format_metadata(tokens, indent=8)}"
 
-    def field_type(self, attr: Attr, parents: List[str]) -> str:
-        """Generate type hints for the given attribute."""
-
+    def field_type(self, obj: Class, attr: Attr) -> str:
+        """Generate type hints for the given attr."""
         if attr.is_prohibited:
             return "Any"
 
-        result = self.field_type_names(attr, parents, choice=False)
+        if attr.tag == Tag.CHOICE:
+            return self.compound_field_types(obj, attr)
 
-        iterable_fmt = self.get_iterable_format()
+        result = self._field_type_names(obj, attr, choice=False)
+
+        iterable_fmt = self._get_iterable_format()
         if attr.is_tokens:
             result = iterable_fmt.format(result)
 
@@ -678,18 +816,46 @@ class Filters:
             return result
 
         if attr.is_dict:
-            return "dict[str, str]" if self.subscriptable_types else "Dict[str, str]"
+            if self.generic_collections:
+                return "Mapping[str, str]"
 
-        if attr.is_nillable or (
-            attr.default is None and (attr.is_optional or not self.format.kw_only)
-        ):
-            return f"None | {result}" if self.union_type else f"Optional[{result}]"
+            return "dict[str, str]"
+
+        if attr.is_nillable or (attr.default is None and attr.is_optional):
+            return f"None | {result}"
 
         return result
 
-    def choice_type(self, choice: Attr, parents: List[str]) -> str:
+    def compound_field_types(self, obj: Class, attr: Attr) -> str:
+        """Generate type hint for a compound field.
+
+        Args:
+            obj: The parent class instance
+            attr: The compound attr instance
+
+        Returns:
+            The string representation of the type hint.
         """
-        Generate type hints for the given choice.
+        results = []
+        iterable_fmt = self._get_iterable_format()
+        for choice in attr.choices:
+            names = self._field_type_names(obj, choice, choice=False)
+            if choice.is_tokens:
+                names = iterable_fmt.format(names)
+            results.append(names)
+
+        result = self._join_type_names(results)
+
+        if attr.is_list:
+            return iterable_fmt.format(result)
+
+        if attr.is_optional:
+            return f"None | {result}"
+
+        return result
+
+    def choice_type(self, obj: Class, choice: Attr) -> str:
+        """Generate type hints for the given choice.
 
         Choices support a subset of features from normal attributes.
         First of all we don't have a proper type hint but a type
@@ -697,52 +863,53 @@ class Filters:
         The second big difference is that our choice belongs to a
         compound field that might be a list, that's why list restriction
         is also ignored.
-        """
 
-        result = self.field_type_names(choice, parents, choice=True)
+        Args:
+            obj: The parent class instance
+            choice: The choice instance
+
+        Returns:
+            The string representation of the type hint.
+        """
+        result = self._field_type_names(obj, choice, choice=True)
 
         if choice.is_tokens:
-            iterable_fmt = self.get_iterable_format()
+            iterable_fmt = self._get_iterable_format()
             result = iterable_fmt.format(result)
 
-        if self.subscriptable_types:
-            return f"type[{result}]"
+        if result.startswith('"'):
+            return f"ForwardRef({result})"
 
         return f"Type[{result}]"
 
-    def field_type_names(
-        self, attr: Attr, parents: List[str], choice: bool = False
+    def _field_type_names(
+        self,
+        obj: Class,
+        attr: Attr,
+        choice: bool = False,
     ) -> str:
-        type_names = [
-            self.field_type_name(x, parents, choice=choice) for x in attr.types
-        ]
-        return self.join_type_names(type_names)
+        type_names = [self._field_type_name(obj, x, choice=choice) for x in attr.types]
+        return self._join_type_names(type_names)
 
-    def join_type_names(self, type_names: List[str]) -> str:
+    def _join_type_names(self, type_names: list[str]) -> str:
         type_names = collections.unique_sequence(type_names)
         if len(type_names) == 1:
             return type_names[0]
 
-        if self.union_type:
-            return " | ".join(type_names)
+        return " | ".join(type_names)
 
-        return f'Union[{", ".join(type_names)}]'
-
-    def field_type_name(
-        self, attr_type: AttrType, parents: List[str], choice: bool = False
+    def _field_type_name(
+        self, obj: Class, attr_type: AttrType, choice: bool = False
     ) -> str:
         name = self.type_name(attr_type)
-
-        if attr_type.forward and attr_type.circular:
-            outer_str = ".".join(map(self.class_name, parents))
-            name = f'"{outer_str}"'
-        elif attr_type.forward:
-            outer_str = ".".join(map(self.class_name, parents))
+        if attr_type.forward:
+            inner = ClassUtils.find_nested(obj, attr_type.qname)
+            outer_str = ".".join(map(self.class_name, inner.parent_names()))
             name = f'"{outer_str}.{name}"'
         elif attr_type.circular:
             name = f'"{name}"'
 
-        if self.postponed_annotations and not choice:
+        if not choice:
             name = name.strip('"')
 
         return name
@@ -760,8 +927,7 @@ class Filters:
 
     def default_imports(self, output: str) -> str:
         """Generate the default imports for the given package output."""
-        module_imports = set()
-        func_imports = set()
+        imports = ["from __future__ import annotations"]
         for library, types in self.import_patterns.items():
             names = [
                 name
@@ -770,36 +936,34 @@ class Filters:
             ]
 
             if len(names) == 1 and names[0] == "__module__":
-                module_imports.add(f"import {library}")
+                imports.append(f"import {library}")
             elif names:
-                func_imports.add(f"from {library} import {', '.join(names)}")
+                imports.append(f"from {library} import {', '.join(names)}")
 
-        imports = sorted(module_imports) + sorted(func_imports)
-        if self.postponed_annotations:
-            imports.insert(0, "from __future__ import annotations")
+        return "\n".join(collections.unique_sequence(imports))
 
-        return "\n".join(imports)
+    def _get_iterable_format(self) -> str:
+        if self.generic_collections:
+            return "Sequence[{}]"
 
-    def get_iterable_format(self):
-        fmt = "Tuple[{}, ...]" if self.format.frozen else "List[{}]"
-        return fmt.lower() if self.subscriptable_types else fmt
+        return "tuple[{}, ...]" if self.format.frozen else "list[{}]"
 
     @classmethod
-    def build_import_patterns(cls) -> Dict[str, Dict]:
+    def build_import_patterns(cls) -> dict[str, dict]:
+        """Build import search patterns."""
         type_patterns = cls.build_type_patterns
         return {
             "dataclasses": {"dataclass": ["@dataclass"], "field": [" = field("]},
             "decimal": {"Decimal": type_patterns("Decimal")},
             "enum": {"Enum": ["(Enum)"]},
             "typing": {
-                "Dict": [": Dict"],
-                "List": [": List["],
-                "Optional": ["Optional["],
-                "Tuple": ["Tuple["],
-                "Type": ["Type["],
-                "Union": ["Union["],
+                "ForwardRef": [": ForwardRef("],
                 "Any": type_patterns("Any"),
             },
+            "collections.abc": {
+                "Sequence": [": Sequence["],
+                "Mapping": [": Mapping["],
+            },
             "xml.etree.ElementTree": {"QName": type_patterns("QName")},
             "xsdata.models.datatype": {
                 "XmlDate": type_patterns("XmlDate"),
@@ -811,7 +975,8 @@ class Filters:
         }
 
     @classmethod
-    def build_type_patterns(cls, x: str) -> Tuple:
+    def build_type_patterns(cls, x: str) -> tuple[str, ...]:
+        """Return all possible type occurrences in the generated code."""
         return (
             f": {x} =",
             f"[{x}]",
