@@ -1,19 +1,10 @@
+import inspect
 import sys
 from collections import defaultdict
+from collections.abc import Callable, Iterator, Mapping, Sequence
 from enum import Enum
 from typing import (
     Any,
-    Callable,
-    Dict,
-    Iterator,
-    List,
-    Mapping,
-    NamedTuple,
-    Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Type,
     get_type_hints,
 )
 
@@ -21,28 +12,87 @@ from xsdata.exceptions import XmlContextError
 from xsdata.formats.converter import converter
 from xsdata.formats.dataclass.compat import ClassType
 from xsdata.formats.dataclass.models.elements import XmlMeta, XmlType, XmlVar
-from xsdata.formats.dataclass.typing import evaluate
+from xsdata.formats.dataclass.typing import (
+    evaluate,
+    evaluate_attribute,
+    evaluate_attributes,
+    evaluate_element,
+    evaluate_elements,
+    evaluate_text,
+    evaluate_wildcard,
+)
 from xsdata.models.enums import NamespaceType
 from xsdata.utils.collections import first
 from xsdata.utils.constants import EMPTY_SEQUENCE, return_input
 from xsdata.utils.namespaces import build_qname
 
+evaluations: dict[str, Callable] = {
+    XmlType.TEXT: evaluate_text,
+    XmlType.ELEMENT: evaluate_element,
+    XmlType.ELEMENTS: evaluate_elements,
+    XmlType.WILDCARD: evaluate_wildcard,
+    XmlType.ATTRIBUTE: evaluate_attribute,
+    XmlType.ATTRIBUTES: evaluate_attributes,
+}
 
-class ClassMeta(NamedTuple):
-    element_name_generator: Callable
-    attribute_name_generator: Callable
-    qname: str
-    local_name: str
-    nillable: bool
-    namespace: Optional[str]
-    target_qname: Optional[str]
+
+class ClassMeta:
+    """The binding model combined metadata.
+
+    Args:
+        element_name_generator: The element name generator
+        attribute_name_generator: The attribute name generator
+        qname: The namespace qualified name of the class
+        local_name: The name of the element this class represents
+        nillable: Specifies whether this class supports nillable content
+        namespace: The class namespace
+        target_qname: The class target namespace qualified name
+    """
+
+    __slots__ = (
+        "attribute_name_generator",
+        "element_name_generator",
+        "local_name",
+        "namespace",
+        "nillable",
+        "qname",
+        "target_qname",
+    )
+
+    def __init__(
+        self,
+        element_name_generator: Callable,
+        attribute_name_generator: Callable,
+        qname: str,
+        local_name: str,
+        nillable: bool,
+        namespace: str | None,
+        target_qname: str | None,
+    ):
+        """Initialize class meta."""
+        self.element_name_generator = element_name_generator
+        self.attribute_name_generator = attribute_name_generator
+        self.qname = qname
+        self.local_name = local_name
+        self.nillable = nillable
+        self.namespace = namespace
+        self.target_qname = target_qname
 
 
 class XmlMetaBuilder:
+    """Binding class metadata builder.
+
+    Args:
+        class_type: The supported class type, e.g. dataclass, attr, pydantic
+        element_name_generator: The default element name generator
+        attribute_name_generator: The default attribute name generator
+        globalns: The global namespace
+    """
+
     __slots__ = (
+        "attribute_name_generator",
         "class_type",
         "element_name_generator",
-        "attribute_name_generator",
         "globalns",
     )
 
@@ -51,15 +101,24 @@ class XmlMetaBuilder:
         class_type: ClassType,
         element_name_generator: Callable,
         attribute_name_generator: Callable,
-        globalns: Optional[Dict[str, Callable]] = None,
+        globalns: dict[str, Callable] | None = None,
     ):
+        """Initialize the builder."""
         self.class_type = class_type
         self.element_name_generator = element_name_generator
         self.attribute_name_generator = attribute_name_generator
         self.globalns = globalns
 
-    def build(self, clazz: Type, parent_namespace: Optional[str]) -> XmlMeta:
-        """Build the binding metadata for a dataclass and its fields."""
+    def build(self, clazz: type, parent_namespace: str | None) -> XmlMeta:
+        """Build the binding metadata for a dataclass and its fields.
+
+        Args:
+            clazz: The target class
+            parent_namespace: The parent class namespace
+
+        Returns:
+            The binding metadata instance.
+        """
         self.class_type.verify_model(clazz)
 
         meta = self.build_class_meta(clazz, parent_namespace)
@@ -71,20 +130,20 @@ class XmlMetaBuilder:
         )
 
         attributes = {}
-        elements: Dict[str, List[XmlVar]] = defaultdict(list)
+        elements: dict[str, list[XmlVar]] = defaultdict(list)
+        wrappers: dict[str, str] = {}
         choices = []
         any_attributes = []
         wildcards = []
-        wrappers: Dict[str, List[XmlVar]] = defaultdict(list)
         text = None
 
         for var in class_vars:
-            if var.wrapper is not None:
-                wrappers[var.wrapper].append(var)
             if var.is_attribute:
                 attributes[var.qname] = var
             elif var.is_element:
                 elements[var.qname].append(var)
+                if var.wrapper_qname:
+                    wrappers[var.wrapper_qname] = var.qname
             elif var.is_elements:
                 choices.append(var)
             elif var.is_attributes:
@@ -110,12 +169,22 @@ class XmlMetaBuilder:
 
     def build_vars(
         self,
-        clazz: Type,
-        namespace: Optional[str],
+        clazz: type,
+        namespace: str | None,
         element_name_generator: Callable,
         attribute_name_generator: Callable,
-    ):
-        """Build the binding metadata for the given dataclass fields."""
+    ) -> Iterator[XmlVar]:
+        """Build the binding metadata for the given dataclass fields.
+
+        Args:
+            clazz: The target class
+            namespace: The target class namespace
+            element_name_generator: The class element name generator
+            attribute_name_generator: The class attribute name generator
+
+        Yields:
+            An iterator of the field binding metadata instances.
+        """
         type_hints = get_type_hints(clazz, globalns=self.globalns)
         builder = XmlVarBuilder(
             class_type=self.class_type,
@@ -132,6 +201,7 @@ class XmlMetaBuilder:
                 parent_namespace = getattr(real_clazz.Meta, "namespace", namespace)
 
             var = builder.build(
+                clazz,
                 field.name,
                 type_hints[field.name],
                 field.metadata,
@@ -144,12 +214,20 @@ class XmlMetaBuilder:
                 yield var
 
     def build_class_meta(
-        self, clazz: Type, parent_namespace: Optional[str] = None
+        self,
+        clazz: Any,
+        parent_namespace: str | None = None,
     ) -> ClassMeta:
-        """
-        Fetch the class meta options and merge defaults.
+        """Build the class meta options and merge with the defaults.
 
-        Metaclass is not inheritable
+        The class metaclass is not inheritable.
+
+        Args:
+            clazz: The target class
+            parent_namespace: The parent class namespace
+
+        Returns:
+            A class meta instance.
         """
         meta = clazz.Meta if "Meta" in clazz.__dict__ else None
         element_name_generator = getattr(
@@ -183,21 +261,26 @@ class XmlMetaBuilder:
         )
 
     @classmethod
-    def find_declared_class(cls, clazz: Type, name: str) -> Type:
+    def find_declared_class(cls, clazz: type, name: str) -> Any:
+        """Find the user class that matches the name.
+
+        Todo: Honestly I have no idea why we needed this.
+        """
         for base in clazz.__mro__:
-            ann = base.__dict__.get("__annotations__")
+            ann = inspect.get_annotations(base)
+
             if ann and name in ann:
                 return base
 
         raise XmlContextError(f"Failed to detect the declared class for field {name}")
 
     @classmethod
-    def is_inner_class(cls, clazz: Type) -> bool:
+    def is_inner_class(cls, clazz: type) -> bool:
         """Return whether the given type is nested inside another type."""
         return "." in clazz.__qualname__
 
     @classmethod
-    def target_namespace(cls, module: Any, meta: Any) -> Optional[str]:
+    def target_namespace(cls, module: Any, meta: Any) -> str | None:
         """The target namespace this class metadata was defined in."""
         namespace = getattr(meta, "target_namespace", None)
         if namespace is not None:
@@ -209,10 +292,16 @@ class XmlMetaBuilder:
 
         return getattr(meta, "namespace", None)
 
-    def default_xml_type(self, clazz: Type) -> str:
-        """Return the default xml type for the fields of the given dataclass
-        with an undefined type."""
-        counters: Dict[str, int] = defaultdict(int)
+    def default_xml_type(self, clazz: type) -> str:
+        """Return the default xml type for the fields of the given dataclass.
+
+        If a class has fields with no xml type defined, attempt
+        to figure it from the rest of the fields. It's either
+        a text or an element field.
+
+        # Todo hacks like this are so unnecessary...
+        """
+        counters: dict[str, int] = defaultdict(int)
         for var in self.class_type.get_fields(clazz):
             xml_type = var.metadata.get("type")
             counters[xml_type or "undefined"] += 1
@@ -229,12 +318,24 @@ class XmlMetaBuilder:
 
 
 class XmlVarBuilder:
+    """Binding class field metadata builder.
+
+    Args:
+        class_type: The supported class type, e.g. dataclass, attr, pydantic
+        default_xml_type: The default xml type of this class fields
+        element_name_generator: The element name generator
+        attribute_name_generator: The attribute name generator
+
+    Attributes:
+        index: The index of the next var
+    """
+
     __slots__ = (
-        "index",
+        "attribute_name_generator",
         "class_type",
         "default_xml_type",
         "element_name_generator",
-        "attribute_name_generator",
+        "index",
     )
 
     def __init__(
@@ -244,6 +345,7 @@ class XmlVarBuilder:
         element_name_generator: Callable = return_input,
         attribute_name_generator: Callable = return_input,
     ):
+        """Initialize the builder."""
         self.index = 0
         self.class_type = class_type
         self.default_xml_type = default_xml_type
@@ -252,16 +354,32 @@ class XmlVarBuilder:
 
     def build(
         self,
+        model: type,
         name: str,
         type_hint: Any,
         metadata: Mapping[str, Any],
         init: bool,
-        parent_namespace: Optional[str],
+        parent_namespace: str | None,
         default_value: Any,
         globalns: Any,
-        factory: Optional[Callable] = None,
-    ) -> Optional[XmlVar]:
-        """Build the binding metadata for a dataclass field."""
+        parent_factory: Callable | None = None,
+    ) -> XmlVar | None:
+        """Build the binding metadata for a class field.
+
+        Args:
+            model: The model class
+            name: The model field name
+            type_hint: The typing annotations of the field
+            metadata: The field metadata mapping
+            init: Specify whether this field can be initialized
+            parent_namespace: The class namespace
+            default_value: The field default value or factory
+            globalns: Python's global namespace
+            parent_factory: The value factory
+
+        Returns:
+            The field binding metadata instance.
+        """
         xml_type = metadata.get("type", self.default_xml_type)
         if xml_type == XmlType.IGNORE:
             return None
@@ -272,50 +390,46 @@ class XmlVarBuilder:
         choices = metadata.get("choices", EMPTY_SEQUENCE)
         mixed = metadata.get("mixed", False)
         process_contents = metadata.get("process_contents", "strict")
-        required = metadata.get("required", False)
         nillable = metadata.get("nillable", False)
         format_str = metadata.get("format", None)
         sequence = metadata.get("sequence", None)
         wrapper = metadata.get("wrapper", None)
 
-        origin, sub_origin, types = self.analyze_types(type_hint, globalns)
+        annotation = evaluate(type_hint, globalns)
 
-        if not self.is_valid(xml_type, origin, sub_origin, types, tokens, init):
+        try:
+            result = evaluations[xml_type](annotation, tokens=tokens)
+            types = tuple(converter.sort_types(result.types))
+            if not self.is_typing_supported(types):
+                raise TypeError
+
+        except TypeError:
             raise XmlContextError(
-                f"Xml type '{xml_type}' does not support typing: {type_hint}"
+                f"Error on {model.__qualname__}::{name}: "
+                f"Xml {xml_type} does not support typing `{type_hint}`"
             )
 
-        if wrapper is not None and (
-            not isinstance(origin, type) or not issubclass(origin, (list, set, tuple))
-        ):
-            raise XmlContextError(
-                f"a wrapper requires a collection type on attribute {name}"
-            )
-
-        local_name = self.build_local_name(xml_type, local_name, name)
-
-        if tokens and sub_origin is None:
-            sub_origin = origin
-            origin = None
-
-        if origin is None:
-            origin = factory
+        factory = result.factory or parent_factory
+        tokens_factory = result.tokens_factory
+        required = not result.optional
+        if xml_type == XmlType.ATTRIBUTE and default_value is not None:
+            required = metadata.get("required", False)
+        elif tokens or factory:
+            required = False
 
+        local_name = local_name or self.build_local_name(xml_type, name)
         any_type = self.is_any_type(types, xml_type)
         clazz = first(tp for tp in types if self.class_type.is_model(tp))
         namespaces = self.resolve_namespaces(xml_type, namespace, parent_namespace)
-        default_namespace = self.default_namespace(namespaces)
-        qname = build_qname(default_namespace, local_name)
-        if wrapper is not None:
-            wrapper = build_qname(default_namespace, wrapper)
 
         elements = {}
         wildcards = []
         self.index += 1
         cur_index = self.index
         for choice in self.build_choices(
-            name, choices, origin, globalns, parent_namespace
+            model, name, choices, factory, globalns, parent_namespace
         ):
+            choice.required = False
             if choice.is_element:
                 elements[choice.qname] = choice
             else:  # choice.is_wildcard:
@@ -324,7 +438,8 @@ class XmlVarBuilder:
         return XmlVar(
             index=cur_index,
             name=name,
-            qname=qname,
+            local_name=local_name,
+            wrapper=wrapper,
             init=init,
             mixed=mixed,
             format=format_str,
@@ -334,28 +449,39 @@ class XmlVarBuilder:
             required=required,
             nillable=nillable,
             sequence=sequence,
-            factory=origin,
-            tokens_factory=sub_origin,
+            factory=factory,
+            tokens_factory=tokens_factory,
             default=default_value,
             types=types,
             elements=elements,
             wildcards=wildcards,
             namespaces=namespaces,
             xml_type=xml_type,
-            derived=False,
-            wrapper=wrapper,
         )
 
     def build_choices(
         self,
+        model: type,
         name: str,
-        choices: List[Dict],
-        factory: Callable,
+        choices: list[dict],
+        factory: Callable | None,
         globalns: Any,
-        parent_namespace: Optional[str],
+        parent_namespace: str | None,
     ) -> Iterator[XmlVar]:
-        """Build the binding metadata for a compound dataclass field."""
-        existing_types: Set[type] = set()
+        """Build the binding metadata for a compound dataclass field.
+
+        Args:
+            model: The model class
+            name: The model field name
+            choices: The list of choice metadata
+            factory: The compound field values factory
+            globalns: Python's global namespace
+            parent_namespace: The class namespace
+
+        Yields:
+            An iterator of field choice binding metadata instance.
+        """
+        existing_types: set[type] = set()
 
         for choice in choices:
             default_value = self.class_type.default_choice_value(choice)
@@ -370,6 +496,7 @@ class XmlVarBuilder:
                 metadata["type"] = XmlType.ELEMENT
 
             var = self.build(
+                model,
                 name,
                 type_hint,
                 metadata,
@@ -383,36 +510,39 @@ class XmlVarBuilder:
             # It's impossible for choice elements to be ignorable, read above!
             assert var is not None
 
-            if var.any_type or any(True for tp in var.types if tp in existing_types):
-                var.derived = True
+            if any(True for tp in var.types if tp in existing_types):
+                raise XmlContextError(
+                    f"Error on {model.__qualname__}::{name}: "
+                    f"Compound field contains ambiguous types"
+                )
 
             existing_types.update(var.types)
 
             yield var
 
-    def build_local_name(
-        self, xml_type: str, local_name: Optional[str], name: str
-    ) -> str:
-        """Build a local name based on the field name and xml type if it's not
-        set."""
-        if not local_name:
-            if xml_type == XmlType.ATTRIBUTE:
-                return self.attribute_name_generator(name)
+    def build_local_name(self, xml_type: str, name: str) -> str:
+        """Transform the name for serialization by the target xml type.
 
-            return self.element_name_generator(name)
+        Args:
+            xml_type: The xml type: element, attribute, ...
+            name: The field name
 
-        return local_name
+        Returns:
+            The name to use for serialization.
+        """
+        if xml_type == XmlType.ATTRIBUTE:
+            return self.attribute_name_generator(name)
+
+        return self.element_name_generator(name)
 
     @classmethod
     def resolve_namespaces(
         cls,
-        xml_type: Optional[str],
-        namespace: Optional[str],
-        parent_namespace: Optional[str],
-    ) -> Tuple[str, ...]:
-        """
-        Resolve the namespace(s) for the given xml type and the parent
-        namespace.
+        xml_type: str | None,
+        namespace: str | None,
+        parent_namespace: str | None,
+    ) -> tuple[str, ...]:
+        """Resolve a fields supported namespaces.
 
         Only elements and wildcards are allowed to inherit the parent
         namespace if the given namespace is empty.
@@ -420,10 +550,13 @@ class XmlVarBuilder:
         In case of wildcard try to decode the ##any, ##other, ##local,
         ##target.
 
-        :param xml_type: The xml type
-            (Text|Element(s)|Attribute(s)|Wildcard)
-        :param namespace: The field namespace
-        :param parent_namespace: The parent namespace
+        Args:
+            xml_type: The xml type (Text|Element(s)|Attribute(s)|Wildcard)
+            namespace: The field namespace
+            parent_namespace: The parent namespace
+
+        Returns:
+            A tuple of supported namespaces.
         """
         if xml_type in (XmlType.ELEMENT, XmlType.WILDCARD) and namespace is None:
             namespace = parent_namespace
@@ -445,93 +578,15 @@ class XmlVarBuilder:
         return tuple(result)
 
     @classmethod
-    def default_namespace(cls, namespaces: Sequence[str]) -> Optional[str]:
-        """
-        Return the first valid namespace uri or None.
-
-        :param namespaces: A list of namespace options which may include
-            valid uri(s) or one of the ##any, ##other,
-            ##targetNamespace, ##local
-        """
-        for namespace in namespaces:
-            if namespace and not namespace.startswith("#"):
-                return namespace
-
-        return None
-
-    @classmethod
-    def is_any_type(cls, types: Sequence[Type], xml_type: str) -> bool:
-        """Return whether the given xml type supports derived values."""
+    def is_any_type(cls, types: Sequence[type], xml_type: str) -> bool:
+        """Return whether the given xml type supports generic values."""
         if xml_type in (XmlType.ELEMENT, XmlType.ELEMENTS):
             return object in types
 
         return False
 
-    @classmethod
-    def analyze_types(
-        cls, type_hint: Any, globalns: Any
-    ) -> Tuple[Any, Any, Tuple[Type, ...]]:
-        """
-        Analyze a type hint and return the origin, sub origin and the type
-        args.
-
-        The only case we support a sub origin is for fields derived from
-        xs:NMTOKENS!
-
-        :raises XmlContextError: if the typing is not supported for
-            binding
-        """
-        try:
-            types = evaluate(type_hint, globalns)
-            origin = None
-            sub_origin = None
-
-            while types[0] in (tuple, list, dict):
-                if origin is None:
-                    origin = types[0]
-                elif sub_origin is None:
-                    sub_origin = types[0]
-                else:
-                    raise TypeError()
-
-                types = types[1:]
-
-            return origin, sub_origin, tuple(converter.sort_types(types))
-        except Exception:
-            raise XmlContextError(f"Unsupported typing: {type_hint}")
-
-    def is_valid(
-        self,
-        xml_type: str,
-        origin: Any,
-        sub_origin: Any,
-        types: Sequence[Type],
-        tokens: bool,
-        init: bool,
-    ) -> bool:
-        """Validate the given xml type against common unsupported cases."""
-
-        if not init:
-            # Ignore init==false vars
-            return True
-
-        if xml_type == XmlType.ATTRIBUTES:
-            # Attributes need origin dict, no sub origin and tokens
-            if origin is not dict or sub_origin or tokens:
-                return False
-        elif origin is dict or tokens and origin not in (list, tuple):
-            # Origin dict is only supported by Attributes
-            # xs:NMTOKENS need origin list
-            return False
-
-        if object in types and xml_type != XmlType.ELEMENTS:
-            # Any type, secondary types are not allowed except for 'Elements' XML type
-            return len(types) == 1
-
-        return self.is_typing_supported(types)
-
-    def is_typing_supported(self, types: Sequence[Type]) -> bool:
-        # Validate all types are registered in the converter.
+    def is_typing_supported(self, types: Sequence[type]) -> bool:
+        """Validate all types are registered in the converter."""
         for tp in types:
             if (
                 not self.class_type.is_model(tp)
