@@ -2,7 +2,8 @@ import datetime
 import operator
 import re
 from collections import UserString
-from typing import Any, Callable, Dict, NamedTuple, Optional, Union
+from collections.abc import Callable
+from typing import Any, NamedTuple
 
 from xsdata.utils.dates import (
     calculate_offset,
@@ -31,6 +32,8 @@ DS_OFFSET = -60
 
 
 class DateFormat:
+    """Xml date formats."""
+
     DATE = "%Y-%m-%d%z"
     TIME = "%H:%M:%S%z"
     DATE_TIME = "%Y-%m-%dT%H:%M:%S%z"
@@ -42,34 +45,31 @@ class DateFormat:
 
 
 class XmlDate(NamedTuple):
-    """
-    Concrete xs:date builtin type.
+    """Concrete xs:date builtin type.
 
     Represents iso 8601 date format [-]CCYY-MM-DD[Z|(+|-)hh:mm] with
     rich comparisons and hashing.
 
-    :param year: Any signed integer, eg (0, -535, 2020)
-    :param month: Unsigned integer between 1-12
-    :param day: Unsigned integer between 1-31
-    :param offset: Signed integer representing timezone offset in
-        minutes
+    Attributes:
+        year: Any signed integer, eg (0, -535, 2020)
+        month: Unsigned integer between 1-12
+        day: Unsigned integer between 1-31
+        offset: Signed integer representing timezone offset in minutes
     """
 
     year: int
     month: int
     day: int
-    offset: Optional[int] = None
+    offset: int | None = None
 
     def replace(
         self,
-        year: Optional[int] = None,
-        month: Optional[int] = None,
-        day: Optional[int] = None,
-        offset: Optional[int] = True,
+        year: int | None = None,
+        month: int | None = None,
+        day: int | None = None,
+        offset: int | None = True,
     ) -> "XmlDate":
-        """Return a new instance replacing the specified fields with new
-        values."""
-
+        """Return a new instance replacing the specified fields with new values."""
         if year is None:
             year = self.year
         if month is None:
@@ -83,51 +83,52 @@ class XmlDate(NamedTuple):
 
     @classmethod
     def from_string(cls, string: str) -> "XmlDate":
-        """Initialize from string with format ``%Y-%m-%dT%z``"""
-        return cls(*parse_date_args(string, DateFormat.DATE))
+        """Initialize from string with format `%Y-%m-%dT%z`."""
+        year, month, day, offset = parse_date_args(string, DateFormat.DATE)
+        assert year is not None
+        assert month is not None
+        assert day is not None
+        return cls(year, month, day, offset)
 
     @classmethod
     def from_date(cls, obj: datetime.date) -> "XmlDate":
-        """
-        Initialize from :class:`datetime.date` instance.
-
-        .. warning::
-
-            date instances don't have timezone information!
-        """
+        """Initialize from a `datetime.date` instance."""
         return cls(obj.year, obj.month, obj.day)
 
     @classmethod
     def from_datetime(cls, obj: datetime.datetime) -> "XmlDate":
-        """Initialize from :class:`datetime.datetime` instance."""
+        """Initialize from `datetime.datetime` instance."""
         return cls(obj.year, obj.month, obj.day, calculate_offset(obj))
 
     @classmethod
     def today(cls) -> "XmlDate":
-        """Initialize from datetime.date.today()"""
+        """Initialize with the current date."""
         return cls.from_date(datetime.date.today())
 
     def to_date(self) -> datetime.date:
-        """Return a :class:`datetime.date` instance."""
+        """Convert to a :`datetime.date` instance."""
         return datetime.date(self.year, self.month, self.day)
 
     def to_datetime(self) -> datetime.datetime:
-        """Return a :class:`datetime.datetime` instance."""
+        """Convert to a `datetime.datetime` instance."""
         tz_info = calculate_timezone(self.offset)
         return datetime.datetime(self.year, self.month, self.day, tzinfo=tz_info)
 
     def __str__(self) -> str:
-        """
-        Return the date formatted according to ISO 8601 for xml.
+        """Return the date formatted according to ISO 8601 for xml.
 
         Examples:
             - 2001-10-26
             - 2001-10-26+02:00
             - 2001-10-26Z
+
+        Returns:
+            The str result.
         """
         return format_date(self.year, self.month, self.day) + format_offset(self.offset)
 
     def __repr__(self) -> str:
+        """Return the instance string representation."""
         args = [self.year, self.month, self.day, self.offset]
         if args[-1] is None:
             del args[-1]
@@ -136,20 +137,20 @@ class XmlDate(NamedTuple):
 
 
 class XmlDateTime(NamedTuple):
-    """
-    Concrete xs:dateTime builtin type.
+    """Concrete xs:dateTime builtin type.
 
-    Represents iso 8601 date time format [-]CCYY-MM-DDThh
-    :mm: ss[Z|(+|-)hh:mm] with rich comparisons and hashing.
-    :param year: Any signed integer, eg (0, -535, 2020)
-    :param month: Unsigned integer between 1-12
-    :param day: Unsigned integer between 1-31
-    :param hour: Unsigned integer between 0-24
-    :param minute: Unsigned integer between 0-59
-    :param second: Unsigned integer between 0-59
-    :param fractional_second: Unsigned integer between 0-999999999
-    :param offset: Signed integer representing timezone offset in
-        minutes
+    Represents iso 8601 date time format `[-]CCYY-MM-DDThh:mm: ss[Z|(+|-)hh:mm]`
+    with rich comparisons and hashing.
+
+    Attributes:
+        year: Any signed integer, eg (0, -535, 2020)
+        month: Unsigned integer between 1-12
+        day: Unsigned integer between 1-31
+        hour: Unsigned integer between 0-24
+        minute: Unsigned integer between 0-59
+        second: Unsigned integer between 0-59
+        fractional_second: Unsigned integer between 0-999999999
+        offset: Signed integer representing timezone offset in minutes
     """
 
     year: int
@@ -159,14 +160,16 @@ class XmlDateTime(NamedTuple):
     minute: int
     second: int
     fractional_second: int = 0
-    offset: Optional[int] = None
+    offset: int | None = None
 
     @property
     def microsecond(self) -> int:
+        """Calculate the instance microseconds."""
         return self.fractional_second // 1000
 
     @property
     def duration(self) -> float:
+        """Calculate the instance signed duration in seconds."""
         if self.year < 0:
             negative = True
             year = -self.year
@@ -188,7 +191,7 @@ class XmlDateTime(NamedTuple):
 
     @classmethod
     def from_string(cls, string: str) -> "XmlDateTime":
-        """Initialize from string with format ``%Y-%m-%dT%H:%M:%S%z``"""
+        """Initialize from string with format `%Y-%m-%dT%H:%M:%S%z`."""
         (
             year,
             month,
@@ -199,6 +202,15 @@ class XmlDateTime(NamedTuple):
             fractional_second,
             offset,
         ) = parse_date_args(string, DateFormat.DATE_TIME)
+
+        assert year is not None
+        assert month is not None
+        assert day is not None
+        assert hour is not None
+        assert minute is not None
+        assert second is not None
+        assert fractional_second is not None
+
         validate_date(year, month, day)
         validate_time(hour, minute, second, fractional_second)
 
@@ -206,7 +218,7 @@ class XmlDateTime(NamedTuple):
 
     @classmethod
     def from_datetime(cls, obj: datetime.datetime) -> "XmlDateTime":
-        """Initialize from :class:`datetime.datetime` instance."""
+        """Initialize from `datetime.datetime` instance."""
         return cls(
             obj.year,
             obj.month,
@@ -219,17 +231,17 @@ class XmlDateTime(NamedTuple):
         )
 
     @classmethod
-    def now(cls, tz: Optional[datetime.timezone] = None) -> "XmlDateTime":
-        """Initialize from datetime.datetime.now()"""
+    def now(cls, tz: datetime.timezone | None = None) -> "XmlDateTime":
+        """Initialize with the current datetime and the given timezone."""
         return cls.from_datetime(datetime.datetime.now(tz=tz))
 
     @classmethod
     def utcnow(cls) -> "XmlDateTime":
-        """Initialize from datetime.now(timezone.utc)"""
+        """Initialize with the current datetime and utc timezone."""
         return cls.from_datetime(datetime.datetime.now(datetime.timezone.utc))
 
     def to_datetime(self) -> datetime.datetime:
-        """Return a :class:`datetime.datetime` instance."""
+        """Return a `datetime.datetime` instance."""
         return datetime.datetime(
             self.year,
             self.month,
@@ -243,18 +255,16 @@ class XmlDateTime(NamedTuple):
 
     def replace(
         self,
-        year: Optional[int] = None,
-        month: Optional[int] = None,
-        day: Optional[int] = None,
-        hour: Optional[int] = None,
-        minute: Optional[int] = None,
-        second: Optional[int] = None,
-        fractional_second: Optional[int] = None,
-        offset: Optional[int] = True,
+        year: int | None = None,
+        month: int | None = None,
+        day: int | None = None,
+        hour: int | None = None,
+        minute: int | None = None,
+        second: int | None = None,
+        fractional_second: int | None = None,
+        offset: int | None = True,
     ) -> "XmlDateTime":
-        """Return a new instance replacing the specified fields with new
-        values."""
-
+        """Return a new instance replacing the specified fields with new values."""
         if year is None:
             year = self.year
         if month is None:
@@ -277,8 +287,7 @@ class XmlDateTime(NamedTuple):
         )
 
     def __str__(self) -> str:
-        """
-        Return the datetime formatted according to ISO 8601 for xml.
+        """Return the datetime formatted according to ISO 8601 for xml.
 
         Examples:
             - 2001-10-26T21:32:52
@@ -288,13 +297,12 @@ class XmlDateTime(NamedTuple):
             - 2001-10-26T21:32:52.126
             - -2001-10-26T21:32:52.126Z
         """
-        return "{}T{}{}".format(
-            format_date(self.year, self.month, self.day),
-            format_time(self.hour, self.minute, self.second, self.fractional_second),
-            format_offset(self.offset),
-        )
+        date = format_date(self.year, self.month, self.day)
+        time = format_time(self.hour, self.minute, self.second, self.fractional_second)
+        return f"{date}T{time}{format_offset(self.offset)}"
 
     def __repr__(self) -> str:
+        """Return the instance string representation."""
         args = tuple(self)
         if args[-1] is None:
             args = args[:-1]
@@ -305,50 +313,58 @@ class XmlDateTime(NamedTuple):
         return f"{self.__class__.__qualname__}({', '.join(map(str, args))})"
 
     def __eq__(self, other: Any) -> bool:
-        return cmp(self, other, operator.eq)
+        """Return self == other."""
+        return _cmp(self, other, operator.eq)
 
     def __ne__(self, other: Any) -> bool:
-        return cmp(self, other, operator.ne)
+        """Return self != other."""
+        return _cmp(self, other, operator.ne)
 
     def __lt__(self, other: Any) -> bool:
-        return cmp(self, other, operator.lt)
+        """Return self < other."""
+        return _cmp(self, other, operator.lt)
 
     def __le__(self, other: Any) -> bool:
-        return cmp(self, other, operator.le)
+        """Return self <= other."""
+        return _cmp(self, other, operator.le)
 
     def __gt__(self, other: Any) -> bool:
-        return cmp(self, other, operator.gt)
+        """Return self > other."""
+        return _cmp(self, other, operator.gt)
 
     def __ge__(self, other: Any) -> bool:
-        return cmp(self, other, operator.ge)
+        """Return self >= other."""
+        return _cmp(self, other, operator.ge)
 
 
 class XmlTime(NamedTuple):
-    """
-    Concrete xs:time builtin type.
+    """Concrete xs:time builtin type.
 
-    Represents iso 8601 time format hh
-    :mm: ss[Z|(+|-)hh:mm] with rich comparisons and hashing.
-    :param hour: Unsigned integer between 0-24
-    :param minute: Unsigned integer between 0-59
-    :param second: Unsigned integer between 0-59
-    :param fractional_second: Unsigned integer between 0-999999999
-    :param offset: Signed integer representing timezone offset in
-        minutes
+    Represents iso 8601 time format `hh:mm: ss[Z|(+|-)hh:mm]`
+    with rich comparisons and hashing.
+
+    Attributes:
+        hour: Unsigned integer between 0-24
+        minute: Unsigned integer between 0-59
+        second: Unsigned integer between 0-59
+        fractional_second: Unsigned integer between 0-999999999
+        offset: Signed integer representing timezone offset in minutes
     """
 
     hour: int
     minute: int
     second: int
     fractional_second: int = 0
-    offset: Optional[int] = None
+    offset: int | None = None
 
     @property
     def microsecond(self) -> int:
+        """Calculate the instance microseconds."""
         return self.fractional_second // 1000
 
     @property
     def duration(self) -> float:
+        """Calculate the total duration in seconds."""
         return (
             self.hour * DS_HOUR
             + self.minute * DS_MINUTE
@@ -359,15 +375,13 @@ class XmlTime(NamedTuple):
 
     def replace(
         self,
-        hour: Optional[int] = None,
-        minute: Optional[int] = None,
-        second: Optional[int] = None,
-        fractional_second: Optional[int] = None,
-        offset: Optional[int] = True,
+        hour: int | None = None,
+        minute: int | None = None,
+        second: int | None = None,
+        fractional_second: int | None = None,
+        offset: int | None = True,
     ) -> "XmlTime":
-        """Return a new instance replacing the specified fields with new
-        values."""
-
+        """Return a new instance replacing the specified fields with new values."""
         if hour is None:
             hour = self.hour
         if minute is None:
@@ -383,16 +397,22 @@ class XmlTime(NamedTuple):
 
     @classmethod
     def from_string(cls, string: str) -> "XmlTime":
-        """Initialize from string format ``%H:%M:%S%z``"""
-        hour, minute, second, fractional_second, offset = parse_date_args(
+        """Initialize from string format `%H:%M:%S%z`."""
+        (hour, minute, second, fractional_second, offset) = parse_date_args(
             string, DateFormat.TIME
         )
+
+        assert hour is not None
+        assert minute is not None
+        assert second is not None
+        assert fractional_second is not None
+
         validate_time(hour, minute, second, fractional_second)
         return cls(hour, minute, second, fractional_second, offset)
 
     @classmethod
     def from_time(cls, obj: datetime.time) -> "XmlTime":
-        """Initialize from :class:`datetime.time` instance."""
+        """Initialize from `datetime.time` instance."""
         return cls(
             obj.hour,
             obj.minute,
@@ -402,17 +422,17 @@ class XmlTime(NamedTuple):
         )
 
     @classmethod
-    def now(cls, tz: Optional[datetime.timezone] = None) -> "XmlTime":
-        """Initialize from datetime.datetime.now()"""
+    def now(cls, tz: datetime.timezone | None = None) -> "XmlTime":
+        """Initialize with the current time and the given timezone."""
         return cls.from_time(datetime.datetime.now(tz=tz).time())
 
     @classmethod
     def utcnow(cls) -> "XmlTime":
-        """Initialize from datetime.now(timezone.utc)"""
+        """Initialize with the current time and utc timezone."""
         return cls.from_time(datetime.datetime.now(datetime.timezone.utc).time())
 
     def to_time(self) -> datetime.time:
-        """Return a :class:`datetime.time` instance."""
+        """Convert to a `datetime.time` instance."""
         return datetime.time(
             self.hour,
             self.minute,
@@ -422,8 +442,7 @@ class XmlTime(NamedTuple):
         )
 
     def __str__(self) -> str:
-        """
-        Return the time formatted according to ISO 8601 for xml.
+        """Return the time formatted according to ISO 8601 for xml.
 
         Examples:
             - 21:32:52
@@ -432,12 +451,11 @@ class XmlTime(NamedTuple):
             - 21:32:52.126789
             - 21:32:52.126Z
         """
-        return "{}{}".format(
-            format_time(self.hour, self.minute, self.second, self.fractional_second),
-            format_offset(self.offset),
-        )
+        time = format_time(self.hour, self.minute, self.second, self.fractional_second)
+        return f"{time}{format_offset(self.offset)}"
 
     def __repr__(self) -> str:
+        """Return the instance string representation."""
         args = list(self)
         if args[-1] is None:
             del args[-1]
@@ -445,28 +463,34 @@ class XmlTime(NamedTuple):
         return f"{self.__class__.__qualname__}({', '.join(map(str, args))})"
 
     def __eq__(self, other: Any) -> bool:
-        return cmp(self, other, operator.eq)
+        """Return self == other."""
+        return _cmp(self, other, operator.eq)
 
     def __ne__(self, other: Any) -> bool:
-        return cmp(self, other, operator.ne)
+        """Return self != other."""
+        return _cmp(self, other, operator.ne)
 
     def __lt__(self, other: Any) -> bool:
-        return cmp(self, other, operator.lt)
+        """Return self < other."""
+        return _cmp(self, other, operator.lt)
 
     def __le__(self, other: Any) -> bool:
-        return cmp(self, other, operator.le)
+        """Return self <= other."""
+        return _cmp(self, other, operator.le)
 
     def __gt__(self, other: Any) -> bool:
-        return cmp(self, other, operator.gt)
+        """Return self > other."""
+        return _cmp(self, other, operator.gt)
 
     def __ge__(self, other: Any) -> bool:
-        return cmp(self, other, operator.ge)
+        """Return self >= other."""
+        return _cmp(self, other, operator.ge)
 
 
-DurationType = Union[XmlTime, XmlDateTime]
+DurationType = XmlTime | XmlDateTime
 
 
-def cmp(a: DurationType, b: DurationType, op: Callable) -> bool:
+def _cmp(a: DurationType, b: DurationType, op: Callable) -> bool:
     if isinstance(b, a.__class__):
         return op(a.duration, b.duration)
 
@@ -474,18 +498,19 @@ def cmp(a: DurationType, b: DurationType, op: Callable) -> bool:
 
 
 class TimeInterval(NamedTuple):
+    """Time interval model representation."""
+
     negative: bool
-    years: Optional[int]
-    months: Optional[int]
-    days: Optional[int]
-    hours: Optional[int]
-    minutes: Optional[int]
-    seconds: Optional[float]
+    years: int | None
+    months: int | None
+    days: int | None
+    hours: int | None
+    minutes: int | None
+    seconds: float | None
 
 
 class XmlDuration(UserString):
-    """
-    Concrete xs:duration builtin type.
+    """Concrete xs:duration builtin type.
 
     Represents iso 8601 duration format PnYnMnDTnHnMnS
     with rich comparisons and hashing.
@@ -500,40 +525,42 @@ class XmlDuration(UserString):
         - **nM**: the number of minutes followed by a literal M
         - **nS**: the number of seconds followed by a literal S
 
-    :param value: String representation of a xs:duration, eg **P2Y6M5DT12H**
+    Args:
+        value: String representation of a xs:duration, eg **P2Y6M5DT12H**
     """
 
     def __init__(self, value: str) -> None:
+        """Initialize with the given string."""
         super().__init__(value)
         self._interval = self._parse_interval(value)
 
     @property
-    def years(self) -> Optional[int]:
+    def years(self) -> int | None:
         """Number of years in the interval."""
         return self._interval.years
 
     @property
-    def months(self) -> Optional[int]:
+    def months(self) -> int | None:
         """Number of months in the interval."""
         return self._interval.months
 
     @property
-    def days(self) -> Optional[int]:
+    def days(self) -> int | None:
         """Number of days in the interval."""
         return self._interval.days
 
     @property
-    def hours(self) -> Optional[int]:
+    def hours(self) -> int | None:
         """Number of hours in the interval."""
         return self._interval.hours
 
     @property
-    def minutes(self) -> Optional[int]:
+    def minutes(self) -> int | None:
         """Number of minutes in the interval."""
         return self._interval.minutes
 
     @property
-    def seconds(self) -> Optional[float]:
+    def seconds(self) -> float | None:
         """Number of seconds in the interval."""
         return self._interval.seconds
 
@@ -565,23 +592,26 @@ class XmlDuration(UserString):
             seconds=float(seconds) if seconds else None,
         )
 
-    def asdict(self) -> Dict:
+    def asdict(self) -> dict:
+        """Return instance as a dict."""
         return self._interval._asdict()
 
     def __repr__(self) -> str:
+        """Return the instance string representation."""
         return f'{self.__class__.__qualname__}("{self.data}")'
 
 
 class TimePeriod(NamedTuple):
-    year: Optional[int]
-    month: Optional[int]
-    day: Optional[int]
-    offset: Optional[int]
+    """Time period model representation."""
+
+    year: int | None
+    month: int | None
+    day: int | None
+    offset: int | None
 
 
 class XmlPeriod(UserString):
-    """
-    Concrete xs:gYear/Month/Day builtin type.
+    """Concrete xs:gYear/Month/Day builtin type.
 
     Represents iso 8601 period formats with rich comparisons and hashing.
 
@@ -592,31 +622,33 @@ class XmlPeriod(UserString):
         - xs:gMonthDay: **--%m-%d%z**
         - xs:gYearMonth: **%Y-%m%z**
 
-    :param value: String representation of a xs:period, eg **--11-01Z**
+    Args:
+        value: String representation of a xs:period, eg **--11-01Z**
     """
 
     def __init__(self, value: str) -> None:
+        """Initialize a xs:period."""
         value = value.strip()
         super().__init__(value)
         self._period = self._parse_period(value)
 
     @property
-    def year(self) -> Optional[int]:
+    def year(self) -> int | None:
         """Period year."""
         return self._period.year
 
     @property
-    def month(self) -> Optional[int]:
+    def month(self) -> int | None:
         """Period month."""
         return self._period.month
 
     @property
-    def day(self) -> Optional[int]:
+    def day(self) -> int | None:
         """Period day."""
         return self._period.day
 
     @property
-    def offset(self) -> Optional[int]:
+    def offset(self) -> int | None:
         """Period timezone offset in minutes."""
         return self._period.offset
 
@@ -648,14 +680,16 @@ class XmlPeriod(UserString):
 
         return TimePeriod(year=year, month=month, day=day, offset=offset)
 
-    def as_dict(self) -> Dict:
+    def as_dict(self) -> dict:
         """Return date units as dict."""
         return self._period._asdict()
 
     def __repr__(self) -> str:
+        """Return the instance string representation."""
         return f'{self.__class__.__qualname__}("{self.data}")'
 
     def __eq__(self, other: Any) -> bool:
+        """Return self == other."""
         if isinstance(other, XmlPeriod):
             return self._period == other._period
 
@@ -663,8 +697,7 @@ class XmlPeriod(UserString):
 
 
 class XmlHexBinary(bytes):
-    """
-    Subclass bytes to infer base16 format.
+    """Subclass bytes to infer base16 format.
 
     This type can be used with xs:anyType fields that don't have a
     format property to specify the target output format.
@@ -672,8 +705,7 @@ class XmlHexBinary(bytes):
 
 
 class XmlBase64Binary(bytes):
-    """
-    Subclass bytes to infer base64 format.
+    """Subclass bytes to infer base64 format.
 
     This type can be used with xs:anyType fields that don't have a
     format property to specify the target output format.
