@@ -3,8 +3,10 @@ import copy
 import importlib
 import random
 import unittest
+from collections.abc import Callable, Sequence
+from contextlib import suppress
 from dataclasses import is_dataclass
-from typing import Any, Callable, Dict, List, Optional, Sequence, Type, TypeVar
+from typing import Any, TypeVar
 
 from xsdata.codegen.models import (
     Attr,
@@ -41,23 +43,30 @@ DEFAULT_NS_MAP = {
 }
 
 
+def filter_none(d: Any) -> Any:
+    if not isinstance(d, dict):
+        return d
+
+    return {k: filter_none(v) for k, v in d.items() if v is not None}
+
+
 def load_class(output: str, clazz_name: str) -> Any:
     search = "Generating package: "
     start = len(search)
     packages = [line[start:] for line in output.splitlines() if line.startswith(search)]
 
     for package in reversed(packages):
-        try:
+        with suppress(ModuleNotFoundError, AttributeError):
             module = importlib.import_module(package)
             return getattr(module, clazz_name)
-        except (ModuleNotFoundError, AttributeError):
-            pass
 
     raise ModuleNotFoundError(f"Class `{clazz_name}` not found.")
 
 
 class FactoryTestCase(unittest.TestCase):
-    def setUp(self):
+    maxDiff = None
+
+    def setUp(self) -> None:
         super().setUp()
         ClassFactory.reset()
         AttrFactory.reset()
@@ -74,7 +83,7 @@ class FactoryTestCase(unittest.TestCase):
 
 class Factory(abc.ABC):
     counter = 0
-    model: Type
+    model: type
 
     @classmethod
     @abc.abstractmethod
@@ -91,36 +100,36 @@ class Factory(abc.ABC):
         return chr(cls.counter)
 
     @classmethod
-    def list(cls, number: int, **kwargs: Any) -> List:
+    def list(cls, number: int, **kwargs: Any) -> list:
         return [cls.create(**kwargs) for _ in range(number)]
 
 
 class ClassFactory(Factory):
-    tags = [Tag.ELEMENT, Tag.ATTRIBUTE, Tag.COMPLEX_TYPE, Tag.SIMPLE_TYPE]
+    tags = (Tag.ELEMENT, Tag.ATTRIBUTE, Tag.COMPLEX_TYPE, Tag.SIMPLE_TYPE)
     counter = 65
 
     @classmethod
     def create(
         cls,
-        qname: Optional[str] = None,
-        meta_name: Optional[str] = None,
-        namespace: Optional[str] = None,
-        target_namespace: Optional[str] = None,
-        tag: Optional[str] = None,
+        qname: str | None = None,
+        meta_name: str | None = None,
+        namespace: str | None = None,
+        target_namespace: str | None = None,
+        tag: str | None = None,
         abstract: bool = False,
         mixed: bool = False,
         nillable: bool = False,
-        extensions: Optional[List[Extension]] = None,
-        substitutions: Optional[List[str]] = None,
-        attrs: Optional[List[Attr]] = None,
-        inner: Optional[List[Class]] = None,
-        ns_map: Optional[Dict] = None,
+        extensions: list[Extension] | None = None,
+        substitutions: list[str] | None = None,
+        attrs: list[Attr] | None = None,
+        inner: list[Class] | None = None,
+        ns_map: dict | None = None,
         location: str = "tests.xsd",
-        package: Optional[str] = None,
-        module: Optional[str] = "tests",
+        package: str | None = None,
+        module: str | None = "tests",
         status: Status = Status.RAW,
-        container: Optional[str] = None,
-        default: Optional[Any] = None,
+        container: str | None = None,
+        default: Any | None = None,
         fixed: bool = False,
         prefix: str = "class_",
         **kwargs: Any,
@@ -189,14 +198,14 @@ class ClassFactory(Factory):
 
 class ExtensionFactory(Factory):
     counter = 65
-    tags = [Tag.ELEMENT, Tag.EXTENSION, Tag.RESTRICTION]
+    tags = (Tag.ELEMENT, Tag.EXTENSION, Tag.RESTRICTION)
 
     @classmethod
     def create(
         cls,
-        attr_type: Optional[AttrType] = None,
-        restrictions: Optional[Restrictions] = None,
-        tag: Optional[str] = None,
+        attr_type: AttrType | None = None,
+        restrictions: Restrictions | None = None,
+        tag: str | None = None,
         **kwargs: Any,
     ) -> Extension:
         return Extension(
@@ -226,8 +235,8 @@ class AttrTypeFactory(Factory):
     @classmethod
     def create(
         cls,
-        qname: Optional[str] = None,
-        alias: Optional[str] = None,
+        qname: str | None = None,
+        alias: str | None = None,
         native: bool = False,
         forward: bool = False,
         circular: bool = False,
@@ -253,22 +262,23 @@ class AttrTypeFactory(Factory):
 
 
 class AttrFactory(Factory):
-    tags = [Tag.ATTRIBUTE, Tag.ELEMENT, Tag.RESTRICTION]
+    tags = (Tag.ATTRIBUTE, Tag.ELEMENT, Tag.RESTRICTION)
     counter = 65
 
     @classmethod
     def create(
         cls,
-        name: Optional[str] = None,
-        index: Optional[int] = None,
-        types: Optional[List[AttrType]] = None,
-        choices: Optional[List[Attr]] = None,
-        tag: Optional[str] = None,
-        namespace: Optional[str] = None,
-        default: Optional[Any] = None,
+        name: str | None = None,
+        index: int | None = None,
+        types: list[AttrType] | None = None,
+        choices: list[Attr] | None = None,
+        tag: str | None = None,
+        namespace: str | None = None,
+        wrapper: str | None = None,
+        default: Any | None = None,
         fixed: bool = False,
         mixed: bool = False,
-        restrictions: Optional[Restrictions] = None,
+        restrictions: Restrictions | None = None,
         prefix: str = "attr_",
         **kwargs: Any,
     ) -> Attr:
@@ -280,6 +290,7 @@ class AttrFactory(Factory):
             choices=choices or [],
             tag=tag or random.choice(cls.tags),
             namespace=namespace,
+            wrapper=wrapper,
             default=default,
             fixed=fixed,
             mixed=mixed,
@@ -288,14 +299,28 @@ class AttrFactory(Factory):
         )
 
     @classmethod
-    def reference(cls, qname: str, tag: str = Tag.ELEMENT, **kwargs: Any) -> Attr:
+    def reference(
+        cls,
+        qname: str,
+        tag: str = Tag.ELEMENT,
+        name: str | None = None,
+        **kwargs: Any,
+    ) -> Attr:
         return cls.create(
-            tag=tag, types=[AttrTypeFactory.create(qname=qname, **kwargs)]
+            name=name, tag=tag, types=[AttrTypeFactory.create(qname=qname, **kwargs)]
         )
 
     @classmethod
-    def native(cls, datatype: DataType, tag: str = Tag.ELEMENT, **kwargs: Any) -> Attr:
-        return cls.create(tag=tag, types=[AttrTypeFactory.native(datatype)], **kwargs)
+    def native(
+        cls,
+        datatype: DataType,
+        tag: str = Tag.ELEMENT,
+        name: str | None = None,
+        **kwargs: Any,
+    ) -> Attr:
+        return cls.create(
+            name=name, tag=tag, types=[AttrTypeFactory.native(datatype)], **kwargs
+        )
 
     @classmethod
     def enumeration(cls, **kwargs: Any) -> Attr:
@@ -348,7 +373,7 @@ class PackageFactory(Factory):
         cls,
         qname: str = "{xsdata}Root",
         source: str = "generated.models",
-        alias: Optional[str] = None,
+        alias: str | None = None,
         **kwargs: Any,
     ) -> Import:
         return Import(qname=qname, source=source, alias=alias)
@@ -360,34 +385,34 @@ class XmlVarFactory(Factory):
     @classmethod
     def create(
         cls,
-        name: Optional[str] = None,
-        qname: Optional[str] = None,
+        name: str | None = None,
+        local_name: str | None = None,
+        wrapper: str | None = None,
         index: int = 0,
-        types: Optional[Sequence[Type]] = None,
-        clazz: Optional[Type] = None,
+        types: Sequence[type] | None = None,
+        clazz: type | None = None,
         init: bool = True,
         mixed: bool = False,
-        factory: Optional[Callable] = None,
-        tokens_factory: Optional[Callable] = None,
-        format: Optional[str] = None,
-        derived: bool = False,
+        factory: Callable | None = None,
+        tokens_factory: Callable | None = None,
+        format: str | None = None,
         any_type: bool = False,
         required: bool = False,
         nillable: bool = False,
-        sequence: Optional[int] = None,
+        sequence: int | None = None,
         list_element: bool = False,
-        default: Optional[Any] = None,
+        default: Any | None = None,
         xml_type: str = XmlType.ELEMENT,
-        namespaces: Optional[Sequence[str]] = None,
-        elements: Optional[Dict[str, XmlVar]] = None,
-        wildcards: Optional[Sequence[XmlVar]] = None,
+        namespaces: Sequence[str] | None = None,
+        elements: dict[str, XmlVar] | None = None,
+        wildcards: Sequence[XmlVar] | None = None,
         prefix: str = "field_",
         **kwargs: Any,
     ) -> XmlVar:
         name = name or f"{prefix}{cls.next_letter()}"
 
-        if qname is None:
-            qname = name
+        if local_name is None:
+            local_name = name
 
         if types is None:
             types = ()
@@ -401,7 +426,8 @@ class XmlVarFactory(Factory):
         return XmlVar(
             index=index,
             name=name,
-            qname=qname,
+            local_name=local_name,
+            wrapper=wrapper,
             types=types,
             clazz=clazz or first(tp for tp in types if is_dataclass(tp)),
             init=init,
@@ -409,7 +435,6 @@ class XmlVarFactory(Factory):
             factory=factory,
             tokens_factory=tokens_factory,
             format=format,
-            derived=derived,
             any_type=any_type,
             required=required,
             nillable=nillable,
@@ -421,7 +446,6 @@ class XmlVarFactory(Factory):
             namespaces=namespaces,
             elements=elements,
             wildcards=wildcards,
-            wrapper=None,
         )
 
 
@@ -431,16 +455,16 @@ class XmlMetaFactory(Factory):
     @classmethod
     def create(  # type: ignore
         cls,
-        clazz: Type,
-        qname: Optional[str] = None,
-        target_qname: Optional[str] = None,
+        clazz: type,
+        qname: str | None = None,
+        target_qname: str | None = None,
         nillable: bool = False,
-        text: Optional[XmlVar] = None,
-        choices: Optional[Sequence[XmlVar]] = None,
-        elements: Optional[Dict[str, Sequence[XmlVar]]] = None,
-        wildcards: Optional[Sequence[XmlVar]] = None,
-        attributes: Optional[Dict[str, XmlVar]] = None,
-        any_attributes: Optional[Sequence[XmlVar]] = None,
+        text: XmlVar | None = None,
+        choices: Sequence[XmlVar] | None = None,
+        elements: dict[str, Sequence[XmlVar]] | None = None,
+        wildcards: Sequence[XmlVar] | None = None,
+        attributes: dict[str, XmlVar] | None = None,
+        any_attributes: Sequence[XmlVar] | None = None,
         **kwargs: Any,
     ) -> XmlMeta:
         if qname is None:
@@ -485,12 +509,12 @@ class DtdAttributeFactory(Factory):
     @classmethod
     def create(
         cls,
-        name: Optional[str] = None,
-        prefix: Optional[str] = None,
-        type: Optional[DtdAttributeType] = None,
-        default: Optional[DtdAttributeDefault] = None,
-        default_value: Optional[str] = None,
-        values: Optional[List[str]] = None,
+        name: str | None = None,
+        prefix: str | None = None,
+        type: DtdAttributeType | None = None,
+        default: DtdAttributeDefault | None = None,
+        default_value: str | None = None,
+        values: list[str] | None = None,
         **kwargs: Any,
     ) -> DtdAttribute:
         if name is None:
@@ -521,11 +545,11 @@ class DtdContentFactory(Factory):
     @classmethod
     def create(
         cls,
-        name: Optional[str] = None,
-        type: Optional[DtdContentType] = None,
-        occur: Optional[DtdContentOccur] = None,
-        left: Optional[DtdContent] = None,
-        right: Optional[DtdContent] = None,
+        name: str | None = None,
+        type: DtdContentType | None = None,
+        occur: DtdContentOccur | None = None,
+        left: DtdContent | None = None,
+        right: DtdContent | None = None,
         **kwargs: Any,
     ) -> DtdContent:
         if name is None:
@@ -552,12 +576,12 @@ class DtdElementFactory(Factory):
     @classmethod
     def create(
         cls,
-        name: Optional[str] = None,
-        prefix: Optional[str] = None,
-        type: Optional[DtdElementType] = None,
-        content: Optional[DtdContent] = None,
-        attributes: Optional[List[DtdAttribute]] = None,
-        ns_map: Optional[Dict] = None,
+        name: str | None = None,
+        prefix: str | None = None,
+        type: DtdElementType | None = None,
+        content: DtdContent | None = None,
+        attributes: list[DtdAttribute] | None = None,
+        ns_map: dict | None = None,
         **kwargs: Any,
     ) -> DtdElement:
         if name is None:
@@ -586,8 +610,8 @@ class DtdFactory(Factory):
     @classmethod
     def create(
         cls,
-        elements: Optional[List[DtdElement]] = None,
-        location: Optional[str] = None,
+        elements: list[DtdElement] | None = None,
+        location: str | None = None,
         **kwargs: Any,
     ) -> Dtd:
         if elements is None:
